@@ -1,4 +1,4 @@
-# $Id$
+# $Id: IO.pm,v 1.17.4.3 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::Biblio::IO
 #
@@ -17,72 +17,73 @@ Bio::Biblio::IO - Handling the bibliographic references
 
     # getting citations from a file
     $in = Bio::Biblio::IO->new ('-file' => 'myfile.xml' ,
-				'-format' => 'medlinexml');
- --- OR ---
+                                '-format' => 'medlinexml');
+  # --- OR ---
 
     # getting citations from a string
     $in = Bio::Biblio::IO->new ('-data' => '<MedlineCitation>...</MedlineCitation>' ,
-				'-format' => 'medlinexml');
- --- OR ---
+                                '-format' => 'medlinexml');
+  #--- OR ---
 
     # getting citations from a string if IO::String is installed
     use IO::String;
     $in = Bio::Biblio::IO->new ('-fh' => IO::String->new ($citation),
-				'-format' => 'medlinexml');
+                                '-format' => 'medlinexml');
 
     $in = Bio::Biblio::IO->new(-fh => $io_handle , '-format' => 'medlinexml');
 
- --- OR ---
+  #--- OR ---
 
     # getting citations from any IO handler
     $in = Bio::Biblio::IO->new('-fh' => $io_handle ,
-			       '-format' => 'medlinexml');
+                               '-format' => 'medlinexml');
 
 
     # now, having $in, we can read all citations
     while ( my $citation = $in->next_bibref() ) {
-	&do_something_with_citation ($citation);
+        &do_something_with_citation ($citation);
     }
 
- --- OR ---
+  #--- OR ---
 
     # again reading all citation but now a callback defined in your
     # code is used (note that the reading starts already when new()
     # is called)
     $io = new Bio::Biblio::IO ('-format'   => 'medlinexml',
-			       '-file'     => $testfile,
-			       '-callback' => \&callback);
+                               '-file'     => $testfile,
+                               '-callback' => \&callback);
     sub callback {
         my $citation = shift;
-	print $citation->{'_identifier'} . "\n";
+        print $citation->{'_identifier'} . "\n";
     }
 
-Now, to actually get a citation in an XML format,
-use I<Bio::Biblio> module which returns an XML string:
+  #Now, to actually get a citation in an XML format,
+  #use I<Bio::Biblio> module which returns an XML string:
 
     use Bio::Biblio;
-    my $xml = new Bio::Biblio->get_by_id ('94033980');
+    use Bio::Biblio::IO;
+    my $xml = new Bio::Biblio->get_by_id ('12368254');
     my $reader = Bio::Biblio::IO->new ('-data' => $xml,
-				       '-format' => 'medlinexml');
+                                       '-format' => 'medlinexml');
 
     while (my $citation = $reader->next_bibref()) {
-       ... do something here with $citation
+       #... do something here with $citation
        }
 
-And, finally, the resulting citation can be received in different
-output formats:
+  #And, finally, the resulting citation can be received in different
+  #output formats:
 
     $io = new Bio::Biblio::IO ('-format' => 'medlinexml',
-			       '-result' => 'raw');
- --- OR ---
+                               '-result' => 'raw');
+  #--- OR ---
 
     $io = new Bio::Biblio::IO ('-format' => 'medlinexml',
-			       '-result' => 'medline2ref');
+                               '-result' => 'medline2ref');
 
- --- OR ---
+  #--- OR ---
 
     $io = new Bio::Biblio::IO ('-format' => 'pubmedxml',
-			       '-result' => 'pubmed2ref');
+                               '-result' => 'pubmed2ref');
 
 =head1 DESCRIPTION
 
@@ -129,20 +130,20 @@ Another result format available is for PUBMED citations (which is a
 super-set of the MEDLINE citations having few more tags):
 
     $io = new Bio::Biblio::IO ('-format' => 'pubmedxml',
-			       '-result' => 'pubmed2ref',
-			       '-data'   => $citation);
+                               '-result' => 'pubmed2ref',
+                               '-data'   => $citation);
 
 Or, because C<pubmed2ref> is a default one for PUBMED citations, you can say just:
 
     $io = new Bio::Biblio::IO ('-format' => 'pubmedxml',
-			       '-data'   => $citation);
+                               '-data'   => $citation);
 
 Both C<medline2ref> and C<pubmed2ref> results are objects defined in
 the directory C<Bio::Biblio>.
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item *
 
@@ -153,11 +154,11 @@ format to achieve).
 
 =item *
 
-OpenBQS home page: http://industry.ebi.ac.uk/openBQS
+OpenBQS home page: http://www.ebi.ac.uk/~senger/openbqs
 
 =item *
 
-Comments to the Perl client: http://industry.ebi.ac.uk/openBQS/Client_perl.html
+Comments to the Perl client: http://www.ebi.ac.uk/~senger/openbqs/Client_perl.html
 
 =back
 
@@ -171,16 +172,15 @@ and other Bioperl modules. Send your comments and suggestions preferably
 Your participation is much appreciated.
 
   bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/MailList.shtml      - About the mailing lists
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -210,25 +210,22 @@ methods. Internal methods are preceded with a _
 package Bio::Biblio::IO;
 
 use strict;
-use vars qw(@ISA);
 
-use Bio::Root::Root;
-use Bio::Root::IO;
 use Symbol();
 
-@ISA = qw(Bio::Root::Root Bio::Root::IO);
+use base qw(Bio::Root::Root Bio::Root::IO);
 
 my $entry = 0;
 
 sub new {
     my ($caller, @args) = @_;
     my $class = ref ($caller) || $caller;
-    
+
     # if $caller is an object, or if it is an underlying
     # 'real-work-doing' class (e.g. Bio::Biblio::IO::medlinexml) then
     # we want to call SUPER to create and bless an object
     if( $class =~ /Bio::Biblio::IO::(\S+)/ ) {
-	my ($self) = $class->SUPER::new (@args);	
+	my ($self) = $class->SUPER::new (@args);
 	$self->_initialize (@args);
 	return $self;
 
@@ -236,16 +233,16 @@ sub new {
     # Bio::Biblio::IO (...)', and it actually loads a 'real-work-doing'
     # module and call this new() method again (unless the loaded
     # module has its own new() method)
-    } else { 
+    } else {
 	my %param = @args;
 	@param{ map { lc $_ } keys %param } = values %param; # lowercase keys
-	my $format = $param{'-format'} || 
+	my $format = $param{'-format'} ||
 	    $class->_guess_format( $param{-file} || $ARGV[0] ) ||
 		'medlinexml';
 	$format = "\L$format";	# normalize capitalization to lower case
 
 	# load module with the real implementation - as defined in $format
-	return undef unless (&_load_format_module ($format));
+	return unless (&_load_format_module ($format));
 
 	# this will call this same method new() - but rather its
 	# upper (object) branche
