@@ -1,4 +1,4 @@
-# $Id$
+# $Id: medlinexml.pm,v 1.9.4.1 2006/10/02 23:10:13 sendu Exp $
 #
 # BioPerl module Bio::Biblio::IO::medlinexml.pm
 #
@@ -33,17 +33,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -75,23 +74,15 @@ with an underscore _.
 
 
 package Bio::Biblio::IO::medlinexml;
-use vars qw(@ISA $VERSION $Revision);
 use vars qw(@Citations $Callback $Convert @ObjectStack @PCDataStack);
 use vars qw(%PCDATA_NAMES %SIMPLE_TREATMENT %POP_DATA_AND_PEEK_OBJ %POP_OBJ_AND_PEEK_OBJ);
 use vars qw(%POP_AND_ADD_ELEMENT %POP_AND_ADD_DATA_ELEMENT);
 
 use strict;
 
-use Bio::Biblio::IO;
 use XML::Parser;
 
-@ISA = qw(Bio::Biblio::IO);
-
-BEGIN { 
-    # set the version for version checking
-    $VERSION = do { my @r = (q$Revision$ =~ /\d+/g); sprintf "%d.%-02d", @r };
-    $Revision = q$Id$;
-}
+use base qw(Bio::Biblio::IO);
 
 # -----------------------------------------------------------------------------
 
