@@ -1,4 +1,4 @@
-# $Id$
+# $Id: MedlineBookArticle.pm,v 1.10.4.3 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::Biblio::MedlineBookArticle
 #
@@ -15,8 +15,8 @@ Bio::Biblio::MedlineBookArticle - Representation of a MEDLINE book article
 
     $obj = new Bio::Biblio::MedlineBookArticle
                   (-title => 'Getting started'.
-		   -book => new Bio::Biblio::MedlineBook);
- --- OR ---
+                   -book => new Bio::Biblio::MedlineBook);
+  #--- OR ---
 
     $obj = new Bio::Biblio::MedlineBookArticle;
     $obj->title ('Getting started');
@@ -25,7 +25,7 @@ Bio::Biblio::MedlineBookArticle - Representation of a MEDLINE book article
 
 A storage object for a MEDLINE book.
 See its place in the class hierarchy in
-http://industry.ebi.ac.uk/openBQS/images/bibobjects_perl.gif
+http://www.ebi.ac.uk/~senger/openbqs/images/bibobjects_perl.gif
 
 =head2 Attributes
 
@@ -36,15 +36,15 @@ The following attributes are specific to this class
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item *
 
-OpenBQS home page: http://industry.ebi.ac.uk/openBQS
+OpenBQS home page: http://www.ebi.ac.uk/~senger/openbqs/
 
 =item *
 
-Comments to the Perl client: http://industry.ebi.ac.uk/openBQS/Client_perl.html
+Comments to the Perl client: http://www.ebi.ac.uk/~senger/openbqs/Client_perl.html
 
 =back
 
@@ -56,21 +56,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHORS
 
-Heikki Lehvaslaiho (heikki@ebi.ac.uk),
+Heikki Lehvaslaiho (heikki-at-bioperl-dot-org),
 Martin Senger (senger@ebi.ac.uk)
 
 =head1 COPYRIGHT
@@ -94,10 +93,8 @@ package Bio::Biblio::MedlineBookArticle;
 use strict;
 use vars qw(@ISA);
 
-use Bio::Biblio::BookArticle;
-use Bio::Biblio::MedlineArticle;
 
-@ISA = qw(Bio::Biblio::BookArticle Bio::Biblio::MedlineArticle);
+use base qw(Bio::Biblio::BookArticle Bio::Biblio::MedlineArticle);
 
 #
 # a closure with a list of allowed attribute names (these names
