@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Ref.pm,v 1.12.4.3 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::Biblio::Ref
 #
@@ -14,8 +14,8 @@ Bio::Biblio::Ref - Representation of a bibliographic reference
 =head1 SYNOPSIS
 
     $obj = new Bio::Biblio::Ref (-type  => 'Letter',
-				 -title => 'Onegin to Tatiana');
- --- OR ---
+                                 -title => 'Onegin to Tatiana');
+  #--- OR ---
 
     $obj = new Bio::Biblio::Ref;
     $obj->type ('Letter');
@@ -24,11 +24,11 @@ Bio::Biblio::Ref - Representation of a bibliographic reference
 
 A storage object for a general bibliographic reference (a citation).
 See its place in the class hierarchy in
-http://industry.ebi.ac.uk/openBQS/images/bibobjects_perl.gif
+http://www.ebi.ac.uk/~senger/openbqs/images/bibobjects_perl.gif
 
 =head2 Attributes
 
-The following attributes are specific to this class, 
+The following attributes are specific to this class,
 and they are inherited by all citation types.
 
   author_list_complete            values: 'Y'  (default) or 'N'
@@ -63,15 +63,15 @@ and they are inherited by all citation types.
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item *
 
-OpenBQS home page: http://industry.ebi.ac.uk/openBQS
+OpenBQS home page: http://www.ebi.ac.uk/~senger/openbqs/
 
 =item *
 
-Comments to the Perl client: http://industry.ebi.ac.uk/openBQS/Client_perl.html
+Comments to the Perl client: http://www.ebi.ac.uk/~senger/openbqs/Client_perl.html
 
 =back
 
@@ -83,21 +83,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHORS
 
-Heikki Lehvaslaiho (heikki@ebi.ac.uk),
+Heikki Lehvaslaiho (heikki-at-bioperl-dot-org),
 Martin Senger (senger@ebi.ac.uk)
 
 =head1 COPYRIGHT
@@ -124,12 +123,11 @@ methods. Internal methods are preceded with a _
 
 package Bio::Biblio::Ref;
 use strict;
-use vars qw(@ISA $AUTOLOAD);
+use vars qw($AUTOLOAD);
 
-use Bio::Biblio::BiblioBase;
 use Bio::Annotation::DBLink;
 
-@ISA = qw(Bio::Biblio::BiblioBase);
+use base qw(Bio::Biblio::BiblioBase);
 
 #
 # a closure with a list of allowed attribute names (these names
