@@ -1,4 +1,4 @@
-# $Id$
+# $Id: ClusterIO.pm,v 1.18.4.1 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::ClusterIO.pm
 #
@@ -104,16 +104,15 @@ and other Bioperl modules. Send your comments and suggestions preferably
 Your participation is much appreciated.
 
   bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/MailList.shtml      - About the mailing lists
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Andrew Macgregor
 
@@ -132,12 +131,9 @@ methods. Internal methods are usually preceded with a _
 package Bio::ClusterIO;
 
 use strict;
-use vars qw(@ISA);
 
-use Bio::Root::Root;
-use Bio::Root::IO;
 
-@ISA = qw(Bio::Root::Root Bio::Root::IO);
+use base qw(Bio::Root::Root Bio::Root::IO);
 
 
 
@@ -173,7 +169,7 @@ sub new {
 	    $class->_guess_format( $param{-file} || $ARGV[0] );
 	$format = "\L$format";	# normalize capitalization to lower case
 
-	return undef unless( $class->_load_format_module($format) );
+	return unless( $class->_load_format_module($format) );
 	return "Bio::ClusterIO::$format"->new(@args);
     }
 }
