@@ -1,8 +1,8 @@
-# $Id$
+# $Id: GeneMapper.pm,v 1.27.4.1 2006/10/02 23:10:14 sendu Exp $
 #
 # bioperl module for Bio::Coordinate::GeneMapper
 #
-# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
+# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
 #
 # Copyright Heikki Lehvaslaiho
 #
@@ -28,9 +28,9 @@ Bio::Coordinate::GeneMapper - transformations between gene related coordinate sy
   my $exons;
 
   # create a gene mapper and set it to map from chromosomal to cds coordinates
-  my $gene = Bio::Coordinate::GeneMapper->new(-in=>'chr',
-                                              -out=>'cds',
-                                              -cds=>$cds,
+  my $gene = Bio::Coordinate::GeneMapper->new(-in   =>'chr',
+                                              -out  =>'cds',
+                                              -cds  =>$cds,
                                               -exons=>$exons
                                              );
 
@@ -114,26 +114,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                 - General discussion
-  http://bio.perl.org/MailList.html     - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email:  heikki@ebi.ac.uk
-Address:
-
-     EMBL Outstation, European Bioinformatics Institute
-     Wellcome Trust Genome Campus, Hinxton
-     Cambs. CB10 1SD, United Kingdom
+Email:  heikki-at-bioperl-dot-org
 
 =head1 APPENDIX
 
@@ -146,13 +140,12 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Coordinate::GeneMapper;
-use vars qw(@ISA %COORDINATE_SYSTEMS  %COORDINATE_INTS $TRANSLATION $DAG
+use vars qw(%COORDINATE_SYSTEMS %COORDINATE_INTS $TRANSLATION $DAG
             $NOZERO_VALUES $NOZERO_KEYS);
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
 
-use Bio::Root::Root;
 use Bio::Coordinate::Result;
 use Bio::Location::Simple;
 use Bio::Coordinate::Graph;
@@ -160,7 +153,7 @@ use Bio::Coordinate::Collection;
 use Bio::Coordinate::Pair;
 use Bio::Coordinate::ExtrapolatingPair;
 
-@ISA = qw(Bio::Root::Root Bio::Coordinate::MapperI);
+use base qw(Bio::Root::Root Bio::Coordinate::MapperI);
 
 # first set internal values for all translation tables
 
@@ -296,7 +289,7 @@ sub out {
 
  Title   : strict
  Usage   : $obj->strict('peptide');
- Function: Set and read weather strict boundaried of coordinate
+ Function: Set and read whether strict boundaried of coordinate
            systems are enforced.
            When strict is on, the end of the coordinate range must be defined.
  Example :
@@ -401,7 +394,8 @@ sub peptide {
        (-seq_id => 'propeptide',
 	-start => $self->{'_peptide_offset'} + 1 ,
 	-end => $self->{'_peptide_length'} + $self->{'_peptide_offset'},
-	-strand => 1
+	-strand => 1,
+	-verbose => $self->verbose,
        );
 }
 
@@ -502,31 +496,36 @@ sub exons {
        # sort the input array
        #
        # and if the used has not defined CDS assume it is the complete exonic range
-       if (defined $value[0]->strand && $value[0]->strand == - 1) {  #reverse strand
+       if (defined $value[0]->strand && 
+	   $value[0]->strand == - 1) {  #reverse strand
 	   @value = map { $_->[0] }
-	               sort { $b->[1] <=> $a->[1] }
-                       map { [ $_, $_->start] }
-                       @value;
+	            sort { $b->[1] <=> $a->[1] }
+	            map { [ $_, $_->start] }
+                    @value;
 
            unless ($self->cds) {
-               $self->cds(new Bio::Location::Simple(-start => $value[-1]->start,
-                                                    -end   => $value[0]->end,
-                                                    -strand=> $value[0]->strand,
-                                                    -seq_id=> $value[0]->seq_id,
-                                                   )
-                         );
+               $self->cds(new Bio::Location::Simple
+			  (-start   => $value[-1]->start,
+			   -end     => $value[0]->end,
+			   -strand  => $value[0]->strand,
+			   -seq_id  => $value[0]->seq_id,
+			   -verbose => $self->verbose,
+			   )
+			  );
            }
-       } else {               #undef or forward strand
+       } else {               # undef or forward strand
 	   @value = map { $_->[0] }
-	               sort { $a->[1] <=> $b->[1] }
-                       map { [ $_, $_->start] }
-                       @value;
+	            sort { $a->[1] <=> $b->[1] }
+                    map { [ $_, $_->start] }
+                    @value;
            unless ($self->cds) {
-               $self->cds(new Bio::Location::Simple(-start => $value[0]->start,
-                                                    -end   => $value[-1]->end,
-                                                    -strand=> $value[0]->strand,
-                                                    -seq_id=> $value[0]->seq_id,
-                                                   )
+               $self->cds(new Bio::Location::Simple
+			  (-start   => $value[0]->start,
+			   -end     => $value[-1]->end,
+			   -strand  => $value[0]->strand,
+			   -seq_id  => $value[0]->seq_id,
+			   -verbose => $self->verbose,
+			   )
                          );
            }
 
@@ -548,8 +547,7 @@ sub exons {
 
 	   $self->in('chr');
 	   $self->out('gene');
-
-	   @exons = map {$self->map($_)} @value;
+	   @exons = map {$self->map($_) } @value;
 
 	   $self->{'_in'} = ($tmp_in);
 	   $self->{'_out'} = ($tmp_out);
@@ -571,7 +569,6 @@ sub exons {
        my $prev_exon_end;
 
        for my $exon ( @exons ) {
-
 	   $exon_counter++;
 
 	   #
@@ -580,13 +577,17 @@ sub exons {
 
 	   my $match1 = Bio::Location::Simple->new
 	       (-seq_id =>'gene' ,
-		-start => $exon->start,
-		-end => $exon->end, -strand=>1 );
+		-start  => $exon->start,
+		-end    => $exon->end, 
+		-strand => 1,
+		-verbose=> $self->verbose);
+
 	   my $match2 = Bio::Location::Simple->new
 	       (-seq_id => 'cds',
 		-start => $tr_end + 1,
 		-end => $tr_end + $exon->end - $exon->start +1,
-		-strand=>$exon->strand );
+		-strand=>$exon->strand,
+		-verbose=>$self->verbose);
 
 	   $cds_map->add_mapper(Bio::Coordinate::Pair->new
                                 (-in => $match1,
@@ -605,22 +606,26 @@ sub exons {
 
 	   if (defined $prev_exon_end) {
 	       my $match3 = Bio::Location::Simple->new
-		   (-seq_id =>'gene',
-		    -start => $prev_exon_end + 1,
-		    -end => $exon->start -1, -strand=>$exon->strand );
+		   (-seq_id  => 'gene',
+		    -start   => $prev_exon_end + 1,
+		    -end     => $exon->start -1, 
+		    -strand  => $exon->strand,
+		    -verbose => $self->verbose);
 
 	       my $match4 = Bio::Location::Simple->new
-		   (-seq_id => 'intron'. ($exon_counter -1),
-		    -start => 1,
-		    -end => $exon->start - 1 - $prev_exon_end,
-		    -strand=>$exon->strand );
+		   (-seq_id  => 'intron'. ($exon_counter -1),
+		    -start   => 1,
+		    -end     => $exon->start - 1 - $prev_exon_end,
+		    -strand  =>$exon->strand,
+		    -verbose => $self->verbose,);
 
 	       # negative intron coordinates
 	       my $match5 = Bio::Location::Simple->new
-		   (-seq_id => 'intron'. ($exon_counter -1),
-		    -start => -1 * ($exon->start - 2 - $prev_exon_end) -1,
-		    -end => -1,
-		    -strand=>$exon->strand );
+		   (-seq_id  => 'intron'. ($exon_counter -1),
+		    -start   => -1 * ($exon->start - 2 - $prev_exon_end) -1,
+		    -end     => -1,
+		    -strand  => $exon->strand,
+		    -verbose => $self->verbose);
 
 	       $inex_map->add_mapper(Bio::Coordinate::Pair->new
                                      (-in => $match3,
@@ -647,9 +652,10 @@ sub exons {
 	   #
 	   my $match6 = Bio::Location::Simple->new
 	       (-seq_id => 'exon'. $exon_counter,
-		-start => 1,
-		-end => $exon->end - $exon->start +1,
-		-strand=> $exon->strand );
+		-start  => 1,
+		-end    => $exon->end - $exon->start +1,
+		-strand => $exon->strand,
+		-verbose=> $self->verbose,);
 
 	   my $pair2 = Bio::Coordinate::Pair->new(-in => $self->_clone_loc($match1),
 						  -out => $match6
@@ -712,10 +718,11 @@ sub _clone_loc { # clone a simple location
        unless $loc->isa('Bio::Location::Simple');
 
    return  Bio::Location::Simple->new
-       (-seq_id => $loc->seq_id,
-        -start => $loc->start,
-        -end => $loc->end,
-        -strand=> $loc->strand,
+       (-verbose       => $self->verbose,
+	-seq_id        => $loc->seq_id,
+        -start         => $loc->start,
+        -end           => $loc->end,
+        -strand        => $loc->strand,
         -location_type => $loc->location_type
        );
 }
@@ -743,7 +750,8 @@ sub cds {
    my ($self,$value) = @_;
    if( defined $value) {
        if ($value =~ /^[+-]?\d+$/ ) {
-	   my $loc = Bio::Location::Simple->new(-start=>$value);
+	   my $loc = Bio::Location::Simple->new(-start=>$value,
+						-verbose=>$self->verbose);
 	   $self->{'_cds'} = $loc;
        }
        elsif (ref $value &&  $value->isa('Bio::RangeI') ) {
@@ -790,7 +798,6 @@ sub cds {
 sub map {
    my ($self,$value) = @_;
    my ($res);
-
    $self->throw("Need to pass me a Bio::Location::Simple or ".
                 "Bio::Location::Simple or Bio::SeqFeatureI, not [".
 		ref($value). "]")
@@ -808,10 +815,9 @@ sub map {
    $self->_check_direction();
 
    $value = $value->location if $value->isa('Bio::SeqFeatureI');
-   print STDERR "=== Start location: ". $value->start. ",".
-       $value->end. " (". $value->strand. ")\n" if $self->verbose > 0;
-
-
+   $self->debug( "=== Start location: ". $value->start. ",".
+		 $value->end. " (". ($value->strand || ''). ")\n");
+	       
    # if nozero coordinate system is used in the input values
    if ( defined $self->{'_nozero'} &&
 	( $self->{'_nozero'} == 1 || $self->{'_nozero'} == 3 ) ) {
@@ -822,19 +828,18 @@ sub map {
    }
 
    my @steps = $self->_get_path();
-   print "mapping ", $self->{'_in'}, "->", $self->{'_out'},
-       "  Mappers: ", join(", ", @steps), "\n"  if $self->verbose > 0;
-
+   $self->debug( "mapping ". $self->{'_in'}. "->". $self->{'_out'}.
+		 "  Mappers: ". join(", ", @steps). "\n");
+   
    foreach my $mapper (@steps) {
        if ($mapper eq $TRANSLATION) {
 	   if ($self->direction == 1) {
+
 	       $value = $self->_translate($value);
-	       print STDERR "+   $TRANSLATION cds -> propeptide (translate) \n"
-		   if $self->verbose > 0;
+	       $self->debug( "+   $TRANSLATION cds -> propeptide (translate) \n");
 	   } else {
 	       $value = $self->_reverse_translate($value);
-	       print STDERR "+   $TRANSLATION propeptide -> cds (reverse translate) \n"
-		   if $self->verbose > 0;
+	       $self->debug("+   $TRANSLATION propeptide -> cds (reverse translate) \n");
 	   }
        }
        # keep the start and end values, and go on to next iteration
@@ -843,17 +848,20 @@ sub map {
 	   # update mapper name
 	   $mapper =~ /\d+-(\d+)/;   my ($counter) = $1;
 	   $value->seq_id($COORDINATE_INTS{$counter});
-	   print STDERR "-   $mapper\n" if $self->verbose > 0;
+	   $self->debug( "-   $mapper\n");
        } else {
-
            #
 	   # the DEFAULT : generic mapping
            #
+	   
 	   $value = $self->{'_mappers'}->{$mapper}->map($value);
-           $value->purge_gaps
-              if ($value && $value->isa('Bio::Location::SplitLocationI') && $value->can('gap'));
-	   print STDERR "+  $mapper (", $self->direction, "):  start ",
-               $value->start, " end ", $value->end, "\n"
+           
+	   $value->purge_gaps
+	       if ($value && $value->isa('Bio::Location::SplitLocationI') && 
+		   $value->can('gap'));
+	   
+	   $self->debug( "+  $mapper (". $self->direction. "):  start ".
+			 $value->start. " end ". $value->end. "\n")
 	       if $value && $self->verbose > 0;
        }
    }
@@ -881,7 +889,8 @@ sub map {
                push @matches, $prevloc;
                next;
            }
-           if ($prevloc->end == ($loc->start - 1) && $prevloc->seq_id eq $loc->seq_id) {
+           if ($prevloc->end == ($loc->start - 1) && 
+	       $prevloc->seq_id eq $loc->seq_id) {
                $prevloc->end($loc->end);
                $merging = 1;
            } else {
@@ -895,19 +904,20 @@ sub map {
                map {$newvalue->add_sub_Location} @matches;
            } else {
                $newvalue = Bio::Coordinate::Result::Match->new
-                   (-seq_id => $matches[0]->seq_id,
-                    -start => $matches[0]->start,
-                    -end => $matches[0]->end,
-                    -strand=> $matches[0]->strand );
+                   (-seq_id   => $matches[0]->seq_id,
+                    -start    => $matches[0]->start,
+                    -end      => $matches[0]->end,
+                    -strand   => $matches[0]->strand,
+		    -verbose  => $self->verbose,);
            }
            $value = $newvalue;
        }
    } 
-   elsif (ref $value eq "Bio::Coordinate::Result" && $value->each_match == 1 ){
+   elsif (ref $value eq "Bio::Coordinate::Result" && 
+	  $value->each_match == 1 ){
        $value = $value->match;
    }
 
-
    return $value;
 }
 
@@ -1093,19 +1103,24 @@ sub _create_pair {
    $length ||= 20;
 
    my $match1 = Bio::Location::Simple->new
-       (-seq_id => $in,
-	-start => $offset+1,
-	-end => $offset+$length, -strand=>1 );
+       (-seq_id  => $in,
+	-start   => $offset+1,
+	-end     => $offset+$length, 
+	-strand  => 1,
+	-verbose => $self->verbose);
 
    my $match2 = Bio::Location::Simple->new
-       (-seq_id => $out,
-	-start => 1,
-	-end => $length, -strand=>$strand );
+       (-seq_id  => $out,
+	-start   => 1,
+	-end     => $length, 
+	-strand  => $strand,
+	-verbose => $self->verbose);
 
    my $pair = Bio::Coordinate::ExtrapolatingPair->new
-       (-in => $match1,
-        -out => $match2,
-        -strict => $strict
+       (-in      => $match1,
+        -out     => $match2,
+        -strict  => $strict,
+	-verbose => $self->verbose,
        );
 
    return $pair;
@@ -1134,25 +1149,27 @@ sub _translate {
            ($value->isa('Bio::Location::Simple') || $value->isa('Bio::Location::SplitLocationI'));
 
    my $seqid = 'propeptide';
-
-   if ($value->isa("Bio::Location::SplitLocationI")) {
+   
+   if ($value->isa("Bio::Location::SplitLocationI") ) {
        my $split = new Bio::Location::Split(-seq_id=>$seqid);
        foreach my $loc ( $value->each_Location(1) ) {
-
-           my $match = new Bio::Location::Simple(-start => int($loc->start / 3 )+1,
-                                                 -end => int($loc->end / 3 )+1,
-                                                 -seq_id => $seqid,
-                                                 -strand => 1
-                                                );
+           my $match = new Bio::Location::Simple
+	       (-start   => int ($loc->start / 3 ) +1,
+		-end     => int ($loc->end / 3 ) +1,
+		-seq_id  => $seqid,
+		-strand  => 1,
+		-verbose => $self->verbose,
+		);
            $split->add_sub_Location($match);
        }
        return $split;
 
    } else {
-       return new Bio::Location::Simple(-start => int($value->start / 3 )+1,
-                                        -end => int($value->end / 3 )+1,
+       return new Bio::Location::Simple(-start  => int($value->start / 3 )+1,
+                                        -end    => int($value->end / 3 )+1,
                                         -seq_id => $seqid,
-                                        -strand => 1
+                                        -strand => 1,
+					-verbose=> $self->verbose,
                                        );
    }
 }
@@ -1171,20 +1188,22 @@ sub _frame {
        my $split = new Bio::Location::Split(-seq_id=>$seqid);
        foreach my $loc ( $value->each_Location(1) ) {
 
-           my $match = new Bio::Location::Simple(-start => ($value->start-1) % 3 +1,
-                                                 -end => ($value->end-1) % 3 +1,
-                                                 -seq_id => 'frame',
-                                                 -strand => 1
-                                       );
+           my $match = new Bio::Location::Simple
+	       (-start  => ($value->start-1) % 3 +1,
+		-end    => ($value->end-1) % 3 +1,
+		-seq_id => 'frame',
+		-strand => 1,
+		-verbose=> $self->verbose);
            $split->add_sub_Location($match);
        }
        return $split;
    } else {
-       return new Bio::Location::Simple(-start => ($value->start-1) % 3 +1,
-                                        -end => ($value->end-1) % 3 +1,
-                                        -seq_id => 'frame',
-                                        -strand => 1
-                                       );
+       return new Bio::Location::Simple(-start   => ($value->start-1) % 3 +1,
+                                        -end     => ($value->end-1) % 3 +1,
+                                        -seq_id  => 'frame',
+                                        -strand  => 1,
+					-verbose => $self->verbose,
+					);
    }
 }
 
@@ -1218,20 +1237,23 @@ sub _reverse_translate {
        my $split = new Bio::Location::Split(-seq_id=>$seqid);
        foreach my $loc ( $value->each_Location(1) ) {
 
-           my $match = new Bio::Location::Simple(-start => $value->start * 3 - 2,
-                                               -end => $value->end * 3,
-                                               -seq_id => $seqid,
-                                               -strand => 1
-                                              );
+           my $match = new Bio::Location::Simple
+	       (-start   => $value->start * 3 - 2,
+		-end     => $value->end * 3,
+		-seq_id  => $seqid,
+		-strand  => 1,
+		-verbose => $self->verbose,
+		);
            $split->add_sub_Location($match);
        }
        return $split;
 
    } else {
-       return new Bio::Location::Simple(-start => $value->start * 3 - 2,
-                                        -end => $value->end * 3,
-                                        -seq_id => $seqid,
-                                        -strand => 1
+       return new Bio::Location::Simple(-start   => $value->start * 3 - 2,
+                                        -end     => $value->end * 3,
+                                        -seq_id  => $seqid,
+                                        -strand  => 1,
+					-verbose => $self->verbose,
                                        );
    }
 }
