@@ -1,4 +1,4 @@
-# $Id$
+# $Id: BioFetch.pm,v 1.29.4.1 2006/10/02 23:10:14 sendu Exp $
 #
 # BioPerl module for Bio::DB::BioFetch
 #
@@ -13,7 +13,6 @@
 
 package Bio::DB::BioFetch;
 use strict;
-use Bio::DB::WebDBSeqI;
 use HTTP::Request::Common 'POST';
 
 =head1 NAME
@@ -26,7 +25,7 @@ Bio::DB::BioFetch - Database object interface to BioFetch retrieval
 
  $bf = new Bio::DB::BioFetch;
 
- $seq = $sp->get_Seq_by_id('BUM');  # EMBL or SWALL ID
+ $seq = $bf->get_Seq_by_id('BUM');  # EMBL or SWALL ID
 
  # change formats, storage procedures
  $bf = new Bio::DB::BioFetch(-format        => 'fasta',
@@ -65,23 +64,22 @@ Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Lincoln Stein
 
 Email Lincoln Stein  E<lt>lstein@cshl.orgE<lt>
 
-Also thanks to Heikki Lehvaslaiho E<lt>heikki@ebi.ac.ukE<gt> for the
+Also thanks to Heikki Lehvaslaiho E<lt>heikki-at-bioperl-dot-orgE<gt> for the
 BioFetch server and interface specification.
 
 =head1 APPENDIX
@@ -92,52 +90,56 @@ methods. Internal methods are usually preceded with a _
 =cut
 
 # Let the code begin...
-use vars qw(@ISA $VERSION %FORMATMAP );
-use Bio::Root::Root;
-@ISA = qw(Bio::DB::WebDBSeqI Bio::Root::Root);
-$VERSION = '1.0';
+use vars qw(%FORMATMAP);
+use base qw(Bio::DB::WebDBSeqI Bio::Root::Root);
 
 # warning: names used here must map into Bio::SeqIO::* space
 use constant DEFAULT_LOCATION => 'http://www.ebi.ac.uk/cgi-bin/dbfetch';
 
 BEGIN {
-
-  %FORMATMAP = (
-		'embl' => {
-			   default => 'embl', # default BioFetch format/SeqIOmodule pair
-			   embl => 'embl',    # alternative BioFetch format/module pair 
-			   fasta => 'fasta',   # alternative BioFetch format/module pair 
-			   namespace => 'embl',
-			  },
-		'swissprot' => {
-				default => 'swiss',
-				swissprot => 'swiss',
-				fasta => 'fasta',
-				namespace => 'swall',
-			       },
-		'refseq' => {
-			     default => 'genbank',
-			     genbank => 'genbank',
-			     fasta => 'fasta',
-			     namespace => 'RefSeq',
-			    },
-		'swall' => {
-			    default => 'swiss',
-			    swissprot => 'swiss',
-			    fasta => 'fasta',
-			    namespace => 'swall',
-			   },
-		'genbank' => {
-			      default => 'genbank',
-			      genbank => 'genbank',
-			      namespace => 'genbank',
-			     },
-		'genpep' => {
-			     default => 'genbank',
-			     genbank => 'genbank',
-			     namespace => 'genpep',
-			    },
-	       );
+    
+    %FORMATMAP = (
+	'embl' => {
+	    default   => 'embl',  # default BioFetch format/SeqIOmodule pair
+	    embl      => 'embl',  # alternative BioFetch format/module pair 
+	    fasta     => 'fasta', # alternative BioFetch format/module pair 
+	    namespace => 'embl',
+	},
+	'swissprot' => {
+	    default   => 'swiss',
+	    swissprot => 'swiss',
+	    fasta     => 'fasta',
+	    namespace => 'uniprot',
+	},
+	'refseq' => {
+	    default   => 'genbank',
+	    genbank   => 'genbank',
+	    fasta     => 'fasta',
+	    namespace => 'RefSeq',
+	},
+	'swall' => {
+	    default   => 'swiss',
+	    swissprot => 'swiss',
+	    fasta     => 'fasta',
+	    namespace => 'uniprot',
+	},
+    'uniprot' => {
+	    default   => 'swiss',
+	    swissprot => 'swiss',
+	    fasta     => 'fasta',
+	    namespace => 'uniprot',
+	},
+	'genbank' => {
+	    default   => 'genbank',
+	    genbank   => 'genbank',
+	    namespace => 'genbank',
+	},
+	'genpep' => {
+	    default   => 'genbank',
+	    genbank   => 'genbank',
+	    namespace => 'genpep',
+	},
+    );
 }
 
 =head2 new
@@ -320,7 +322,7 @@ sub get_request {
     ($format, $tmp) = $self->request_format($format);
 
     my $base = $self->url_base_address;
-    my $uid = join('+', ref $uids ? @$uids : $uids);
+    my $uid = join('+',ref $uids ? @$uids : $uids);
     $self->debug("\n$base$format_string&id=$uid\n");
     return POST($base,
 		[ db     => $namespace,
@@ -506,7 +508,7 @@ sub _check_id {
     # Asking for a RefSeq from EMBL/GenBank
 
     if ($id =~ /N._/ &&  $self->db ne 'refseq') {
-	$self->warn("[$id] is not a normal sequence database but a RefSeq entry.".
+	$self->warn("[$id] is not a normal sequence entry but a RefSeq entry.".
 		   " Redirecting the request.\n")
 	    if $self->verbose >= 0;
 	$self->db('RefSeq');
