@@ -1,3 +1,5 @@
+# $Id: FileCache.pm,v 1.11.4.2 2006/10/02 23:10:14 sendu Exp $
+#
 # POD documentation - main docs before the code
 #
 #
@@ -39,16 +41,15 @@ This module requires DB_File and Storable.
 
 =head1 CONTACT
 
-Lincoln Stein
+Lincoln Stein E<lt>lstein@cshl.orgE<gt>
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-    bioperl-bugs@bio.perl.org
-    http://bio.perl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 APPENDIX
 
@@ -66,19 +67,18 @@ use Storable qw(freeze thaw);
 use Fcntl qw(O_CREAT O_RDWR O_RDONLY);
 use File::Temp 'tmpnam';
 
-use vars qw(@ISA);
 use strict;
 
-use Bio::Root::Root;
 
-@ISA = qw(Bio::Root::Root Bio::DB::SeqI);
+use base qw(Bio::Root::Root Bio::DB::SeqI);
 
-use Bio::DB::SeqI;
 use Bio::Seq::RichSeq;
 use Bio::Location::Split;
 use Bio::Location::Fuzzy;
 use Bio::Seq;
 use Bio::SeqFeature::Generic;
+use Bio::Species;
+use Bio::Annotation::Collection;
 
 =head2 new
 
@@ -100,15 +100,18 @@ can be retrieved using file_name().
 
 =cut
 
+#'
 sub new {
     my ($class,@args) = @_;
 
     my $self = Bio::Root::Root->new();
     bless $self,$class;
 
-    my ($seqdb,$file_name,$keep) = $self->_rearrange([qw(SEQDB FILE KEEP)],@args);
+    my ($seqdb,$file_name,$keep) = $self->_rearrange([qw(SEQDB FILE
+							 KEEP)],@args);
 
-    if( !defined $seqdb || !ref $seqdb || !$seqdb->isa('Bio::DB::RandomAccessI') ) {
+    if( !defined $seqdb || !ref $seqdb ||
+	! $seqdb->isa('Bio::DB::RandomAccessI') ) {
        $self->throw("Must be a randomaccess database not a [$seqdb]");
     }
 
@@ -141,7 +144,7 @@ sub get_Seq_by_id{
    return $obj if defined $obj;
 
    # get object from seqdb
-   my $obj = $self->seqdb->get_Seq_by_id($id);
+   $obj = $self->seqdb->get_Seq_by_id($id);
    $self->_store('id' => $id, $obj);
 
    return $obj;
@@ -167,7 +170,7 @@ sub get_Seq_by_acc{
    return $obj if defined $obj;
 
    # get object from seqdb
-   my $obj = $self->seqdb->get_Seq_by_acc($acc);
+   $obj = $self->seqdb->get_Seq_by_acc($acc);
    $self->_store('acc' => $acc, $obj);
 
    return $obj;
@@ -232,6 +235,7 @@ file, it probably isn't safe to change this value.
 
 =cut
 
+#'
 sub keep {
   my $self = shift;
   my $d = $self->{keep};
@@ -279,6 +283,11 @@ sub _get {
 sub _store {
   my $self = shift;
   my ($type,$id,$obj) = @_;
+  if( ! defined $obj ) {
+      # bug #1628
+      $self->debug("tried to store an undefined value for $id, skipping");
+      return;
+  }
   my $serialized = freeze($obj);
   $self->db->{"${type}_${id}"} = $serialized;
 }
