@@ -1,5 +1,5 @@
 #
-# $Id$
+# $Id: BDB.pm,v 1.17.4.1 2006/10/02 23:10:16 sendu Exp $
 #
 # BioPerl module for Bio::DB::Flat::BDB
 #
@@ -15,7 +15,9 @@ Bio::DB::Flat::BDB - Interface for BioHackathon standard BDB-indexed flat file
 
 =head1 SYNOPSIS
 
-You should not be using this module directly.  See Bio::DB::Flat.
+  #You should not be using this module directly.
+
+See L<Bio::DB::Flat>.
 
 =head1 DESCRIPTION
 
@@ -36,8 +38,8 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org             - General discussion
-  http://bioperl.org/MailList.shtml - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -45,7 +47,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via
 email or the web:
 
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Lincoln Stein
 
@@ -72,14 +74,12 @@ use DB_File;
 use IO::File;
 use Fcntl qw(O_CREAT O_RDWR O_RDONLY);
 use File::Spec;
-use Bio::DB::Flat;
 use Bio::SeqIO;
 use Bio::DB::RandomAccessI;
 use Bio::Root::Root;
 use Bio::Root::IO;
-use vars '@ISA';
 
-@ISA = qw(Bio::DB::Flat);
+use base qw(Bio::DB::Flat);
 
 sub _initialize {
   my $self = shift;
@@ -139,7 +139,7 @@ sub get_Seq_by_acc {
   $self->throw("more than one sequences correspond to this accession")
       if @primary_ids > 1 && ! wantarray;
   my @rc = map {$self->get_Seq_by_id($_)} @primary_ids;
- return wantarray ? @rc : $rc[0];
+  return wantarray ? @rc : $rc[0];
 }
 
 # fetch array of Bio::Seq objects
@@ -150,7 +150,8 @@ sub get_Seq_by_version {
   my @primary_ids = $self->expand_ids($ns => $key);
   $self->throw("more than one sequences correspond to this accession")
     if @primary_ids > 1 && !wantarray;
-  return map {$self->get_Seq_by_id($_)} @primary_ids;
+  my @rc = map {$self->get_Seq_by_id($_)} @primary_ids;
+  return wantarray ? @rc : $rc[0];
 }
 
 =head2 get_PrimarySeq_stream
