@@ -1,5 +1,5 @@
 #
-# $Id$
+# $Id: embl.pm,v 1.13.4.1 2006/10/02 23:10:16 sendu Exp $
 #
 # BioPerl module for Bio::DB::Flat::BDB
 #
@@ -31,17 +31,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org             - General discussion
-  http://bioperl.org/MailList.shtml - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via
-email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Lincoln Stein
 
@@ -56,20 +55,8 @@ L<Bio::DB::Flat>,
 package Bio::DB::Flat::BDB::embl;
 
 use strict;
-use Bio::DB::Flat::BDB;
-use vars '@ISA';
 
-@ISA = qw(Bio::DB::Flat::BDB);
-
-sub parse_one_record {
-  my $self  = shift;
-  my $fh    = shift;
-  my $parser =
-    $self->{embl_cached_parsers}{fileno($fh)} ||= Bio::SeqIO->new(-fh=>$fh,-format=>$self->default_file_format);
-  my $seq = $parser->next_seq;
-  my $ids = $self->seq_to_ids($seq);
-  return $ids;
-}
+use base qw(Bio::DB::Flat::BDB);
 
 sub seq_to_ids {
   my $self = shift;
@@ -77,9 +64,12 @@ sub seq_to_ids {
 
   my $display_id = $seq->display_id;
   my $accession  = $seq->accession_number;
+  my $version    = $seq->seq_version;
+
   my %ids;
   $ids{ID}       = $display_id;
-  $ids{ACC}      = $accession   if defined $accession;
+  $ids{ACC}      = $accession             if defined $accession;
+  $ids{VERSION}  = "$accession.$version"  if defined $accession && defined $version;
   return \%ids;
 }
 
@@ -88,7 +78,7 @@ sub default_primary_namespace {
 }
 
 sub default_secondary_namespaces {
-  return qw(ACC);
+  return qw(ACC VERSION);
 }
 
 sub default_file_format { "embl" }
