@@ -110,12 +110,9 @@ use strict;
 
 use Bio::DB::GFF::Feature;
 use Bio::DB::GFF::Util::Rearrange;
-use Bio::DB::GFF::Segment;
 use Bio::RangeI;
 
-use vars qw($VERSION @ISA);
-@ISA = qw(Bio::DB::GFF::Segment);
-$VERSION = '0.45';
+use base qw(Bio::DB::GFF::Segment);
 
 use overload '""' => 'asString',
              'bool' => sub { overload::StrVal(shift) },
@@ -194,7 +191,7 @@ be a sequence that has been specified as the "source" in the GFF file.
 #      -length     => length of segment
 #      -nocheck    => turn off checking, force segment to be constructed
 #      -absolute   => use absolute coordinate addressing
-#' 
+
 sub new {
   my $package = shift;
   my ($factory,$name,$start,$stop,$refseq,$class,$refclass,$offset,$length,$force_absolute,$nocheck) =
@@ -229,8 +226,9 @@ sub new {
     $class = $name->class;
     $name  = $name->name;
   }
+
   # if the class of the landmark is not specified then default to 'Sequence'
-  $class ||= 'Sequence';
+  $class ||= eval{$factory->default_class} || 'Sequence';
 
   # confirm that indicated sequence is actually in the database!
   my @abscoords;
@@ -260,6 +258,11 @@ sub new {
 
     $absstrand ||= '+';
 
+    if ($absstart > $absstop) { # AAARGH!  DATA FORMAT ERROR!  FIX.
+	($absstart,$absstop) = ($absstop,$absstart);
+	$absstrand = $absstrand eq '+' ? '-' : '+';
+    }
+
     # an explicit length overrides start and stop
     if (defined $offset) {
       warn "new(): bad idea to call new() with both a start and an offset"
@@ -378,6 +381,8 @@ sub abs_end {
   }
 }
 
+*abs_stop = \&abs_end;
+
 =head2 refseq
 
  Title   : refseq
@@ -588,6 +593,8 @@ The named parameter form gives you control over a few options:
 
   -attributes a hashref containing a set of attributes to match
 
+  -range_type One of 'overlapping', 'contains', or 'contained_in'
+
   -iterator  Whether to return an iterator across the features.
 
   -binsize   A true value will create a set of artificial features whose
@@ -626,46 +633,41 @@ sub features {
   return $self->factory->overlapping_features(@args);
 }
 
-=head2 top_SeqFeatures
+=head2 get_SeqFeatures
 
- Title   : top_SeqFeatures
+ Title   : get_SeqFeatures
  Usage   :
- Function:
- Example :
- Returns :
- Args    :
+ Function: returns the top level sequence features
+ Returns : L<Bio::SeqFeatureI> objects
+ Args    : none
 
-Alias for features().  Provided for Bio::SeqI compatibility.
+Segments do not ordinarily return any subfeatures.
 
 =cut
 
-=head2 all_SeqFeatures
+# A SEGMENT DOES NOT HAVE SUBFEATURES!
+sub get_SeqFeatures { return }
 
- Title   : all_SeqFeatures
- Usage   :
- Function:
- Example :
- Returns :
- Args    :
+=head2 feature_count
 
-Alias for features().  Provided for Bio::SeqI compatibility.
+ Title   : feature_count
+ Usage   : $seq->feature_count()
+ Function: Return the number of SeqFeatures attached to a sequence
+ Returns : integer representing the number of SeqFeatures
+ Args    : none
+
+This method comes through extension of Bio::FeatureHolderI. See
+L<Bio::FeatureHolderI> for more information.
 
 =cut
 
-=head2 sub_SeqFeatures
-
- Title   : sub_SeqFeatures
- Usage   :
- Function:
- Example :
- Returns :
- Args    :
-
-Alias for features().  Provided for Bio::SeqI compatibility.
-
-=cut
-
-*top_SeqFeatures = *all_SeqFeatures = \&features;
+sub feature_count { 
+    my $self = shift;
+    my $ct = 0;
+    my %type_counts = $self->types(-enumerate=>1);
+    map { $ct += $_ } values %type_counts;
+    $ct;
+}
 
 =head2 get_feature_stream
 
@@ -687,7 +689,7 @@ This is the same as features(), but returns a stream.  Use like this:
 
 sub get_feature_stream {
   my $self = shift;
-  my @args = $_[0] =~ /^-/ ? (@_,-iterator=>1) : (-types=>\@_,-iterator=>1);
+  my @args = defined($_[0]) && $_[0] =~ /^-/ ? (@_,-iterator=>1) : (-types=>\@_,-iterator=>1);
   $self->features(@args);
 }
 
@@ -776,6 +778,59 @@ sub contained_in {
   return $self->factory->contained_in(@args);
 }
 
+=head2 delete
+
+ Title   : delete
+ Usage   : $db->delete(@args)
+ Function: delete features
+ Returns : count of features deleted -- if available
+ Args    : numerous, see below
+ Status  : public
+
+This method deletes all features that overlap the specified region or
+are of a particular type.  If no arguments are provided and the -force
+argument is true, then deletes ALL features.
+
+Arguments:
+
+ -type,-types  Either a single scalar type to be deleted, or an
+               reference to an array of types.
+
+ -range_type   Control the range type of the deletion.  One of "overlaps" (default)
+               "contains" or "contained_in"
+
+Examples:
+
+  $segment->delete(-type=>['intron','repeat:repeatMasker']);  # remove all introns & repeats
+  $segment->delete(-type=>['intron','repeat:repeatMasker']
+		   -range_type => 'contains');                # remove all introns & repeats
+                                                              # strictly contained in segment
+
+IMPORTANT NOTE: This method only deletes features.  It does *NOT*
+delete the names of groups that contain the deleted features.  Group
+IDs will be reused if you later load a feature with the same group
+name as one that was previously deleted.
+
+NOTE ON FEATURE COUNTS: The DBI-based versions of this call return the
+result code from the SQL DELETE operation.  Some dbd drivers return the
+count of rows deleted, while others return 0E0.  Caveat emptor.
+
+=cut
+
+# return all features completely contained within this segment
+sub delete {
+  my $self = shift;
+  my ($type,$range_type) =
+    rearrange([[qw(TYPE TYPES)],'RANGE_TYPE'],@_);
+  my $types = $self->factory->parse_types($type);  # parse out list of types
+  $range_type ||= 'overlaps';
+  return $self->factory->_delete({
+                                  segments   => [$self],
+                                  types      => $types,
+                                  range_type => $range_type
+                                  });
+}
+
 =head2 _process_feature_args
 
  Title   : _process_feature_args
@@ -797,7 +852,7 @@ sub _process_feature_args {
   my ($ref,$class,$start,$stop,$strand,$whole)
     = @{$self}{qw(sourceseq class start stop strand whole)};
 
-  ($start,$stop) = ($stop,$start) if $strand eq '-';
+  ($start,$stop) = ($stop,$start) if defined $strand && $strand eq '-';
 
   my @args = (-ref=>$ref,-class=>$class);
 
@@ -954,10 +1009,10 @@ sub rel2abs {
 =head2 abs2rel
 
  Title   : abs2rel
- Usage   : @rel_coords = $s-abs2rel(@abs_coords)
+ Usage   : @rel_coords = $s->abs2rel(@abs_coords)
  Function: convert absolute coordinates into relative coordinates
  Returns : a list of relative coordinates
- Args    : a list of absolutee coordinates
+ Args    : a list of absolute coordinates
  Status  : Public
 
 This function takes a list of positions in absolute coordinates
@@ -993,7 +1048,10 @@ sub strand {
   if ($self->absolute) {
     return _to_strand($self->{strand});
   }
-  return $self->stop <=> $self->start;
+  my $start = $self->start;
+  my $stop  = $self->stop;
+  return 0 unless defined $start and defined $stop;
+  return $stop <=> $start;
 }
 
 sub _to_strand {
@@ -1026,11 +1084,13 @@ sub intersection {
     $low  = $_->abs_low   if !defined($low)  or $low  < $_->abs_low;
     $high = $_->abs_high  if !defined($high) or $high > $_->abs_high;
   }
+
   return unless $low < $high;
-  $self->new(-factory=> $self->factory,
-	     -seq    => $ref,
-	     -start  => $low,
-	     -stop   => $high);
+  return Bio::DB::GFF::RelSegment->new(-factory => $self->factory,
+				       -seq     => $ref,
+				       -start   => $low,
+				       -stop    => $high,
+				      );
 }
 
 sub overlaps {
@@ -1074,6 +1134,8 @@ sub union {
 	     -stop   => $high);
 }
 
+sub version { 0 }
+
 
 1;
 
