@@ -1,4 +1,4 @@
-# $Id$
+# $Id: FeatureI.pm,v 1.9 2006/07/04 22:23:15 mauricio Exp $
 # BioPerl module for Bio::Expression::FeatureI
 #
 # Copyright Allen Day <allenday@ucla.edu>, Stan Nelson <snelson@ucla.edu>
@@ -28,17 +28,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org            - General discussion
-  http://bioperl.org/MailList.shtml - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -55,9 +54,9 @@ methods. Internal methods are usually preceded with a _
 package Bio::Expression::FeatureI;
 
 use strict;
-use Bio::Root::Root;
+use Bio::Root::RootI;
 
-use base qw(Bio::Root::Root Bio::PrimarySeqI);
+use base qw(Bio::Root::RootI Bio::PrimarySeqI);
 use vars qw($DEBUG);
 
 =head2 quantitation()
