@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------
-# $Id$
+# $Id: HitFactoryI.pm,v 1.11.4.1 2006/10/02 23:10:18 sendu Exp $
 #
 # BioPerl module for Bio::Factory::HitFactoryI
 #
@@ -31,17 +31,16 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                - General discussion
-  http://bio.perl.org/MailList.html    - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR 
 
@@ -68,11 +67,10 @@ The rest of the documentation details each of the object methods.
 package Bio::Factory::HitFactoryI;
 
 use strict;
-use Bio::Root::RootI;
+use Bio::Factory::ObjectFactoryI;
 
-use vars qw(@ISA);
 
-@ISA = qw(Bio::Root::RootI); 
+use base qw(Bio::Root::RootI);
 
 =head2 create_hit
 
