@@ -1,4 +1,4 @@
-# $Id: SeqAnalysisParserFactory.pm,v 1.9 2002/12/01 00:05:20 jason Exp $
+# $Id: SeqAnalysisParserFactory.pm,v 1.15.4.1 2006/10/02 23:10:18 sendu Exp $
 #
 # BioPerl module for Bio::Factory::SeqAnalysisParserFactory
 #
@@ -13,8 +13,8 @@
 
 =head1 NAME
 
-Bio::Factory::SeqAnalysisParserFactory - class capable of
-              creating SeqAnalysisParserI compliant parsers
+Bio::Factory::SeqAnalysisParserFactory - class capable of creating
+SeqAnalysisParserI compliant parsers
 
 =head1 SYNOPSIS
 
@@ -22,7 +22,7 @@ Bio::Factory::SeqAnalysisParserFactory - class capable of
     $factory = Bio::Factory::SeqAnalysisParserFactory->new();
     # find out the methods it knows about
     print "registered methods: ",
-          join(', ', keys($factory->driver_table())), "\n";
+          join(', ', keys %{$factory->driver_table}), "\n";
     # obtain a parser object
     $parser = $factory->get_parser(-input=>$inputobj,
                                    -params=>[@params],
@@ -39,14 +39,16 @@ This is a factory class capable of instantiating SeqAnalysisParserI
 implementing parsers.
 
 The concept behind this class and the interface it implements
-(Bio::Factory::SeqAnalysisParserFactoryI) is a generic analysis result parsing
-in high-throughput automated sequence annotation pipelines. See
-Bio::SeqAnalysisParserI for more documentation of this concept.
+(Bio::Factory::SeqAnalysisParserFactoryI) is a generic analysis result
+parsing in high-throughput automated sequence annotation
+pipelines. See Bio::SeqAnalysisParserI for more documentation of this
+concept.
 
 You can always find out the methods an instance of this class knows
 about by the way given in the SYNOPSIS section. By default, and
 assuming that the documentation is up-to-date, this will comprise of
-genscan, mzef, estscan, blast, hmmer, gff, and sim4 (all case-insensitive).
+genscan, mzef, estscan, blast, hmmer, gff, and sim4 (all
+case-insensitive).
 
 =head1 FEEDBACK
 
@@ -57,17 +59,16 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                - General discussion
-  http://bio.perl.org/MailList.html    - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Hilmar Lapp, Jason Stajich
 
@@ -75,18 +76,16 @@ Email Hilmar Lapp E<lt>hlapp@gmx.netE<gt>, Jason Stajich E<lt>jason@bioperl.orgE
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
 package Bio::Factory::SeqAnalysisParserFactory;
 use strict;
 
-use Bio::Factory::SeqAnalysisParserFactoryI;
-use Bio::Factory::DriverFactory;
 
-use vars qw(@ISA);
-@ISA = qw(Bio::Factory::DriverFactory Bio::Factory::SeqAnalysisParserFactoryI);
+use base qw(Bio::Factory::DriverFactory Bio::Factory::SeqAnalysisParserFactoryI);
 
 BEGIN {
     Bio::Factory::DriverFactory->register_driver
@@ -137,10 +136,10 @@ sub get_parser {
     my ($self, @args) = @_;
     my $parser;
     my $module;
-    
+
     my ($input, $params, $method) =
 	$self->_rearrange([qw(INPUT PARAMS METHOD)], @args);
-    
+
     # retrieve module name for requested method
     $method = lc $method; # method is case-insensitive
     $module = $self->get_driver($method);
@@ -159,9 +158,53 @@ sub get_parser {
     # instantiate parser and return the result
     $parser = $module->new($inputmethod => $input, @$params);
     if(! $parser->isa('Bio::SeqAnalysisParserI')) {
-	$self->throw("Driver $module registered for method $method does not implement Bio::SeqAnalyisParserI. How come?");
+	$self->throw("Driver $module registered for method $method does not ".
+                     "implement Bio::SeqAnalyisParserI. How come?");
     }
     return $parser;
 }
 
+
+=head2 register_driver
+
+ Title   : register_driver
+ Usage   : $factory->register_driver("genscan", "Bio::Tools::Genscan");
+ Function: Registers a driver a factory class should be able to instantiate.
+
+           This method can be called both as an instance and as a
+           class method.
+
+ Returns : 
+ Args    : Key of the driver (string) and the module implementing the driver
+           (string).
+
+=cut
+
+=head2 driver_table
+
+ Title   : driver_table
+ Usage   : $table = $factory->driver_table();
+ Function: Returns a reference to the hash table storing associations of
+           methods with drivers.
+
+           You use this table to look up registered methods (keys) and
+           drivers (values).
+
+           In this implementation the table is class-specific and
+           therefore shared by all instances. You can override this in
+           a derived class, but note that this method can be called
+           both as an instance and a class method.
+
+           This will be the table used by the object internally. You
+           should definitely know what you're doing if you modify the
+           table's contents.  Modifications are shared by _all_
+           instances, those present and those yet to be created.
+
+ Returns : A reference to a hash table.
+ Args    : 
+
+
+=cut
+
+
 1;
