@@ -1,4 +1,4 @@
-# $Id$
+# $Id: SeqAnalysisParserFactoryI.pm,v 1.12.4.1 2006/10/02 23:10:18 sendu Exp $
 #
 # BioPerl module for Bio::Factory::SeqAnalysisParserFactoryI
 #
@@ -48,17 +48,16 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                - General discussion
-  http://bio.perl.org/MailList.html    - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Hilmar Lapp, Jason Stajich
 
@@ -74,11 +73,9 @@ methods. Internal methods are usually preceded with a _
 package Bio::Factory::SeqAnalysisParserFactoryI;
 use strict;
 
-use Bio::Root::RootI;
 use Carp;
 
-use vars qw(@ISA );
-@ISA = qw(Bio::Root::RootI); 
+use base qw(Bio::Root::RootI);
 
 =head2 get_parser
 
