@@ -1,6 +1,6 @@
 package Bio::Graphics::FeatureFile;
 
-# $Id: FeatureFile.pm,v 1.60 2004/11/18 03:11:32 scain Exp $
+# $Id: FeatureFile.pm,v 1.78.4.7 2006/12/02 18:35:32 lstein Exp $
 # This package parses and renders a simple tab-delimited format for features.
 # It is simpler than GFF, but still has a lot of expressive power.
 # See __END__ for the file format
@@ -117,10 +117,10 @@ belong to the same group named yk53c10.
 use strict;
 use Bio::Graphics::Feature;
 use Bio::DB::GFF::Util::Rearrange;
-use Carp;
-use Bio::DB::GFF;
+use Carp 'cluck','carp','croak';
+# use Bio::DB::GFF; # not needed - load later
 use IO::File;
-use Text::Shellwords;
+use Text::ParseWords 'shellwords';
 
 # default colors for unconfigured features
 my @COLORS = qw(cyan blue red yellow green wheat turquoise orange);
@@ -203,6 +203,7 @@ sub new {
 		   },$class;
   $self->{coordinate_mapper} = $args{-map_coords} 
     if exists $args{-map_coords} && ref($args{-map_coords}) eq 'CODE';
+
   $self->smart_features($args{-smart_features})       if exists $args{-smart_features};
   $self->{safe}              = $args{-safe}           if exists $args{-safe};
 
@@ -232,15 +233,34 @@ sub new {
 
 =over 4
 
-=item ($rendered,$panel) = $features-E<gt>render([$panel])
+=item ($rendered,$panel) = $features-E<gt>render([$panel, $position_to_insert, $options, $max_bump, $max_label, $selector])
 
 Render features in the data set onto the indicated
 Bio::Graphics::Panel.  If no panel is specified, creates one.
 
+All arguments are optional.
+
+$panel is a Bio::Graphics::Panel that has previously been created and
+configured.
+
+$position_to_insert indicates the position at which to start inserting
+new tracks. The last current track on the panel is assumed.
+
+$options is a scalar used to control automatic expansion of the
+tracks. 0=auto, 1=compact, 2=expanded, 3=expand and label,
+4=hyperexpand, 5=hyperexpand and label.
+
+$max_bump and $max_label indicate the maximum number of features
+before bumping and labeling are turned off.
+
+$selector is a code ref that can be used to filter which features to
+render. It receives a feature and should return true to include the
+feature and false to exclude it.
+
 In a scalar context returns the number of tracks rendered.  In a list
-context, returns a two-element list containing the number of features
-rendered and the panel.  Use this form if you want the panel created
-for you.
+context, returns a three-element list containing the number of
+features rendered, the created panel, and a list of all the track
+objects created.
 
 =back
 
@@ -251,12 +271,12 @@ for you.
 sub render {
   my $self = shift;
   my $panel = shift;
-  my ($position_to_insert,$options,$max_bump,$max_label) = @_;
+  my ($position_to_insert,$options,$max_bump,$max_label,$selector) = @_;
 
   $panel ||= $self->new_panel;
 
   # count up number of tracks inserted
-  my $tracks = 0;
+  my @tracks;
   my $color;
   my %types = map {$_=>1} $self->configured_types;
 
@@ -284,6 +304,8 @@ sub render {
   }
 
   for my $type (@configured_types,@unconfigured_types) {
+    next if defined $selector && !$selector->($self,$type);
+    next unless length $type > 0; # avoid empty ''
     my $f = $self->features($type);
     my @features = grep {$self->{visible}{$_} || $_->type eq 'group'} @$f;
     next unless @features;  # suppress tracks for features that don't appear
@@ -296,6 +318,7 @@ sub render {
     my @config = ( -glyph   => 'segments',         # really generic
 		   -bgcolor => $COLORS[$color++ % @COLORS],
 		   -label   => 1,
+		   -description => 1,
 		   -key     => $type,
 		   @auto_bump,
 		   @base_config,         # global
@@ -303,13 +326,12 @@ sub render {
 		   @override,
 		 );
     if (defined($position_to_insert)) {
-      $panel->insert_track($position_to_insert++,$features,@config);
+      push @tracks,$panel->insert_track($position_to_insert++,$features,@config);
     } else {
-      $panel->add_track($features,@config);
+      push @tracks,$panel->add_track($features,@config);
     }
-    $tracks++;
   }
-  return wantarray ? ($tracks,$panel) : $tracks;
+  return wantarray ? (scalar(@tracks),$panel,\@tracks) : scalar @tracks;
 }
 
 sub _stat {
@@ -356,8 +378,9 @@ sub smart_features {
 
 sub parse_argv {
   my $self = shift;
-
   $self->init_parse;
+
+  local $/ = "\n";
   while (<>) {
     chomp;
     $self->parse_line($_);
@@ -368,9 +391,11 @@ sub parse_argv {
 sub parse_file {
   my $self = shift;
   my $fh   = shift or return;
-  $self->_stat($fh);
 
+  $self->_stat($fh);
   $self->init_parse;
+
+  local $/ = "\n";
   while (<$fh>) {
     chomp;
     $self->parse_line($_) || last;
@@ -403,13 +428,16 @@ sub parse_line {
     return 1;
   }
 
-  # skip on blank lines and comments
-  return 1 if /^\s*[\#]/;
+  # remove comments (but rescue hex-code colors)
+  s/\s*\#.+$// unless /\s*\#[0-9A-Fa-f]{6}\b/;
+
+  # skip on blank lines
+  return 1 if /^\s*$/;
 
   # abort if we see a >FASTA line
   return 0 if /^>/;
 
-  if (/^\s+(.+)/ && $self->{current_tag}) { # continuation line
+  if (/^\s+(.+)/ && $self->{current_tag}) { # configuration continuation line
     my $value = $1;
     my $cc = $self->{current_config} ||= 'general';       # in case no configuration named
     $self->{config}{$cc}{$self->{current_tag}} .= ' ' . $value;
@@ -442,13 +470,14 @@ sub parse_line {
     return 1;
   }
 
+  undef $self->{current_tag};
+
   # parse data lines
   my @tokens = shellwords($_);
-  # my @tokens = split "\t",$_;  # faster?
   unshift @tokens,'' if /^\s+/;
 
   # close any open group
-  if (length $tokens[0] > 0 && $self->{group}) {
+  if ($self->{group} && $self->{grouptype} && $tokens[0] && length $tokens[0] > 0) {
     push @{$self->{features}{$self->{grouptype}}},$self->{group};
     undef $self->{group};
     undef $self->{grouptype};
@@ -467,8 +496,11 @@ sub parse_line {
 
   my @parts;
 
-  if (@tokens >= 8) { # conventional GFF file
+  # conventional GFF file, with check for numeric start/end
+  if (@tokens >= 8 && $tokens[3]=~ /^-?\d+$/ && $tokens[4]=~ /^-?\d+$/) {
+    require Bio::DB::GFF unless Bio::DB::GFF->can('split_group');
     my ($r,$source,$method,$start,$stop,$scor,$s,$phase,@rest) = @tokens;
+    # sanity checks
     my $group = join ' ',@rest;
     $type   = defined $source && $source ne '.' ? join(':',$method,$source) : $method;
     #$bounds = join '..',$start,$stop;
@@ -481,11 +513,11 @@ sub parse_line {
 	my ($key,$value) = @$_;
 	if ($value =~ m!^(http|ftp)://!) { 
 	  $url = $_ 
-	} elsif ($key=~/note/i) { 
-	  push @notes,$value;
+	} else {
+	  push @notes,"$key=$value";
 	}
       }
-      $description = join '; ',@notes if @notes;
+      $description = join '; ',map {_escape($_)} @notes if @notes;
       $score       = $scor if defined $scor && $scor ne '.';
     }
     $name ||= $self->{group}->display_id if $self->{group};
@@ -515,11 +547,12 @@ sub parse_line {
     if $bounds && !@parts;
 
   foreach (@parts) { # max and min calculation, sigh...
-    $self->{min} = $_->[0] if !defined $self->{min} || $_->[0] < $self->{min};
-    $self->{max} = $_->[1] if !defined $self->{max} || $_->[1] > $self->{max};
+    $self->{min} = $_->[0] if defined $_->[0] && defined $self->{min} ? ($_->[0] < $self->{min}) : 1;
+    $self->{max} = $_->[1] if defined $_->[1] && defined $self->{max} ? ($_->[1] > $self->{max}) : 1;
   }
 
   my $visible = 1;
+
   if ($self->{coordinate_mapper} && $ref) {
     my @remapped = $self->{coordinate_mapper}->($ref,@parts);
     ($ref,@parts) = @remapped if @remapped;
@@ -535,13 +568,15 @@ sub parse_line {
   # (this is to deal with confusing documentation, actually)
   unless (defined $strand) {
     foreach (@parts) {
-      $strand           ||= $_->[0] <= $_->[1] ? '+' : '-';
-      ($_->[0],$_->[1])   = ($_->[1],$_->[0]) if $_->[0] > $_->[1];
+      if (defined $_ && ref($_) eq 'ARRAY' && defined $_->[0] && defined $_->[1]) {
+        $strand           ||= $_->[0] <= $_->[1] ? '+' : '-';
+        ($_->[0],$_->[1])   = ($_->[1],$_->[0]) if $_->[0] > $_->[1];
+      }
     }
   }
 
   # attribute handling
-  if (defined $description && $description =~ /\w+=\w+/) { # attribute line
+  if (defined $description && $description =~ /\w+=\S+/) { # attribute line
     my @attributes = split /;\s*/,$description;
     foreach (@attributes) {
       my ($name,$value) = split /=/,$_,2;
@@ -601,6 +636,12 @@ sub _unescape {
   @_;
 }
 
+sub _escape {
+  my $toencode = shift;
+  $toencode =~ s/([^a-zA-Z0-9_.=-])/uc sprintf("%%%02x",ord($1))/eg;
+  $toencode;
+}
+
 sub _make_feature {
   my ($name,$type,$strand,$description,$ref,$attributes,$url,$score,$parts) = @_;
   my @coordinates = @$parts > 1 ? (-segments => $parts) : (-start=>$parts->[0][0],-end=>$parts->[0][1]);
@@ -754,13 +795,10 @@ sub _setting {
   my $self = shift;
   my $config = $self->{config} or return;
   return keys %{$config} unless @_;
-  return keys %{$config->{$_[0]}} if @_ == 1;
-
-  # this seems reasonable, but it prevents deliberate assignment of
-  # undef to settings
-  # return $config->{$_[0]}{$_[1]}  if @_ > 1 && exists $config->{$_[0]};
-
-  return $config->{$_[0]}{$_[1]}  if @_ > 1;
+  return keys %{$config->{$_[0]}}        if @_ == 1;
+  return $config->{$_[0]}{$_[1]}         if @_ == 2 && exists $config->{$_[0]};
+  return $config->{$_[0]}{$_[1]} = $_[2] if @_ > 2;
+  return;
 }
 
 
@@ -790,13 +828,14 @@ sub code_setting {
     my $package         = $self->base2package;
     my $codestring      = "\\&${package}\:\:${subroutine_name}";
     my $coderef         = eval $codestring;
-    warn $@ if $@;
+    $self->_callback_complain($section,$option) if $@;
     $self->set($section,$option,$coderef);
     return $coderef;
   }
   elsif ($setting =~ /^sub\s*(\(\$\$\))*\s*\{/) {
-    my $coderef   = eval $setting;
-    warn $@ if $@;
+    my $package         = $self->base2package;
+    my $coderef         = eval "package $package; $setting";
+    $self->_callback_complain($section,$option) if $@;
     $self->set($section,$option,$coderef);
     return $coderef;
   } else {
@@ -804,6 +843,12 @@ sub code_setting {
   }
 }
 
+sub _callback_complain {
+  my $self    = shift;
+  my ($section,$option) = @_;
+  carp "An error occurred while evaluating the callback at section='$section', option='$option':\n   => $@";
+}
+
 =over 4
 
 =item $flag = $features-E<gt>safe([$flag]);
@@ -1092,6 +1137,9 @@ Each row of the returned array is a arrayref containing the following fields:
 sub search_notes {
   my $self = shift;
   my ($search_string,$limit) = @_;
+
+  $search_string =~ tr/*?//d;
+
   my @results;
   my $search = join '|',map {quotemeta($_)} $search_string =~ /(\S+)/g;
 
@@ -1205,7 +1253,7 @@ sub initialize_code {
   my $init_code = $self->_setting(general => 'init_code') or return;
   my $code = "package $package; $init_code; 1;";
   eval $code;
-  warn $@ if $@;
+  $self->_callback_complain(general=>'init_code') if $@;
 }
 
 sub base2package {
@@ -1217,7 +1265,8 @@ sub base2package {
 
 sub split_group {
   my $self = shift;
-  return Bio::DB::GFF->split_group(shift, $self->{gff_version} > 2);
+  my $gff = $self->{gff} ||= Bio::DB::GFF->new(-adaptor=>'memory');
+  return $gff->split_group(shift, $self->{gff_version} > 2);
 }
 
 # create a panel if needed
@@ -1246,7 +1295,8 @@ sub new_panel {
   my $new_segment = Bio::Graphics::Feature->new(-start=>$start,-stop=>$stop);
   my $panel = Bio::Graphics::Panel->new(-segment   => $new_segment,
 					-width     => $width,
-					-key_style => 'between');
+					-key_style => 'between',
+					$self->style('general'));
   $panel;
 }
 
@@ -1293,7 +1343,7 @@ interface) or its primary_tag() method otherwise.
 sub feature2label {
   my $self = shift;
   my $feature = shift;
-  my $type  = eval {$feature->type} || $feature->primary_tag or return;
+  my $type  = $feature->primary_tag or return;
   (my $basetype = $type) =~ s/:.+$//;
   my @labels = $self->type2label($type);
   @labels = $self->type2label($basetype) unless @labels;
@@ -1321,12 +1371,13 @@ sub link_pattern {
 
   if (ref($linkrule) && ref($linkrule) eq 'CODE') {
     my $val = eval {$linkrule->($feature,$panel)};
-    warn $@ if $@;
+    $self->_callback_complain(none=>"linkrule for $feature") if $@;
     return $val;
   }
 
   require CGI unless defined &CGI::escape;
   my $n;
+  $linkrule ||= ''; # prevent uninit warning
   $linkrule =~ s/\$(\w+)/
     CGI::escape(
     $1 eq 'ref'              ? (($n = $feature->location->seq_id) && "$n") || ''
@@ -1362,7 +1413,15 @@ sub make_link {
 sub make_title {
   my $self = shift;
   my $feature = shift;
-  my $method  = $feature->method;
+
+  for my $label ($self->feature2label($feature)) {
+    my $linkrule     = $self->setting($label,'title');
+    $linkrule        ||= $self->setting(general=>'title');
+    next unless $linkrule;
+    return $self->link_pattern($linkrule,$feature);
+  }
+
+  my $method  = eval {$feature->method} || $feature->primary_tag;
   my $seqid   = $feature->can('seq_id')      ? $feature->seq_id : $feature->location->seq_id;
   my $title = eval {
     if ($feature->can('target') && (my $target = $feature->target)) {
