@@ -2,8 +2,7 @@ package Bio::Graphics::Glyph::line;
 # an arrow without the arrowheads
 
 use strict;
-use vars '@ISA';
-@ISA = 'Bio::Graphics::Glyph::generic';
+use base qw(Bio::Graphics::Glyph::generic);
 
 sub bottom {
   my $self = shift;
@@ -13,7 +12,7 @@ sub bottom {
   $val;
 }
 
-sub draw {
+sub draw_component {
   my $self = shift;
   my $gd = shift;
   my ($x1,$y1,$x2,$y2) = $self->calculate_boundaries(@_);
@@ -78,6 +77,8 @@ L<Bio::Graphics::Glyph> for a full explanation.
   -strand_arrow Whether to indicate            0 (false)
                  strandedness
 
+  -hilite       Highlight color                undef (no color)
+
 =head1 BUGS
 
 Please report them.
