@@ -1,10 +1,8 @@
 package Bio::Graphics::Glyph::redgreen_segment;
-#$Id$
+#$Id: redgreen_segment.pm,v 1.3.10.1 2006/10/02 23:10:20 sendu Exp $
 
 use strict;
-use Bio::Graphics::Glyph::graded_segments;
-use vars '@ISA';
-@ISA = 'Bio::Graphics::Glyph::graded_segments';
+use base qw(Bio::Graphics::Glyph::graded_segments);
 
 sub calculate_color {
   my $self = shift;
