@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Prim_Transcript.pm,v 1.9.4.1 2006/10/02 23:10:21 sendu Exp $
 #
 # bioperl module for Bio::LiveSeq::Prim_Transcript
 #
@@ -28,12 +28,6 @@ The strand could be 1 (forward strand, default), -1 (reverse strand).
 
 Email:  Insana@ebi.ac.uk, jinsana@gmx.net
 
-Address: 
-
-     EMBL Outstation, European Bioinformatics Institute
-     Wellcome Trust Genome Campus, Hinxton
-     Cambs. CB10 1SD, United Kingdom 
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object
@@ -44,15 +38,9 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::LiveSeq::Prim_Transcript;
-$VERSION=1.0;
-
-# Version history:
-# Tue Apr  4 18:11:31 BST 2000 v 1.0 created
 
 use strict;
-use vars qw($VERSION @ISA);
-use Bio::LiveSeq::Range 1.2; # uses Range, inherits from it
-@ISA=qw(Bio::LiveSeq::Range);
+use base qw(Bio::LiveSeq::Range);
 
 =head2 new
 
