@@ -1,4 +1,4 @@
-# $Id$
+# $Id: AvWithinCoordPolicy.pm,v 1.8.4.1 2006/10/02 23:10:21 sendu Exp $
 #
 # BioPerl module for Bio::Location::AvWithinCoordPolicy
 #
@@ -38,21 +38,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org             - General discussion
-  http://bio.perl.org/MailList.html - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Hilmar Lapp, Jason Stajich
 
-Email E<lt>hlapp@gmx.netE<gt>, E<lt>jason@bioperl.orgE<gt>
+Email E<lt>hlapp-at-gmx-dot-netE<gt>, E<lt>jason-at-bioperl-dot-orgE<gt>
 
 =head1 APPENDIX
 
@@ -65,12 +64,10 @@ methods. Internal methods are usually preceded with a _
 
 
 package Bio::Location::AvWithinCoordPolicy;
-use vars qw(@ISA);
 use strict;
 
-use Bio::Location::WidestCoordPolicy;
 
-@ISA = qw(Bio::Location::WidestCoordPolicy);
+use base qw(Bio::Location::WidestCoordPolicy);
 
 sub new { 
     my ($class, @args) = @_;
