@@ -1,4 +1,4 @@
-# $Id$
+# $Id: FuzzyLocationI.pm,v 1.21.4.1 2006/10/02 23:10:21 sendu Exp $
 #
 # BioPerl module for Bio::Location::FuzzyLocationI
 # Cared for by Jason Stajich <jason@bioperl.org>
@@ -36,21 +36,19 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org             - General discussion
-  http://bio.perl.org/MailList.html - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Jason Stajich
 
-Email jason@bioperl.org
+Email jason-at-bioperl-dot-org
 
 =head1 APPENDIX
 
@@ -63,13 +61,9 @@ methods. Internal methods are usually preceded with a _
 
 
 package Bio::Location::FuzzyLocationI;
-use vars qw(@ISA);
 use strict;
 
-use Bio::LocationI;
-use Carp;
-
-@ISA = qw(Bio::LocationI);
+use base qw(Bio::LocationI);
 
 =head1 LocationI methods
 
@@ -78,7 +72,7 @@ use Carp;
   Title   : loc_type
   Usage   : my $location_type = $location->location_type();
   Function: Get location type encoded as text
-  Returns : string ('EXACT', 'WITHIN', 'BETWEEN')
+  Returns : string ('EXACT', 'WITHIN', 'IN-BETWEEN')
   Args    : none
 
 =cut
