@@ -1,4 +1,4 @@
-# $Id$
+# $Id: RelationshipType.pm,v 1.17.4.1 2006/10/02 23:10:22 sendu Exp $
 #
 # BioPerl module for Bio::Ontology::RelationshipType  
 #
@@ -22,7 +22,7 @@
 
 =head1 NAME
 
-RelationshipType - a relationship type for an ontology
+Bio::Ontology::RelationshipType  - a relationship type for an ontology
 
 =head1 SYNOPSIS
 
@@ -31,7 +31,7 @@ RelationshipType - a relationship type for an ontology
 =head1 DESCRIPTION
 
 This class can be used to model various types of relationships
-(such as "IS_A", "PART_OF", "CONTAINS", "FOUND_IN").
+(such as "IS_A", "PART_OF", "CONTAINS", "FOUND_IN", "RELATED_TO").
 
 This class extends L<Bio::Ontology::Term>, so it essentially is-a
 L<Bio::Ontology::TermI>. In addition, all methods are overridden such
@@ -45,17 +45,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the 
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
-report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution.  Bug reports can be submitted via
+the web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -82,18 +81,17 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Ontology::RelationshipType;
-use vars qw( @ISA );
 use strict;
-use Bio::Ontology::Term;
 
 
-use constant PART_OF  => "PART_OF";
-use constant IS_A     => "IS_A";
-use constant CONTAINS => "CONTAINS";
-use constant FOUND_IN => "FOUND_IN";
+use constant PART_OF    => "PART_OF";
+use constant RELATED_TO => "RELATED_TO";
+use constant IS_A       => "IS_A";
+use constant CONTAINS   => "CONTAINS";
+use constant FOUND_IN   => "FOUND_IN";
 
 
-@ISA = qw( Bio::Ontology::Term );
+use base qw(Bio::Ontology::Term);
 
 
 #
@@ -105,13 +103,15 @@ my %term_name_map = ();
 =head2 get_instance
 
  Title   : get_instance
- Usage   : $IS_A     = Bio::Ontology::RelationshipType->get_instance( "IS_A" );
-           $PART_OF  = Bio::Ontology::RelationshipType->get_instance( "PART_OF" );
-           $CONTAINS = Bio::Ontology::RelationshipType->get_instance( "CONTAINS" );
-           $FOUND_IN = Bio::Ontology::RelationshipType->get_instance( "FOUND_IN" );
+ Usage   : $IS_A       = Bio::Ontology::RelationshipType->get_instance( "IS_A" );
+           $PART_OF    = Bio::Ontology::RelationshipType->get_instance( "PART_OF" );
+           $RELATED_TO = Bio::Ontology::RelationshipType->get_instance( "RELATED_TO" );
+           $CONTAINS   = Bio::Ontology::RelationshipType->get_instance( "CONTAINS" );
+           $FOUND_IN   = Bio::Ontology::RelationshipType->get_instance( "FOUND_IN" );
  Function: Factory method to create instances of RelationshipType
  Returns : [Bio::Ontology::RelationshipType]
- Args    : "IS_A" or "PART_OF" or "CONTAINS" or "FOUND_IN" [scalar]
+ Args    : "IS_A" or "PART_OF" or "CONTAINS" or "FOUND_IN" or 
+           "RELATED_TO" [scalar]
            the ontology [Bio::Ontology::OntologyI] (optional)
 
 =cut
@@ -133,12 +133,16 @@ sub get_instance {
 	return $reltype;
     }
     # valid relationship type?
-    if ( ! (($name eq IS_A) || ($name eq PART_OF) ||
-	    ($name eq CONTAINS) || ( $name eq FOUND_IN ))) {
-        my $msg = "Found unknown type of relationship: [" . $name . "]\n";
-        $msg .= "Known types are: [" . IS_A . "], [" . PART_OF . "], [" . CONTAINS . "], [" . FOUND_IN . "]";
-        $class->throw( $msg );
-    }
+
+#
+#see the cell ontology.  this code is too strict, even for dag-edit files. -allen
+#
+#    if ( ! (($name eq IS_A) || ($name eq PART_OF) ||
+#	    ($name eq CONTAINS) || ( $name eq FOUND_IN ))) {
+#        my $msg = "Found unknown type of relationship: [" . $name . "]\n";
+#        $msg .= "Known types are: [" . IS_A . "], [" . PART_OF . "], [" . CONTAINS . "], [" . FOUND_IN . "]";
+#        $class->throw( $msg );
+#    }
     # if we get here we need to create the rel.type
     $reltype = $class->new(-name     => $name,
 			   -ontology => $ont);
@@ -358,9 +362,6 @@ sub is_obsolete {
 } # is_obsolete
 
 
-
-
-
 =head2 comment
 
  Title   : comment
@@ -384,10 +385,10 @@ sub comment {
     return $ret;
 } # comment
 
-=head1
+=head1 Private methods 
 
-Private methods. May be overridden in a derived class, but should
-never be called from outside.
+May be overridden in a derived class, but should never be called from
+outside.
 
 =cut
 
@@ -422,7 +423,6 @@ sub _check_class {
            Optionally, the old value and the new value for reporting
            purposes only.
 
-
 =cut
 
 sub veto_change{
