@@ -1,4 +1,4 @@
-# $Id$
+# $Id: goflat.pm,v 1.7.4.1 2006/10/02 23:10:22 sendu Exp $
 #
 # BioPerl module for Bio::OntologyIO::goflat
 #
@@ -22,7 +22,7 @@
 
 =head1 NAME
 
-goflat - a parser for the Gene Ontology flat-file format
+Bio::OntologyIO::goflat - a parser for the Gene Ontology flat-file format
 
 =head1 SYNOPSIS
 
@@ -31,7 +31,7 @@ goflat - a parser for the Gene Ontology flat-file format
   # do not use directly -- use via Bio::OntologyIO
   my $parser = Bio::OntologyIO->new
 	( -format       => "go",
-          -defs_file    => "/home/czmasek/GO/GO.defs",
+     -defs_file    => "/home/czmasek/GO/GO.defs",
 	  -files        => ["/home/czmasek/GO/component.ontology",
 	                    "/home/czmasek/GO/function.ontology",
 	                    "/home/czmasek/GO/process.ontology"] );
@@ -55,17 +55,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the 
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
-report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -98,17 +97,15 @@ methods. Internal methods are usually preceded with a _
 
 package  Bio::OntologyIO::goflat;
 
-use vars qw( @ISA );
 use strict;
 
 use Bio::Ontology::TermFactory;
-use Bio::OntologyIO::dagflat;
 
 use constant TRUE         => 1;
 use constant FALSE        => 0;
 
 
-@ISA = qw( Bio::OntologyIO::dagflat );
+use base qw(Bio::OntologyIO::dagflat);
 
 
 =head2 new
@@ -121,7 +118,7 @@ use constant FALSE        => 0;
                                         "/path/to/function.ontology",
                                         "/path/to/process.ontology"] );
  Function: Creates a new goflat parser.
- Returns : A new goflat parser object, implementing L<Bio::OntologyIO>.
+ Returns : A new goflat parser object, implementing Bio::OntologyIO.
  Args    : -defs_file  => the name of the file holding the term
                           definitions
            -files      => a single ontology flat file holding the
@@ -133,7 +130,7 @@ use constant FALSE        => 0;
                           also be specified via the -file parameter
            -ontology_name => the name of the ontology; if not specified the
                           parser will auto-discover it by using the term
-                          that starts with a '$', and converting underscores
+                          that starts with a $, and converting underscores
                           to spaces
            -engine     => the Bio::Ontology::OntologyEngineI object
                           to be reused (will be created otherwise); note
@@ -141,6 +138,8 @@ use constant FALSE        => 0;
                           qualify as well since that one inherits from the
                           former.
 
+See L<Bio::OntologyIO>.
+
 =cut
 
 # in reality, we let OntologyIO::new do the instantiation, and override
