@@ -1,4 +1,4 @@
-# $Id$
+# $Id: OMIMparser.pm,v 1.20.4.1 2006/10/02 23:10:22 sendu Exp $
 #
 # BioPerl module for Bio::Phenotype::OMIM::OMIMparser
 #
@@ -22,7 +22,7 @@
 
 =head1 NAME
 
-OMIMparser - parser for the OMIM database
+Bio::Phenotype::OMIM::OMIMparser - parser for the OMIM database
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ OMIMparser - parser for the OMIM database
     my $cont  = $omim_entry->contributors();                   # *FIELD* CN
     my $ed    = $omim_entry->edited();                         # *FIELD* ED
     my $sa    = $omim_entry->additional_references();          # *FIELD* SA
-    my $cs    = $omim_entry->clinical_symptoms();              # *FIELD* CS
+    my $cs    = $omim_entry->clinical_symptoms_raw();              # *FIELD* CS
     my $comm  = $omim_entry->comment();                        # from genemap
 
     my $mini_mim   = $omim_entry->miniMIM();                   # *FIELD* MN
@@ -128,17 +128,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the 
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -167,11 +166,9 @@ methods. Internal methods are usually preceded with a _
 
 package Bio::Phenotype::OMIM::OMIMparser;
 
-use vars qw( @ISA );
 use strict;
 
 use Bio::Root::IO;
-use Bio::Root::Root;
 use Bio::Species;
 use Bio::Annotation::Reference;
 use Bio::Map::CytoPosition;
@@ -179,7 +176,7 @@ use Bio::Phenotype::OMIM::OMIMentry;
 use Bio::Phenotype::OMIM::OMIMentryAllelicVariant;
 use Bio::Phenotype::Correlate;
 
-@ISA = qw( Bio::Root::Root );
+use base qw(Bio::Root::Root);
 
 
 use constant DEFAULT_STATE               => 0;
@@ -255,7 +252,7 @@ sub next_phenotype {
     }
     
     if ( $self->_done() == TRUE ) {
-        return undef;
+        return;
     }
 
     my $fieldtag          = "";
@@ -481,6 +478,7 @@ sub _createOMIMentry {
             } 
         }
         elsif ( $key == TEXT_STATE ) {
+            $val = undef if($val =~ /DESCRIPTION1\nDESCRIPTION2/);
             $omim_entry->description( $val );
         }
         elsif ( $key == ALLELIC_VARIANT_STATE ) {
@@ -495,15 +493,19 @@ sub _createOMIMentry {
             $omim_entry->add_References( @refs );
         }
         elsif ( $key == SYMPT_STATE ) {
-            $omim_entry->clinical_symptoms( $val );
+            $val = '' if($val eq 'clinical symptoms');
+            $omim_entry->clinical_symptoms_raw( $val );
         }
         elsif ( $key == CONTRIBUTORS_STATE ) {
+            $val = undef if($val =~ /cn1\ncn2\ncn3/);
             $omim_entry->contributors( $val );
         }
         elsif ( $key == CREATED_BY_STATE ) {
+            $val = undef if($val =~ /cd1\ncd2\ncd3/);
             $omim_entry->created( $val );
         }
         elsif ( $key == EDITED_BY_STATE ) {
+            $val = undef if($val =~ /ed1\ned2\ned3/);
             $omim_entry->edited( $val );
         }
         elsif ( $key == MINI_MIM_TEXT_STATE ) {
@@ -526,13 +528,36 @@ sub _createOMIMentry {
     $man->common_name( "man" );
     $omim_entry->species( $man );
     $omim_entry->miniMIM( $mini_mim );
+
+    # parse the symptoms text into a hash-based structure.
+    $self->_finer_parse_symptoms($omim_entry);
     
     return $omim_entry;
 
 } # _createOMIMentry
 
 
-
+sub _finer_parse_symptoms {
+    my ($self, $omim_entry) = @_;
+    my $text = $omim_entry->clinical_symptoms_raw;
+    if( $text ) { 
+	my $part;
+	for my $line (split /\n/, $text){
+		if ($line =~ /^([\w\s,]+)\:\s*$/) {
+		$part = $1;
+	    } elsif( $line =~ /^\s+$/ ) {
+	    } elsif($line =~ /^(\s+)([^;]+)\;?\s*$/){
+		my $symptom = $2;
+		if( ! $part ) { 
+		    # $self->warn("$text\nline='$line'\n");
+		    next;
+		}
+		$omim_entry->add_clinical_symptoms($part, $symptom);
+	    }
+	}
+    }
+    $omim_entry->clinical_symptoms_raw('');
+}
 
 sub _parse_genemap {
      my ( $self, $omim_entry, $val ) = @_;
@@ -550,7 +575,7 @@ sub _parse_genemap {
                push( @cps, $cp ); 
           }
           $omim_entry->add_CytoPositions( @cps );
-     }
+      }
 
      my $gene_symbols = $a[ 5 ];
      if ( defined ( $gene_symbols ) ) {
@@ -674,8 +699,8 @@ sub _create_allelic_variant {
          $symbol = $symbol_mut_line;
     }
     
-    if ( ! defined( $description ) ) { die( "undef desc" ); }
-    if ( ! defined( $mutation ) )   { die( "undef mutation" ); }
+    if ( ! defined( $description ) ) { $self->throw("undef desc"); }
+    if ( ! defined( $mutation ) )   { $self->throw("undef mutation"); }
   
     
     my $allelic_variant = Bio::Phenotype::OMIM::OMIMentryAllelicVariant->new();
