@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------
-# $Id$
+# $Id: DatabaseI.pm,v 1.10.4.1 2006/10/02 23:10:24 sendu Exp $
 #
 # BioPerl module Bio::Search::DatabaseI
 #
@@ -43,17 +43,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules.  Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-    bioperl-l@bioperl.org                - General discussion
-    http://bio.perl.org/MailList.html    - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-    bioperl-bugs@bio.perl.org                   
-    http://bugzilla.bioperl.org/           
+  http://bugzilla.open-bio.org/           
 
 =head1 AUTHOR 
 
@@ -82,10 +81,8 @@ The rest of the documentation details each of the object methods.
 package Bio::Search::DatabaseI;
 
 use strict;
-use Bio::Root::RootI;
-use vars qw( @ISA );
 
-@ISA = qw( Bio::Root::RootI);
+use base qw(Bio::Root::RootI);
 
 
 =head2 name
