@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------
-# $Id$
+# $Id: GenericDatabase.pm,v 1.9.4.1 2006/10/02 23:10:24 sendu Exp $
 #
 # BioPerl module Bio::Search::GenericDatabase
 #
@@ -30,7 +30,7 @@ Bio::Search::GenericDatabase - Generic implementation of Bio::Search::DatabaseI
 
 =head1 DESCRIPTION
 
-This module provides a basic implementation of B<Bio::Search::DatabaseI>.
+This module provides a basic implementation of L<Bio::Search::DatabaseI>.
 See documentation in that module for more information.
 
 =head1 FEEDBACK
@@ -41,17 +41,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules.  Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-    bioperl-l@bioperl.org                - General discussion
-    http://bio.perl.org/MailList.html    - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-    bioperl-bugs@bio.perl.org                   
-    http://bugzilla.bioperl.org/           
+  http://bugzilla.open-bio.org/           
 
 =head1 AUTHOR 
 
@@ -81,11 +80,8 @@ The rest of the documentation details each of the object methods.
 package Bio::Search::GenericDatabase;
 
 use strict;
-use Bio::Search::DatabaseI;
-use Bio::Root::Root;
-use vars qw( @ISA );
 
-@ISA = qw( Bio::Root::Root Bio::Search::DatabaseI);
+use base qw(Bio::Root::Root Bio::Search::DatabaseI);
 
 sub new {
     my ($class, @args) = @_; 
