@@ -1,4 +1,4 @@
-# $Id$
+# $Id: FastaHSP.pm,v 1.10.4.1 2006/10/02 23:10:24 sendu Exp $
 #
 # BioPerl module for Bio::Search::HSP::FastaHSP
 #
@@ -40,27 +40,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Jason Stajich
 
-Email jason@bioperl.org
-
-Describe contact details here
-
-=head1 CONTRIBUTORS
-
-Additional contributors names and emails here
+Email jason-at-bioperl.org
 
 =head1 APPENDIX
 
@@ -74,12 +67,10 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Search::HSP::FastaHSP;
-use vars qw(@ISA);
 use strict;
 
-use Bio::Search::HSP::GenericHSP;
 
-@ISA = qw(Bio::Search::HSP::GenericHSP );
+use base qw(Bio::Search::HSP::GenericHSP);
 
 =head2 new
 
@@ -149,7 +140,6 @@ sub get_aln {
     }
     $self->debug("hs seq is '$hs'\n");
     $self->debug("qs seq is '$qs'\n");
-	
 
     $hs = substr($hs, $start,$self->length('total'));
     $qs = substr($qs, $start,$self->length('total'));
@@ -166,7 +156,7 @@ sub get_aln {
     }
 
     my $seqonly = $qs;
-    $seqonly =~ s/[\-\s]//g;
+    $seqonly =~ s/\s+//g;
     my ($q_nm,$s_nm) = ($self->query->seq_id(),
 			$self->hit->seq_id());
     unless( defined $q_nm && CORE::length ($q_nm) ) {
@@ -175,17 +165,17 @@ sub get_aln {
     unless( defined $s_nm && CORE::length ($s_nm) ) {
 	$s_nm = 'hit';
     }
-    my $query = new Bio::LocatableSeq('-seq'   => $qs,
+    my $query = new Bio::LocatableSeq('-seq'   => $seqonly,
 				      '-id'    => $q_nm,
-				      '-start' => 1,
-				      '-end' => CORE::length($seqonly),
+				      '-start' => $self->query->start,
+				      '-end'   => $self->query->end,
 				      );
     $seqonly = $hs;
-    $seqonly =~ s/[\-\s]//g;
-    my $hit =  new Bio::LocatableSeq('-seq'   => $hs,
+    $seqonly =~ s/\s+//g;
+    my $hit =  new Bio::LocatableSeq('-seq'    => $seqonly,
 				      '-id'    => $s_nm,
-				      '-start' => 1,
-				      '-end' => CORE::length($seqonly),
+				      '-start' => $self->hit->start,
+				      '-end'   => $self->hit->end,
 				      );
     $aln->add_seq($query);
     $aln->add_seq($hit);
