@@ -30,17 +30,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bio.perl.org/MailList.html  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bio.perl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Aaron Mackey
 
@@ -60,7 +59,8 @@ methods. Internal methods are usually preceded with a _
 package Bio::Search::Processor;
 
 use strict;
-use vars qw(@ISA);
+
+use Bio::Root::Version;
 
 =head2 new
 
@@ -86,7 +86,7 @@ sub new {
 
     exists $args{'-algorithm'} or do { 
 	print STDERR "Must supply an algorithm!";
-	return undef;
+	return;
     };
 
     $algorithm = $args{'-algorithm'} || $args{'-ALGORITHM'};
@@ -104,7 +104,7 @@ For more information about the Search/Processor system please see the
 Processor docs.  This includes ways of checking for processors at 
 compile time, not run time
 EOF
-	    return undef;
+	    return;
 	}
     }
 
