@@ -1,4 +1,4 @@
-# $Id$
+# $Id: GenericResult.pm,v 1.23.2.7 2006/10/16 17:08:16 sendu Exp $
 #
 # BioPerl module for Bio::Search::Result::GenericResult
 #
@@ -12,7 +12,9 @@
 
 =head1 NAME
 
-Bio::Search::Result::GenericResult - Generic Implementation of Bio::Search::Result::ResultI interface applicable to most search results.
+Bio::Search::Result::GenericResult - Generic Implementation of
+Bio::Search::Result::ResultI interface applicable to most search
+results.
 
 =head1 SYNOPSIS
 
@@ -20,11 +22,11 @@ Bio::Search::Result::GenericResult - Generic Implementation of Bio::Search::Resu
     # typically one gets Results from a SearchIO stream
     use Bio::SearchIO;
     my $io = new Bio::SearchIO(-format => 'blast',
- 			       -file   => 't/data/HUMBETGLOA.tblastx');
-    while( my $result = $io->next_result) {
+                                -file   => 't/data/HUMBETGLOA.tblastx');
+    while( my $result = $io->next_result ) {
         # process all search results within the input stream
-        while( my $hit = $result->next_hits()) {  
-        # insert code here for hit processing
+        while( my $hit = $result->next_hit ) {  
+            # insert code here for hit processing
         }
     }
 
@@ -32,18 +34,18 @@ Bio::Search::Result::GenericResult - Generic Implementation of Bio::Search::Resu
     my @hits = (); # would be a list of Bio::Search::Hit::HitI objects
     # typically these are created from a Bio::SearchIO stream
     my $result = new Bio::Search::Result::GenericResult
-	( -query_name        => 'HUMBETGLOA',
-	  -query_accession   => ''
-	  -query_description => 'Human haplotype C4 beta-globin gene, complete cds.'
-	  -query_length      => 3002
-	  -database_name     => 'ecoli.aa'
-	  -database_letters  => 4662239,
-	  -database_entries  => 400,
-	  -parameters        => { 'e' => '0.001' },
-	  -statistics        => { 'kappa' => 0.731 },
-	  -algorithm         => 'blastp',
+        ( -query_name        => 'HUMBETGLOA',
+          -query_accession   => ''
+          -query_description => 'Human haplotype C4 beta-globin gene, complete cds.'
+          -query_length      => 3002
+          -database_name     => 'ecoli.aa'
+          -database_letters  => 4662239,
+          -database_entries  => 400,
+          -parameters        => { 'e' => '0.001' },
+          -statistics        => { 'kappa' => 0.731 },
+          -algorithm         => 'blastp',
           -algorithm_version => '2.1.2',
-	  );
+          );
 
     my $id = $result->query_name();
 
@@ -63,6 +65,8 @@ Bio::Search::Result::GenericResult - Generic Implementation of Bio::Search::Resu
 
     my @statnames = $result->available_statistics;
 
+# TODO: Show how to configure a SearchIO stream so that it generates
+#       GenericResult objects.
 
 
 =head1 DESCRIPTION
@@ -71,6 +75,15 @@ This object is an implementation of the Bio::Search::Result::ResultI
 interface and provides a generic place to store results from a
 sequence database search.
 
+Unless you're writing a parser, you won't ever need to create a
+GenericResult or any other ResultI-implementing object. If you use
+the SearchIO system, ResultI objects are created automatically from
+a SearchIO stream which returns Bio::Search::Result::ResultI objects.
+
+For documentation on what you can do with GenericResult (and other ResultI
+objects), please see the API documentation in
+L<Bio::Search::Result::ResultI|Bio::Search::Result::ResultI>.
+
 =head1 FEEDBACK
 
 =head2 Mailing Lists
@@ -79,17 +92,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Jason Stajich and Steve Chervitz
 
@@ -98,7 +110,7 @@ Email sac@bioperl.org
 
 =head1 CONTRIBUTORS
 
-Additional contributors names and emails here
+Sendu Bala, bix@sendu.me.uk
 
 =head1 APPENDIX
 
@@ -112,16 +124,16 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Search::Result::GenericResult;
-use vars qw(@ISA);
 use strict;
 
-use Bio::Root::Root;
-use Bio::Search::Result::ResultI;
+use Bio::Search::GenericStatistics;
+use Bio::Tools::Run::GenericParameters;
 
-use overload 
-    '""' => \&to_string;
+# bug #1420
+#use overload 
+#    '""' => \&to_string;
 
-@ISA = qw(Bio::Root::Root Bio::Search::Result::ResultI);
+use base qw(Bio::Root::Root Bio::Search::Result::ResultI);
 
 =head2 new
 
@@ -136,11 +148,14 @@ use overload
            -database_name     => Name of database
            -database_letters  => Number of residues in database
            -database_entries  => Number of entries in database
+           -hits              => array ref of Bio::Search::Hit::HitI objects
            -parameters        => hash ref of search parameters (key => value)
            -statistics        => hash ref of search statistics (key => value)
            -algorithm         => program name (blastx)
            -algorithm_version   => version of the algorithm (2.1.2)
            -algorithm_reference => literature reference string for this algorithm
+           -hit_factory       => Bio::Factory::ObjectFactoryI capable of making
+                                 Bio::Search::Hit::HitI objects
 
 =cut
 
@@ -151,13 +166,13 @@ sub new {
 
   $self->{'_hits'} = [];
   $self->{'_hitindex'} = 0;
-  $self->{'_statistics'} = {};
-  $self->{'_parameters'} = {};
+  $self->{'_statistics'} = new Bio::Search::GenericStatistics;
+  $self->{'_parameters'} = new Bio::Tools::Run::GenericParameters;
 
   my ($qname,$qacc,$qdesc,$qlen,
       $dbname,$dblet,$dbent,$params,   
       $stats, $hits, $algo, $algo_v,
-      $prog_ref, $algo_r) = $self->_rearrange([qw(QUERY_NAME
+      $prog_ref, $algo_r, $hit_factory) = $self->_rearrange([qw(QUERY_NAME
                                                   QUERY_ACCESSION
                                                   QUERY_DESCRIPTION
                                                   QUERY_LENGTH
@@ -171,6 +186,7 @@ sub new {
                                                   ALGORITHM_VERSION
                                                   PROGRAM_REFERENCE
                                                   ALGORITHM_REFERENCE
+                                                  HIT_FACTORY
                                                  )],@args);
 
   $algo_r ||= $prog_ref;         
@@ -186,20 +202,24 @@ sub new {
   defined $dblet  && $self->database_letters($dblet);
   defined $dbent  && $self->database_entries($dbent);
 
+  defined $hit_factory && $self->hit_factory($hit_factory);
+  
   if( defined $params ) {
       if( ref($params) !~ /hash/i ) {
-	  $self->throw("Must specify a hash reference with the the parameter '-parameters");
+          $self->throw("Must specify a hash reference with the parameter '-parameters");
       }
       while( my ($key,$value) = each %{$params} ) {
-	  $self->add_parameter($key,$value);
+          $self->{'_parameters'}->set_parameter($key   =>   $value);
+               # $self->add_parameter($key,$value);
       }
   }
   if( defined $stats ) {
       if( ref($stats) !~ /hash/i ) {
-	  $self->throw("Must specify a hash reference with the the parameter '-statistics");
+          $self->throw("Must specify a hash reference with the parameter '-statistics");
       }
       while( my ($key,$value) = each %{$stats} ) {
-	  $self->add_statistic($key,$value);
+          $self->{'_statistics'}->set_statistic($key   =>   $value); 
+          # $self->add_statistic($key,$value);
       }
   }
 
@@ -207,7 +227,7 @@ sub new {
       $self->throw("Must define arrayref of Hits when initializing a $class\n") unless ref($hits) =~ /array/i;
 
       foreach my $s ( @$hits ) {
-	  $self->add_hit($s);
+          $self->add_hit($s);
       }
   }
   return $self;
@@ -227,8 +247,8 @@ sub algorithm{
     my ($self,$value) = @_;
     my $previous = $self->{'_algorithm'};
     if( defined $value || ! defined $previous ) { 
-	$value = $previous = '' unless defined $value;
-	$self->{'_algorithm'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_algorithm'} = $value;
     } 
     return $previous;   
 }
@@ -247,8 +267,8 @@ sub algorithm_version{
     my ($self,$value) = @_;
     my $previous = $self->{'_algorithm_version'};
     if( defined $value || ! defined $previous ) { 
-	$value = $previous = '' unless defined $value;
-	$self->{'_algorithm_version'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_algorithm_version'} = $value;
     } 
 
     return $previous;   
@@ -273,8 +293,16 @@ Bio::Search::Result::ResultI implementation
 sub next_hit {
     my ($self,@args) = @_;
     my $index = $self->_nexthitindex;
-    return undef if $index > scalar @{$self->{'_hits'}};
-    return $self->{'_hits'}->[$index];    
+    return if $index > scalar @{$self->{'_hits'}};
+    
+    my $hit = $self->{'_hits'}->[$index];
+    if (ref($hit) eq 'HASH') {
+        my $factory = $self->hit_factory || $self->throw("Tried to get a Hit, but it was a hash ref and we have no hit factory");
+        $hit = $factory->create_object(%{$hit});
+        $self->{'_hits'}->[$index] = $hit;
+        delete $self->{_hashes}->{$index};
+    }
+    return $hit;    
 }
 
 =head2 query_name
@@ -292,8 +320,8 @@ sub query_name {
     my ($self,$value) = @_;
     my $previous = $self->{'_queryname'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = '' unless defined $value;
-	$self->{'_queryname'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_queryname'} = $value;
     } 
     return $previous;
 }
@@ -312,8 +340,8 @@ sub query_accession {
     my ($self,$value) = @_;
     my $previous = $self->{'_queryacc'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = '' unless defined $value;
-	$self->{'_queryacc'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_queryacc'} = $value;
     } 
     return $previous;
 }
@@ -333,8 +361,8 @@ sub query_length {
     my ($self,$value) = @_;
     my $previous = $self->{'_querylength'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = 0 unless defined $value;
-	$self->{'_querylength'} = $value;
+        $value = $previous = 0 unless defined $value;
+        $self->{'_querylength'} = $value;
     } 
     return $previous;
 }
@@ -354,8 +382,8 @@ sub query_description {
     my ($self,$value) = @_;
     my $previous = $self->{'_querydesc'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = '' unless defined $value;
-	$self->{'_querydesc'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_querydesc'} = $value;
     } 
     return $previous;
 }
@@ -376,8 +404,8 @@ sub database_name {
     my ($self,$value) = @_;
     my $previous = $self->{'_dbname'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = '' unless defined $value;
-	$self->{'_dbname'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_dbname'} = $value;
     } 
     return $previous;
 }
@@ -399,8 +427,8 @@ sub database_letters {
     my ($self,$value) = @_;
     my $previous = $self->{'_dbletters'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = '' unless defined $value;
-	$self->{'_dbletters'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_dbletters'} = $value;
     } 
     return $previous;
 }
@@ -421,8 +449,8 @@ sub database_entries {
     my ($self,$value) = @_;
     my $previous = $self->{'_dbentries'};
     if( defined $value || ! defined $previous ) {
-	$value = $previous = '' unless defined $value;
-	$self->{'_dbentries'} = $value;
+        $value = $previous = '' unless defined $value;
+        $self->{'_dbentries'} = $value;
     } 
     return $previous;
 }
@@ -438,9 +466,9 @@ sub database_entries {
 
 =cut
 
-sub get_parameter{
+sub get_parameter {
    my ($self,$name) = @_;
-   return $self->{'_parameters'}->{$name};
+   return $self->{'_parameters'}->get_parameter($name);
 }
 
 =head2 available_parameters
@@ -455,7 +483,7 @@ sub get_parameter{
 
 sub available_parameters{
    my ($self) = @_;
-   return keys %{$self->{'_parameters'}};
+   return $self->{'_parameters'}->available_parameters;
 }
 
 
@@ -472,7 +500,7 @@ sub available_parameters{
 
 sub get_statistic{
    my ($self,$key) = @_;
-   return $self->{'_statistics'}->{$key};
+   return $self->{'_statistics'}->get_statistic($key);
 }
 
 =head2 available_statistics
@@ -487,7 +515,7 @@ sub get_statistic{
 
 sub available_statistics{
    my ($self) = @_;
-   return keys %{$self->{'_statistics'}};
+   return $self->{'_statistics'}->available_statistics;
 }
 
 =head2 Bio::Search::Report 
@@ -506,21 +534,40 @@ Bio::Search::Result::GenericResult specific methods
 
 sub add_hit {
     my ($self,$s) = @_;
-    if( $s->isa('Bio::Search::Hit::HitI') ) { 
-	push @{$self->{'_hits'}}, $s;
-    } else { 
-	$self->warn("Passed in " .ref($s). 
-		    " as a Hit which is not a Bio::Search::HitI... skipping");
+    if (ref($s) eq 'HASH' || $s->isa('Bio::Search::Hit::HitI') ) {
+        push @{$self->{'_hits'}}, $s;
+    }
+    else { 
+        $self->throw("Passed in " .ref($s)." as a Hit which is not a Bio::Search::HitI.");
+    }
+    
+    if (ref($s) eq 'HASH') {
+        $self->{_hashes}->{$#{$self->{'_hits'}}} = 1;
     }
     return scalar @{$self->{'_hits'}};
 }
 
+=head2 hit_factory
+
+ Title   : hit_factory
+ Usage   : $hit->hit_factory($hit_factory)
+ Function: Get/set the factory used to build HitI objects if necessary.
+ Returns : Bio::Factory::ObjectFactoryI
+ Args    : Bio::Factory::ObjectFactoryI
+
+=cut
+
+sub hit_factory {
+    my $self = shift;
+    if (@_) { $self->{_hit_factory} = shift }
+    return $self->{_hit_factory} || return;
+}
 
 =head2 rewind
 
  Title   : rewind
  Usage   : $result->rewind;
- Function: Allow one to reset the Hit iteration to the beginning
+ Function: Allow one to reset the Hit iterator to the beginning
            Since this is an in-memory implementation
  Returns : none
  Args    : none
@@ -546,7 +593,6 @@ sub _nexthitindex{
 }
 
 
-
 =head2 add_parameter
 
  Title   : add_parameter
@@ -558,9 +604,9 @@ sub _nexthitindex{
 
 =cut
 
-sub add_parameter{
+sub add_parameter {
    my ($self,$key,$value) = @_;
-   $self->{'_parameters'}->{$key} = $value;
+   $self->{'_parameters'}->set_parameter($key => $value);
 }
 
 
@@ -577,7 +623,7 @@ sub add_parameter{
 
 sub add_statistic {
    my ($self,$key,$value) = @_;
-   $self->{'_statistics'}->{$key} = $value;
+   $self->{'_statistics'}->set_statistic($key => $value);
    return;
 }
 
@@ -613,12 +659,19 @@ sub num_hits{
 
 =cut
 
-sub hits{
-   my ($self) = shift;
-   my @hits = ();
-   if( ref $self->{'_hits'}) {
-       @hits = @{$self->{'_hits'}};
-   }
+sub hits {
+    my ($self) = shift;
+    
+    foreach my $i (keys %{$self->{_hashes} || {}}) {
+        my $factory = $self->hit_factory || $self->throw("Tried to get a Hit, but it was a hash ref and we have no hit factory");
+        $self->{'_hits'}->[$i] = $factory->create_object(%{$self->{'_hits'}->[$i]});
+        delete $self->{_hashes}->{$i};
+    }
+    
+    my @hits = ();
+    if (ref $self->{'_hits'}) {
+        @hits = @{$self->{'_hits'}};
+    }
     return @hits;   
 }
 
@@ -652,37 +705,14 @@ See documentation in L<Bio::Search::Result::ResultI::no_hits_found()|Bio::Search
 
 =cut
 
-#-----------
 sub no_hits_found {
-#-----------
-    my ($self, $round) = @_;
+    my $self = shift;
 
-    my $result = 0;   # final return value of this method.
     # Watch the double negative! 
     # result = 0 means "yes hits were found"
-    # result = 1 means "no hits were found" (for the indicated iteration or all iterations)
+    # result = 1 means "no hits were found" 
 
-    # If a iteration was not specified and there were multiple iterations,
-    # this method should return true only if all iterations had no hits found.
-    if( not defined $round ) {
-        if( $self->{'_iterations'} > 1) {
-            $result = 1;
-            foreach my $i( 1..$self->{'_iterations'} ) {
-                if( not defined $self->{"_iteration_$i"}->{'_no_hits_found'} ) {
-                    $result = 0;
-                    last;
-                }
-            }
-        }
-        else {
-            $result = $self->{"_iteration_1"}->{'_no_hits_found'};
-        }
-    }
-    else {
-        $result = $self->{"_iteration_$round"}->{'_no_hits_found'};
-    }
-
-    return $result;
+    return $self->{'_no_hits_found'};
 }
 
 
@@ -692,46 +722,9 @@ See documentation in L<Bio::Search::Result::ResultI::set_no_hits_found()|Bio::Se
 
 =cut
 
-#-----------
 sub set_no_hits_found {
-#-----------
-    my ($self, $round) = @_;
-    $round ||= 1;
-    $self->{"_iteration_$round"}->{'_no_hits_found'} = 1;
-}
-
-
-=head2 iterations
-
-See documentation in L<Bio::Search::Result::ResultI::iterations()|Bio::Search::Result::ResultI>
-
-=cut
-
-#----------------
-sub iterations {
-#----------------
-    my ($self, $num ) = @_;
-    if( defined $num ) {
-        $self->{'_iterations'} = $num;
-    }
-    return $self->{'_iterations'};
-}
-
-
-=head2 psiblast
-
-See documentation in L<Bio::Search::Result::ResultI::psiblast()|Bio::Search::Result::ResultI>
-
-=cut
-
-#----------------
-sub psiblast {
-#----------------
-    my ($self, $val ) = @_;
-    if( $val ) {
-        $self->{'_psiblast'} = 1;
-    }
-    return $self->{'_psiblast'};
+    my $self = shift;
+    $self->{'_no_hits_found'} = 1;
 }
 
 
@@ -750,11 +743,9 @@ sub psiblast {
 
 =cut
 
-#---------------
 sub to_string {
-#---------------
     my $self = shift;
-    my $str = "[GenericResult] " . $self->algorithm . " query=" . $self->query_name . " " . $self->query_description .", db=" . $self->database_name;
+    my $str = ref($self) . ", algorithm= " . $self->algorithm . ", query=" . $self->query_name . " " . $self->query_description .", db=" . $self->database_name;
     return $str;
 }
 
