@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------
-# $Id$
+# $Id: ResultI.pm,v 1.23.4.1 2006/10/02 23:10:24 sendu Exp $
 #
 # BioPerl module Bio::Search::Result::ResultI
 #
@@ -26,7 +26,7 @@ Bio::Search::Result::ResultI - Abstract interface to Search Result objects
 
     use Bio::SearchIO;
     my $io = new Bio::SearchIO(-format => 'blast',
- 			       -file   => 't/data/HUMBETGLOA.tblastx');
+                                -file   => 't/data/HUMBETGLOA.tblastx');
     my $result = $io->next_result;
     while( $hit = $result->next_hit()) { # enter code here for hit processing
     }
@@ -49,6 +49,7 @@ Bio::Search::Result::ResultI - Abstract interface to Search Result objects
 
     my @statnames = $result->available_statistics;
 
+
 =head1 DESCRIPTION
 
 Bio::Search::Result::ResultI objects are data structures containing
@@ -66,17 +67,16 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bio.perl.org/MailList.html  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR 
 
@@ -107,11 +107,9 @@ The rest of the documentation details each of the object methods. Internal metho
 package Bio::Search::Result::ResultI;
 
 use strict;
-use vars qw(@ISA);
 
-use Bio::AnalysisResultI;
 
-@ISA = qw( Bio::AnalysisResultI );
+use base qw(Bio::AnalysisResultI);
 
 
 =head2 next_hit
@@ -131,6 +129,68 @@ sub next_hit {
     $self->throw_not_implemented;
 }
 
+=head2 sort_hits
+
+ Title		: sort_hits
+ Usage		: $result->sort_hits(\&sort_function)
+ Function	: Sorts the available hit objects by a user-supplied function. Defaults to sort
+                  by descending score.
+ Returns	: n/a
+ Args		: A coderef for the sort function.  See the documentation on the Perl sort() 
+                  function for guidelines on writing sort functions.  
+ Note		: To access the special variables $a and $b used by the Perl sort() function 
+                  the user function must access Bio::Search::Result::ResultI namespace. 
+                  For example, use : 
+                  $result->sort_hits( sub{$Bio::Search::Result::ResultI::a->length <=> 
+					      $Bio::Search::Result::ResultI::b->length});
+                   NOT $result->sort_hits($a->length <=>$b->length);
+
+=cut
+
+sub sort_hits {
+    my ($self, $coderef) = @_;
+    my @sorted_hits;
+
+    if ($coderef)  {
+	$self->throw('sort_hits requires a sort function passed as a subroutine reference')
+	    unless (ref($coderef) eq 'CODE');
+    }
+    else {
+	$coderef = \&_default_sort_hits;
+	# throw a warning?
+    }
+
+    my @hits = $self->hits();
+    
+    eval {@sorted_hits = sort $coderef @hits };
+
+   if ($@) {
+       $self->throw("Unable to sort hits: $@");
+   }
+   else {
+       $self->{'_hits'} = \@sorted_hits;
+       $self->{'_no_iterations'} = 1; # to bypass iteration checking in hits() method
+       1;
+   }
+}
+
+=head2 _default sort_hits
+
+  Title	: _default_sort_hits
+  Usage	: Do not call directly.
+  Function: Sort hits in descending order by score
+  Args	: None
+  Returns: 1 on success
+  Note	: Used by $result->sort_hits()
+
+=cut
+
+sub _default_sort_hits {
+    $Bio::Search::Result::ResultI::b->score <=> 
+	    $Bio::Search::Result::ResultI::a->score;
+
+}
+
 =head2 query_name
 
  Title   : query_name
@@ -380,10 +440,11 @@ sub num_hits{
 
  Title   : hits
  Usage   : my @hits = $result->hits
- Function: Returns the available hits for this Result
- Returns : Array of L<Bio::Search::Hit::HitI> objects
+ Function: Returns the HitI objects contained within this Result
+ Returns : Array of Bio::Search::Hit::HitI objects
  Args    : none
 
+See Also: L<Bio::Search::Hit::HitI>
 
 =cut
 
@@ -392,9 +453,10 @@ sub hits{
    $self->throw_not_implemented();
 }
 
+
 =head2 no_hits_found
 
- Usage     : $nohits = $blast->no_hits_found( [iteration_number] ); 
+ Usage     : $nohits = $blast->no_hits_found();
  Purpose   : Get boolean indicator indicating whether or not any hits
              were present in the report.
 
@@ -406,10 +468,7 @@ sub hits{
              for hitless reports generated when filtering.
 
  Returns   : Boolean
- Argument  : (optional) integer indicating the iteration number (PSI-BLAST)
-             If iteration number is not specified and this is a PSI-BLAST result,
-             then this method will return true only if all iterations had
-             no hits found.
+ Argument  : none
 
 =cut
 
@@ -420,42 +479,16 @@ sub no_hits_found { shift->throw_not_implemented }
 
 =head2 set_no_hits_found
 
- Usage     : $blast->set_no_hits_found( [iteration_number] ); 
+ Usage     : $blast->set_no_hits_found(); 
  Purpose   : Set boolean indicator indicating whether or not any hits
              were present in the report.
  Returns   : n/a
- Argument  : (optional) integer indicating the iteration number (PSI-BLAST)
+ Argument  : none
 
 =cut
 
 sub set_no_hits_found { shift->throw_not_implemented }
 
-
-=head2 iterations
-
- Usage     : $num_iterations = $blast->iterations;  (get)
-             $blast->iterations($num_iterations);   (set)
- Purpose   : Set/get the number of iterations in the Blast Report (PSI-BLAST).
- Returns   : Total number of iterations in the report
- Argument  : integer  (when setting)
-
-=cut
-
-sub iterations { shift->throw_not_implemented }
-
-
-=head2 psiblast
-
- Usage     : if( $blast->psiblast ) { ... }
- Purpose   : Set/get a boolean indicator whether or not the report 
-             is a PSI-BLAST report.
- Returns   : 1 if PSI-BLAST, undef if not.
- Argument  : 1 (when setting)
-
-=cut
-
-sub psiblast { shift->throw_not_implemented }
-
 1;
 
 
