@@ -1,8 +1,8 @@
-# $Id: SearchIO.pm,v 1.18 2002/12/13 13:54:03 jason Exp $
+# $Id: SearchIO.pm,v 1.39.4.1 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::SearchIO
 #
-# Cared for by Jason Stajich <jason@bioperl.org>
+# Cared for by Jason Stajich <jason-at-bioperl.org>
 #
 # Copyright Jason Stajich
 #
@@ -12,21 +12,24 @@
 
 =head1 NAME
 
-Bio::SearchIO - Driver for parsing Sequence Database Searches (Blast,FASTA,...)
+Bio::SearchIO - Driver for parsing Sequence Database Searches 
+(BLAST, FASTA, ...)
 
 =head1 SYNOPSIS
 
-    use Bio::SearchIO;
-    # format can be 'fasta', 'blast'
-    my $searchio = new Bio::SearchIO( -format => 'blastxml',
-                                      -file   => 'blastout.xml' );
-    while ( my $result = $searchio->next_result() ) {
+   use Bio::SearchIO;
+   # format can be 'fasta', 'blast', 'exonerate', ...
+   my $searchio = new Bio::SearchIO( -format => 'blastxml',
+                                     -file   => 'blastout.xml' );
+   while ( my $result = $searchio->next_result() ) {
        while( my $hit = $result->next_hit ) {
-	# process the Bio::Search::Hit::HitI object
+        # process the Bio::Search::Hit::HitI object
            while( my $hsp = $hit->next_hsp ) { 
-	    # process the Bio::Search::HSP::HSPI object
-	}
-    }
+            # process the Bio::Search::HSP::HSPI object
+           }
+       }
+   }
+
 
 =head1 DESCRIPTION
 
@@ -40,6 +43,24 @@ Once you get a SearchIO object, calling next_result() gives you back
 a L<Bio::Search::Result::ResultI> compliant object, which is an object that
 represents one Blast/Fasta/HMMER whatever report.
 
+A list of module names and formats is below:
+
+  blast      BLAST (WUBLAST, NCBIBLAST,bl2seq)   
+  fasta      FASTA -m9 and -m0
+  blasttable BLAST -m9 or -m8 output (NCBI not WUBLAST tabular)
+  megablast  MEGABLAST
+  psl        UCSC PSL format
+  waba       WABA output
+  axt        AXT format
+  sim4       Sim4
+  hmmer      HMMER hmmpfam and hmmsearch
+  exonerate  Exonerate CIGAR and VULGAR format
+  blastxml   NCBI BLAST XML
+  wise       Genewise -genesf format
+
+Also see the SearchIO HOWTO:
+http://bioperl.open-bio.org/wiki/HOWTO:SearchIO
+
 =head1 FEEDBACK
 
 =head2 Mailing Lists
@@ -48,26 +69,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Jason Stajich & Steve Chervitz
 
-Email jason@bioperl.org
-Email sac@bioperl.org
-
-=head1 CONTRIBUTORS
-
-Additional contributors names and emails here
+Email jason-at-bioperl.org
+Email sac-at-bioperl.org
 
 =head1 APPENDIX
 
@@ -82,17 +98,19 @@ Internal methods are usually preceded with a _
 
 package Bio::SearchIO;
 use strict;
-use vars qw(@ISA);
 
 # Object preamble - inherits from Bio::Root::IO
 
-use Bio::Root::IO;
-use Bio::Event::EventGeneratorI;
 use Bio::SearchIO::SearchResultEventBuilder;
-use Bio::AnalysisParserI;
+
+# Special exception class for exceptions during parsing.
+# End users should not ever see these.
+# For an example of usage, see blast.pm.
+@Bio::SearchIO::InternalParserError::ISA = qw(Bio::Root::Exception);
+
 use Symbol();
 
-@ISA = qw( Bio::Root::IO Bio::Event::EventGeneratorI Bio::AnalysisParserI);
+use base qw(Bio::Root::IO Bio::Event::EventGeneratorI Bio::AnalysisParserI);
 
 =head2 new
 
@@ -100,16 +118,20 @@ use Symbol();
  Usage   : my $obj = new Bio::SearchIO();
  Function: Builds a new Bio::SearchIO object 
  Returns : Bio::SearchIO initialized with the correct format
- Args    : Args    : -file => $filename
-           -format => format
-           -fh => filehandle to attach to
-           -result_factory => Object implementing Bio::Factory::ResultFactoryI
-           -hit_factory    => Object implementing Bio::Factory::HitFactoryI
+ Args    : -file           => $filename
+           -format         => format
+           -fh             => filehandle to attach to
+           -result_factory => Object implementing Bio::Factory::ObjectFactoryI
+           -hit_factory    => Object implementing Bio::Factory::ObjectFactoryI
+           -hsp_factory    => Object implementing Bio::Factory::ObjectFactoryI
            -writer         => Object implementing Bio::SearchIO::SearchWriterI
            -output_format  => output format, which will dynamically load writer
 
-See L<Bio::Factory::ResultFactoryI>, L<Bio::Factory::HitFactoryI>,
-L<Bio::SearchIO::SearchWriterI>
+See L<Bio::Factory::ObjectFactoryI>, L<Bio::SearchIO::SearchWriterI>
+
+Any factory objects in the arguments are passed along to the
+SearchResultEventBuilder object which holds these factories and sets
+default ones if none are supplied as arguments.
 
 =cut
 
@@ -120,7 +142,7 @@ sub new {
   # or do we want to call SUPER on an object if $caller is an
   # object?
   if( $class =~ /Bio::SearchIO::(\S+)/ ) {
-    my ($self) = $class->SUPER::new(@args);	
+    my ($self) = $class->SUPER::new(@args);        
     $self->_initialize(@args);
     return $self;
   } else { 
@@ -133,25 +155,25 @@ sub new {
     my $writer = undef;
 
     if( defined $output_format ) {
-	if( defined $param{'-writer'} ) {
-	    my $dummy = Bio::Root::Root->new();
-	    $dummy->throw("Both writer and output format specified - not good");
-	}
+        if( defined $param{'-writer'} ) {
+            my $dummy = Bio::Root::Root->new();
+            $dummy->throw("Both writer and output format specified - not good");
+        }
 
-	if( $output_format =~ /^blast$/i ) {
-	    $output_format = 'TextResultWriter';
-	}
-	my $output_module = "Bio::SearchIO::Writer::".$output_format;
-	$class->_load_module($output_module);
-	$writer = $output_module->new();
-	push(@args,"-writer",$writer);
+        if( $output_format =~ /^blast$/i ) {
+            $output_format = 'TextResultWriter';
+        }
+        my $output_module = "Bio::SearchIO::Writer::".$output_format;
+        $class->_load_module($output_module);
+        $writer = $output_module->new(@args);
+        push(@args,"-writer",$writer);
     }
 
 
     # normalize capitalization to lower case
     $format = "\L$format";
     
-    return undef unless( $class->_load_format_module($format) );
+    return unless( $class->_load_format_module($format) );
     return "Bio::SearchIO::${format}"->new(@args);
   }
 }
@@ -215,7 +237,7 @@ sub attach_EventHandler{
     my ($self,$handler) = @_;
     return if( ! $handler );
     if( ! $handler->isa('Bio::SearchIO::EventHandlerI') ) {
-	$self->warn("Ignoring request to attatch handler ".ref($handler). ' because it is not a Bio::SearchIO::EventHandlerI');
+        $self->warn("Ignoring request to attatch handler ".ref($handler). ' because it is not a Bio::SearchIO::EventHandlerI');
     }
     $self->{'_handler'} = $handler;
     return;
@@ -243,32 +265,15 @@ sub _initialize {
     $self->{'_handler'} = undef;
     # not really necessary unless we put more in RootI
     #$self->SUPER::_initialize(@args);
-    
+
     # initialize the IO part
     $self->_initialize_io(@args);
-    $self->attach_EventHandler(new Bio::SearchIO::SearchResultEventBuilder());
+    $self->attach_EventHandler(new Bio::SearchIO::SearchResultEventBuilder(@args));
     $self->{'_reporttype'} = '';
-
-    my ( $writer, $rfactory, $hfactory, $use_factories ) =
-      $self->_rearrange([qw(WRITER 
-			    RESULT_FACTORY 
-			    HIT_FACTORY
-			    USE_FACTORIES)], @args);
+    $self->{_notfirsttime} = 0;
+    my ( $writer ) = $self->_rearrange([qw(WRITER)], @args);
 
     $self->writer( $writer ) if $writer;
-
-    # TODO: Resolve this issue:
-    # The $use_factories flag is a temporary hack to allow factory-based and 
-    # non-factory based SearchIO objects to co-exist. 
-    # steve --- Sat Dec 22 04:41:20 2001
-    if( $use_factories) {
-      if( not defined $self->{'_result_factory'}) {
-	$self->result_factory( $rfactory || $self->default_result_factory_class->new );
-      }
-      if( not defined $self->{'_hit_factory'}) {
-	$self->hit_factory( $hfactory || $self->default_hit_factory_class->new );
-      }
-    }
 }
 
 =head2 next_result
@@ -321,10 +326,12 @@ sub write_result {
    if( not ref($self->{'_result_writer'}) ) {
        $self->throw("ResultWriter not defined.");
    }
-   my $str = $self->writer->to_string( $result, @args );
-   #print "Got string: \n$str\n";
-   $self->_print( "$str" );
-   
+   @args = $self->{'_notfirsttime'} unless( @args );
+
+   my $str = $self->writer->to_string( $result, @args);
+   $self->{'_notfirsttime'} = 1;
+   # print "Got string: \n$str\n";
+   $self->_print( "$str" ) if defined $str;
    return 1;
 }
 
@@ -353,62 +360,6 @@ sub writer {
 }
 
 
-=head2 hit_factory
-
- Title   : hit_factory
- Usage   : $hit_factory = $stream->hit_factory;  (get)
-         : $stream->hit_factory( $factory );     (set)
- Function: Sets/Gets a factory object to create hit objects for this SearchIO
- Returns : Bio::Factory::HitFactoryI object 
- Args    : Bio::Factory::HitFactoryI object (when setting)
- Throws  : Bio::Root::Exception if a non-Bio::Factory::HitFactoryI object  
-           is passed in.
- Comments: A SearchIO implementation should provide a default hit factory.
-
-See L<Bio::Factory::HitFactoryI>
-
-=cut
-
-sub hit_factory {
-    my ($self, $fact) = @_;
-    if( ref $fact and $fact->isa( 'Bio::Factory::HitFactoryI' )) {
-    	   $self->{'_hit_factory'} = $fact;
-    }
-    elsif( defined $fact ) {
-        $self->throw("Can't set HitFactory. Not a Bio::Factory::HitFactoryI: $fact");
-    }
-    return $self->{'_hit_factory'};
-}
-
-=head2 result_factory
-
- Title   : result_factory
- Usage   : $result_factory = $stream->result_factory;  (get)
-         : $stream->result_factory( $factory );        (set)
- Function: Sets/Gets a factory object to create result objects for this
-           SearchIO.
- Returns : Bio::Factory::ResultFactoryI object 
- Args    : Bio::Factory::ResultFactoryI object (when setting)
- Throws  : Bio::Root::Exception if a non-Bio::Factory::ResultFactoryI object
-           is passed in.
- Comments: A SearchIO implementation should provide a default result factory.
-
-See L<Bio::Factory::ResultFactoryI>
-
-=cut
-
-sub result_factory {
-    my ($self, $fact) = @_;
-    if( ref $fact and $fact->isa( 'Bio::Factory::ResultFactoryI' )) {
-    	   $self->{'_result_factory'} = $fact;
-    }
-    elsif( defined $fact ) {
-        $self->throw("Can't set ResultFactory. Not a Bio::Factory::ResultFactoryI: $fact");
-    }
-    return $self->{'_result_factory'};
-}
-
-
 =head2 result_count
 
  Title   : result_count
@@ -426,29 +377,6 @@ sub result_count {
 }
 
 
-=head2 default_hit_factory_class
-
- Title   : default_hit_factory_class
- Usage   : $res_factory = $obj->default_hit_factory_class()->new( @args )
- Function: Returns the name of the default class to be used for creating
-           Bio::Search::Hit::HitI objects.
- Example :
- Returns : A string containing the name of a class that implements 
-           the Bio::Search::Hit::HitI interface.
- Args    : none
- Comments: Bio::SearchIO does not implement this method. It throws a
-           NotImplemented exception
-
-See L<Bio::Search::Hit::HitI>
-
-=cut
-
-sub default_hit_factory_class {
-    my $self = shift;
-# TODO: Uncomment this when Jason's SearchIO code conforms
-#    $self->throw_not_implemented;
-}
-
 =head2 _load_format_module
 
  Title   : _load_format_module
@@ -492,27 +420,34 @@ END
 
 =cut
 
-
 sub _guess_format {
    my $class = shift;
    return unless $_ = shift;
-   return 'blast'   if (/blast/i or /\.bl\w$/i);
-   return 'fasta' if (/fasta/i or /\.fas$/i);
-   return 'blastxml' if (/blast/i and /\.xml$/i);
-   return 'exonerate' if ( /\.exonerate/i or /\.exon/i );
+   return 'blast'   if (/\.(blast|t?bl\w)$/i );
+   return 'fasta' if (/\.
+		      (?: t? fas (?:ta)? |
+		       m\d+ |
+		       (?: t? (?: fa |  fx |  fy |  ff |  fs ) ) |
+		       (?: (?:ss | os | ps) (?:earch)? ))
+		      $/ix );
+   return 'blastxml' if ( /\.(blast)?xml$/i);
+   return 'exonerate' if ( /\.exon(erate)?/i );
 }
 
 sub close { 
-    my $self = shift;
+    my $self = shift;    
+
     if( $self->writer ) {
-	$self->_print($self->writer->end_report());
+        $self->_print($self->writer->end_report());
+	$self->{'_result_writer'}= undef;
     }
     $self->SUPER::close(@_);
 }
 
 sub DESTROY {
     my $self = shift;
-    $self->close();
+    $self->close() if defined $self->_fh;
+    $self->SUPER::DESTROY;
 }
 
 sub TIEHANDLE {
@@ -533,6 +468,7 @@ sub PRINT {
   $self->{'processor'}->write_result(@_);
 }
 
+
 1;
 
 __END__
