@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------
-# $Id$
+# $Id: SearchWriterI.pm,v 1.10.4.1 2006/10/02 23:10:26 sendu Exp $
 #
 # BioPerl module Bio::SearchIO::SearchWriterI
 #
@@ -25,12 +25,12 @@ you can do the following things with it:
 =head1 DESCRIPTION
 
 This module defines abstract methods that all subclasses must implement
-to be used for outputting results from B<Bio::Search::Result::ResultI>
+to be used for outputting results from L<Bio::Search::Result::ResultI>
 objects.
 
 =head1 AUTHOR
 
-Steve Chervitz E<lt>sac@bioperl.orgE<gt>
+Steve Chervitz E<lt>sac-at-bioperl.orgE<gt>
 
 =head1 DISCLAIMER
 
@@ -44,9 +44,8 @@ The rest of the documentation details each of the object methods.
 
 package Bio::SearchIO::SearchWriterI;
 
-use Bio::Root::RootI;
 
-@ISA = qw( Bio::Root::RootI );
+use base qw(Bio::Root::RootI);
 
 =head2 to_string
 
@@ -68,6 +67,19 @@ sub to_string {
     $self->throw_not_implemented;
 }
 
+=head2 start_report
+
+ Title   : start_report
+ Usage   : $self->start_report()
+ Function: The method to call when starting a report. You can override it
+           to make a custom header
+ Returns : string
+ Args    : none
+
+=cut
+
+sub start_report { return '' }
+
 =head2 end_report
 
  Title   : end_report
@@ -82,10 +94,7 @@ sub to_string {
 
 =cut
 
-sub end_report { 
-    my $self = shift;
-    return '';
-}
+sub end_report {  return '' }
 
 =head2 filter
 
@@ -107,13 +116,13 @@ sub end_report {
 
 sub filter {
     my ($self,$method,$code) = @_;    
-    return undef unless $method;
+    return unless $method;
     $method = uc($method);
     if( $method ne 'HSP' &&
 	$method ne 'HIT' &&
 	$method ne 'RESULT' ) {
 	$self->warn("Unknown method $method");
-	return undef;
+	return;
     }
     if( $code )  {
 	$self->throw("Must provide a valid code reference") unless ref($code) =~ /CODE/;
