@@ -1,4 +1,4 @@
-# $Id$
+# $Id: RichSeq.pm,v 1.19.4.1 2006/10/02 23:10:27 sendu Exp $
 #
 # BioPerl module for Bio::Seq::RichSeq
 #
@@ -17,7 +17,7 @@ sequence database entry
 
 =head1 SYNOPSIS
 
-See Bio::Seq::RichSeqI and documentation of methods.
+See L<Bio::Seq::RichSeqI> and documentation of methods.
 
 =head1 DESCRIPTION
 
@@ -54,27 +54,25 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                 - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Ewan Birney
 
 Email birney@ebi.ac.uk
 
-Describe contact details here
-
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -83,15 +81,12 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Seq::RichSeq;
-use vars qw($AUTOLOAD @ISA);
+use vars qw($AUTOLOAD);
 use strict;
 
-# Object preamble - inherits from Bio::Root::Object
 
-use Bio::Seq;
-use Bio::Seq::RichSeqI;
 
-@ISA = qw(Bio::Seq Bio::Seq::RichSeqI);
+use base qw(Bio::Seq Bio::Seq::RichSeqI);
 
 
 =head2 new
@@ -120,22 +115,29 @@ sub new {
     my ($dates, $xtra, $sv,
 	$keywords, $pid, $mol, 
 	$division ) = $self->_rearrange([qw(DATES 
-					   SECONDARY_ACCESSIONS
-					   SEQ_VERSION 
-					   KEYWORDS
-					   PID
-					   MOLECULE
-					   DIVISION
-					   )],
-				   @args);
+					    SECONDARY_ACCESSIONS
+					    SEQ_VERSION 
+					    KEYWORDS
+					    PID
+					    MOLECULE
+					    DIVISION
+					    )],
+					@args);
     defined $division && $self->division($division);
     defined $mol && $self->molecule($mol);
-    defined $keywords && $self->keywords($keywords);
+    if(defined($keywords)) {
+	if(ref($keywords) && (ref($keywords) eq "ARRAY")) {
+	    $self->add_keyword(@$keywords);
+	} else {
+	    # got a string - use the old API
+	    $self->keywords($keywords);
+	}
+    }
     defined $sv && $self->seq_version($sv);
     defined $pid && $self->pid($pid);
 
     if( defined $dates ) {
-	if( ref($dates) =~ /array/i ) {
+	if( ref($dates) eq "ARRAY" ) {
 	    foreach ( @$dates) {
 		$self->add_date($_);
 	    } 
@@ -145,7 +147,7 @@ sub new {
     }
 
     if( defined $xtra ) {
-	if( ref($xtra) =~ /array/i ) {
+	if( ref($xtra) eq "ARRAY" ) {
 	    foreach ( @$xtra) {
 		$self->add_secondary_accession($_);
 	    } 
@@ -204,27 +206,29 @@ sub molecule {
 
  Title   : add_date
  Usage   : $self->add_date($datestr)
- Function: adds a date
+ Function: adds one or more dates
+
+           This implementation stores dates as keyed annotation, the
+           key being 'date_changed'. You can take advantage of this
+           fact when accessing the annotation collection directly.
+
  Example :
- Returns : a date string or an array of such strings
- Args    :
+ Returns : 
+ Args    : a date string or an array of such strings
 
 
 =cut
 
 sub add_date {
-   my ($self,@dates) = @_;
-   foreach my $dt ( @dates ) {
-       push(@{$self->{'_dates'}},$dt);
-   }
+    return shift->_add_annotation_value('date_changed',@_);
 }
 
 =head2 get_dates
 
  Title   : get_dates
- Usage   :
- Function:
- Example :
+ Usage   : my @dates = $seq->get_dates;
+ Function: Get the dates of the sequence (usually, when it was created and
+           changed.
  Returns : an array of date strings
  Args    :
 
@@ -232,30 +236,26 @@ sub add_date {
 =cut
 
 sub get_dates{
-   my ($self) = @_;
-   return @{$self->{'_dates'}}; 
+    return shift->_get_annotation_values('date_changed');
 }
 
 
 =head2 pid
 
  Title   : pid
- Usage   :
+ Usage   : my $pid = $seq->pid();
  Function: Get (and set, depending on the implementation) the PID property
            for the sequence.
- Example :
  Returns : a string
  Args    :
 
 
 =cut
 
-sub pid {
-    my ($self,$pid) = @_;
-    
-    if(defined($pid)) {
-	$self->{'_pid'} = $pid;
-    }
+sub pid{
+    my $self = shift;
+
+    return $self->{'_pid'} = shift if @_;
     return $self->{'_pid'};
 }
 
@@ -286,6 +286,12 @@ sub accession {
  Title   : add_secondary_accession
  Usage   : $self->add_domment($ref)
  Function: adds a secondary_accession
+
+           This implementation stores secondary accession numbers as
+           keyed annotation, the key being 'secondary_accession'. You
+           can take advantage of this fact when accessing the
+           annotation collection directly.
+
  Example :
  Returns : 
  Args    : a string or an array of strings
@@ -294,78 +300,147 @@ sub accession {
 =cut
 
 sub add_secondary_accession {
-   my ($self) = shift;
-   foreach my $dt ( @_ ) {
-       push(@{$self->{'_secondary_accession'}},$dt);
-   }
+    return shift->_add_annotation_value('secondary_accession',@_);
 }
 
 =head2 get_secondary_accessions
 
  Title   : get_secondary_accessions
- Usage   :
- Function:
- Example :
+ Usage   : my @acc = $seq->get_secondary_accessions();
+ Function: Get the secondary accession numbers as strings.
  Returns : An array of strings
- Args    :
+ Args    : none
 
 
 =cut
 
 sub get_secondary_accessions{
-   my ($self,@args) = @_;
-   return @{$self->{'_secondary_accession'}}; 
+    return shift->_get_annotation_values('secondary_accession');
 }
 
 =head2 seq_version
 
  Title   : seq_version
  Usage   : $obj->seq_version($newval)
- Function: 
- Example : 
- Returns : value of seq_version
- Args    : newvalue (optional)
+ Function: Get/set the sequence version
+ Returns : value of seq_version (a scalar)
+ Args    : on set, new value (a scalar or undef, optional)
 
 
 =cut
 
 sub seq_version{
-   my ($obj,$value) = @_;
-   if( defined $value) {
-      $obj->{'_seq_version'} = $value;
-    }
-    return $obj->{'_seq_version'};
+    my $self = shift;
 
+    return $self->{'_seq_version'} = shift if @_;
+    return $self->{'_seq_version'};
 }
 
 
-=head2 keywords
+=head2 add_keyword
 
- Title   : keywords
- Usage   : $obj->keywords($newval)
- Function: 
- Returns : value of keywords (a string)
- Args    : newvalue (optional) (a string)
+ Title   : add_keyword
+ Usage   : $obj->add_keyword($newval)
+ Function: Add a new keyword to the annotation of the sequence.
+
+           This implementation stores keywords as keyed annotation,
+           the key being 'keyword'. You can take advantage of this
+           fact when accessing the annotation collection directly.
+
+ Returns : 
+ Args    : value to be added (optional) (a string)
 
 
 =cut
 
-sub keywords {
-   my $obj = shift;
-   if( @_ ) {
-      my $value = shift;
-      $obj->{'_keywords'} = $value;
-    }
-    return $obj->{'_keywords'};
+sub add_keyword {
+    return shift->_add_annotation_value('keyword',@_);
+}
 
+=head2 get_keywords
+
+ Title   : get_keywords
+ Usage   : $obj->get_keywords($newval)
+ Function: Get the keywords for this sequence as an array of strings.
+ Returns : an array of strings
+ Args    : 
+
+
+=cut
+
+sub get_keywords {
+    return shift->_get_annotation_values('keyword');
+}
+
+=head1 Private methods and synonyms for backward compatibility
+
+=cut
+
+=head2 _add_annotation_value
+
+ Title   : _add_annotation_value
+ Usage   :
+ Function: Adds a value to the annotation collection under the specified
+           key. Note that this is not a public method.
+ Returns : 
+ Args    : key (a string), value(s) (one or more scalars)
+
+
+=cut
+
+sub _add_annotation_value{
+    my $self = shift;
+    my $key  = shift;
+
+    foreach my $val (@_) {
+	$self->annotation->add_Annotation(
+			Bio::Annotation::SimpleValue->new(-tagname => $key,
+							  -value => $val)
+					  );
+    }
+}
+
+=head2 _get_annotation_values
+
+ Title   : _get_annotation_values
+ Usage   :
+ Function: Gets the values of a specific annotation as identified by the
+           key from the annotation collection. Note that this is not a
+           public method.
+ Example :
+ Returns : an array of strings
+ Args    : the key (a string)
+
+
+=cut
+
+sub _get_annotation_values{
+    my $self = shift;
+
+    return map { $_->value(); } $self->annotation->get_Annotations(shift);
 }
 
 #
 ##
-### Deprecated methods kept for ease of transtion
+### Deprecated methods kept for ease of transition
 ##
 #
 
+sub keywords {
+    my $self = shift;
+
+    # have we been called in set mode?
+    if(@_) {
+	# yes; translate to the new API
+	foreach my $kwd (@_) {
+	    $self->add_keyword(split(/\s*;\s*/,$kwd));
+	}
+    } else {
+	# no; translate read-only to the new API
+	return join("; ",$self->get_keywords());
+    }
+}
+
 sub each_date {
    my ($self) = @_;
    $self->warn("Deprecated method... please use get_dates");
