@@ -1,4 +1,4 @@
-# $Id$
+# $Id: RichSeqI.pm,v 1.14.4.1 2006/10/02 23:10:27 sendu Exp $
 #
 # BioPerl module for Bio::Seq::RichSeqI
 #
@@ -12,17 +12,17 @@
 
 =head1 NAME
 
-Bio::Seq::RichSeqI - RichSeq interface, mainly for database orientated sequences
+Bio::Seq::RichSeqI - interface for sequences from rich data sources, mostly databases
 
 =head1 SYNOPSIS
 
     @secondary   = $richseq->get_secondary_accessions;
     $division    = $richseq->division;
     $mol         = $richseq->molecule;
-    @dates       = $richseq->get_dates; 
-    $seq_version = $richseq->seq_version;  
+    @dates       = $richseq->get_dates;
+    $seq_version = $richseq->seq_version;
     $pid         = $richseq->pid;
-    $keywords    = $richseq->keywords;
+    @keywords    = $richseq->get_keywords;
 
 =head1 DESCRIPTION
 
@@ -39,24 +39,21 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                 - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Ewan Birney
 
 Email birney@ebi.ac.uk
 
-Describe contact details here
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
@@ -68,11 +65,9 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Seq::RichSeqI;
-use vars qw(@ISA);
 use strict;
-use Bio::SeqI;
 
-@ISA = ('Bio::SeqI');
+use base qw(Bio::SeqI);
 
 
 =head2 get_secondary_accessions
@@ -80,6 +75,11 @@ use Bio::SeqI;
  Title   : get_secondary_accessions
  Usage   : 
  Function: Get the secondary accessions for a sequence.
+
+           An implementation that allows modification of this array
+           property should provide the methods add_secondary_accession
+           and remove_secondary_accessions, with obvious purpose.
+
  Example :
  Returns : an array of strings
  Args    : none
@@ -165,6 +165,11 @@ sub pid {
  Usage   :
  Function: Get (and set, depending on the implementation) the dates the
            databank entry specified for the sequence
+
+           An implementation that allows modification of this array
+           property should provide the methods add_date and
+           remove_dates, with obvious purpose.
+
  Example :
  Returns : an array of strings
  Args    :
@@ -200,18 +205,23 @@ sub seq_version{
 
 }
 
-=head2 keywords
+=head2 get_keywords
 
- Title   : keywords
- Usage   : $obj->keywords($newval)
- Function: 
- Returns : value of keywords (a string)
- Args    : newvalue (optional) (a string)
+ Title   : get_keywords
+ Usage   : $obj->get_keywords()
+ Function: Get the keywords for this sequence object.
+
+           An implementation that allows modification of this array
+           property should provide the methods add_keyword and
+           remove_keywords, with obvious purpose.
+
+ Returns : an array of strings
+ Args    : 
 
 
 =cut
 
-sub keywords {
+sub get_keywords {
    my ($self) = @_;
    $self->throw("hit keywords in interface definition - error");
 }
