@@ -1,4 +1,4 @@
-# $Id: SeqBuilder.pm,v 1.6 2002/10/22 07:45:20 lapp Exp $
+# $Id: SeqBuilder.pm,v 1.9.4.1 2006/10/02 23:10:27 sendu Exp $
 #
 # BioPerl module for Bio::Seq::SeqBuilder
 #
@@ -32,8 +32,8 @@ Bio::Seq::SeqBuilder - Configurable object builder for sequence stream parsers
 
    use Bio::SeqIO;
 
-   # usually you won't instantiate this yourself -- a SeqIO object
-   # will have one already
+   # usually you won't instantiate this yourself - a SeqIO object -
+   # you will have one already
    my $seqin = Bio::SeqIO->new(-fh => \*STDIN, -format => "genbank");
    my $builder = $seqin->sequence_builder();
 
@@ -69,10 +69,11 @@ parsers of rich sequence streams. It provides for a relatively
 easy-to-use configurator of the parsing flow.
 
 Configuring the parsing process may be for you if you need much less
-information, or much less sequences, than the stream actually
+information, or much less sequence, than the stream actually
 contains. Configuration can in both cases speed up the parsing time
 considerably, because unwanted sections or the rest of unwanted
-sequences are skipped over by the parser.
+sequences are skipped over by the parser. This configuration could
+also conserve memory if you're running out of available RAM.
 
 See the methods of the class-specific implementation section for
 further documentation of what can be configured.
@@ -85,26 +86,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+the web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Hilmar Lapp
 
 Email hlapp at gmx.net
 
-=head1 CONTRIBUTORS
-
-Additional contributors names and emails here
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object methods.
@@ -117,15 +113,12 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Seq::SeqBuilder;
-use vars qw(@ISA);
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
 
-use Bio::Root::Root;
-use Bio::Factory::ObjectBuilderI;
 
-@ISA = qw(Bio::Root::Root Bio::Factory::ObjectBuilderI);
+use base qw(Bio::Root::Root Bio::Factory::ObjectBuilderI);
 
 my %slot_param_map = ("add_SeqFeature" => "features",
 		      );
@@ -140,14 +133,13 @@ my %param_slot_map = ("features"       => "add_SeqFeature",
  Returns : an instance of Bio::Seq::SeqBuilder
  Args    :
 
-
 =cut
 
 sub new {
     my($class,@args) = @_;
-    
+
     my $self = $class->SUPER::new(@args);
-    
+
     $self->{'wanted_slots'} = [];
     $self->{'unwanted_slots'} = [];
     $self->{'object_conds'} = [];
@@ -186,34 +178,34 @@ sub new {
 =cut
 
 sub want_slot{
-    my ($self,$slot) = @_;
-    my $ok = 0;
+	my ($self,$slot) = @_;
+	my $ok = 0;
 
-    $slot = substr($slot,1) if substr($slot,0,1) eq '-';
-    if($self->want_all()) {
+	$slot = substr($slot,1) if substr($slot,0,1) eq '-';
+	if($self->want_all()) {
 	foreach ($self->get_unwanted_slots()) {
-	    # this always overrides in want-all mode
-	    return 0 if($slot eq $_);
+		# this always overrides in want-all mode
+		return 0 if($slot eq $_);
 	}
 	if(! exists($self->{'_objskel'})) {
-	    $self->{'_objskel'} = $self->sequence_factory->create_object();
+		$self->{'_objskel'} = $self->sequence_factory->create_object();
 	}
 	if(exists($param_slot_map{$slot})) {
-	    $ok = $self->{'_objskel'}->can($param_slot_map{$slot});
+		$ok = $self->{'_objskel'}->can($param_slot_map{$slot});
 	} else {
-	    $ok = $self->{'_objskel'}->can($slot);
+		$ok = $self->{'_objskel'}->can($slot);
 	}
 	return $ok if $ok;
 	# even if the object 'cannot' do this slot, it might have been
 	# added to the list of wanted slot, so carry on
-    }
-    foreach ($self->get_wanted_slots()) {
-	if($slot eq $_) {
-	    $ok = 1;
-	    last;
+}
+	foreach ($self->get_wanted_slots()) {
+		if($slot eq $_) {
+			$ok = 1;
+			last;
+		}
 	}
-    }
-    return $ok;
+	return $ok;
 }
 
 =head2 add_slot_value
@@ -255,32 +247,31 @@ sub want_slot{
            starting with a dash, and each element at an odd index is
            the value of the preceding name.
 
-
 =cut
 
 sub add_slot_value{
-    my ($self,$slot,@args) = @_;
+	my ($self,$slot,@args) = @_;
 
-    my $h = $self->{'_objhash'};
-    return unless $h;
-    # multiple named parameter variant of calling?
-    if((@args > 1) && (@args % 2) && (substr($slot,0,1) eq '-')) {
-	unshift(@args, $slot);
-	while(@args) {
-	    my $key = shift(@args);
-	    $h->{$key} = shift(@args);
-	}
-    } else {
-	if($slot eq 'add_SeqFeature') {
-	    $slot = '-'.$slot_param_map{$slot};
-	    $h->{$slot} = [] unless $h->{$slot};
-	    push(@{$h->{$slot}}, @args);
+	my $h = $self->{'_objhash'};
+	return unless $h;
+	# multiple named parameter variant of calling?
+	if((@args > 1) && (@args % 2) && (substr($slot,0,1) eq '-')) {
+		unshift(@args, $slot);
+		while(@args) {
+			my $key = shift(@args);
+			$h->{$key} = shift(@args);
+		}
 	} else {
-	    $slot = '-'.$slot unless substr($slot,0,1) eq '-';
-	    $h->{$slot} = $args[0];
+		if($slot eq 'add_SeqFeature') {
+			$slot = '-'.$slot_param_map{$slot};
+			$h->{$slot} = [] unless $h->{$slot};
+			push(@{$h->{$slot}}, @args);
+		} else {
+			$slot = '-'.$slot unless substr($slot,0,1) eq '-';
+			$h->{$slot} = $args[0];
+		}
 	}
-    }
-    return 1;
+	return 1;
 }
 
 =head2 want_object
@@ -303,19 +294,18 @@ sub add_slot_value{
            the present object, and FALSE otherwise.
  Args    : none
 
-
 =cut
 
 sub want_object{
-    my $self = shift;
+	my $self = shift;
 
-    my $ok = 1;
-    foreach my $cond ($self->get_object_conditions()) {
-	$ok = &$cond($self->{'_objhash'});
-	last unless $ok;
-    }
-    delete $self->{'_objhash'} unless $ok;
-    return $ok;
+	my $ok = 1;
+	foreach my $cond ($self->get_object_conditions()) {
+		$ok = &$cond($self->{'_objhash'});
+		last unless $ok;
+	}
+	delete $self->{'_objhash'} unless $ok;
+	return $ok;
 }
 
 =head2 make_object
@@ -338,18 +328,17 @@ sub want_object{
  Returns : the object that was built
  Args    : none
 
-
 =cut
 
 sub make_object{
-    my $self = shift;
+	my $self = shift;
 
-    my $obj;
-    if(exists($self->{'_objhash'}) && %{$self->{'_objhash'}}) {
-	$obj = $self->sequence_factory->create_object(%{$self->{'_objhash'}});
-    }
-    $self->{'_objhash'} = {}; # reset
-    return $obj;
+	my $obj;
+	if(exists($self->{'_objhash'}) && %{$self->{'_objhash'}}) {
+		$obj = $self->sequence_factory->create_object(%{$self->{'_objhash'}});
+	}
+	$self->{'_objhash'} = {}; # reset
+	return $obj;
 }
 
 =head1 Implementation specific methods
@@ -393,9 +382,9 @@ in the wanted and the unwanted lists.
 =cut
 
 sub get_wanted_slots{
-    my $self = shift;
+	my $self = shift;
 
-    return @{$self->{'wanted_slots'}};
+	return @{$self->{'wanted_slots'}};
 }
 
 =head2 add_wanted_slot
@@ -407,19 +396,18 @@ sub get_wanted_slots{
  Returns : TRUE
  Args    : an array of slot names (strings)
 
-
 =cut
 
 sub add_wanted_slot{
-    my ($self,@slots) = @_;
+	my ($self,@slots) = @_;
 
-    my $myslots = $self->{'wanted_slots'};
-    foreach my $slot (@slots) {
-	if(! grep { $slot eq $_; } @$myslots) {
-	    push(@$myslots, $slot);
+	my $myslots = $self->{'wanted_slots'};
+	foreach my $slot (@slots) {
+		if(! grep { $slot eq $_; } @$myslots) {
+			push(@$myslots, $slot);
+		}
 	}
-    }
-    return 1;
+	return 1;
 }
 
 =head2 remove_wanted_slots
@@ -432,14 +420,13 @@ sub add_wanted_slot{
  Returns : the previous list of wanted slot names
  Args    : none
 
-
 =cut
 
 sub remove_wanted_slots{
-    my $self = shift;
-    my @slots = $self->get_wanted_slots();
-    $self->{'wanted_slots'} = [];
-    return @slots;
+	my $self = shift;
+	my @slots = $self->get_wanted_slots();
+	$self->{'wanted_slots'} = [];
+	return @slots;
 }
 
 =head2 get_unwanted_slots
@@ -451,13 +438,12 @@ sub remove_wanted_slots{
  Returns : a list of strings
  Args    : none
 
-
 =cut
 
 sub get_unwanted_slots{
-    my $self = shift;
+	my $self = shift;
 
-    return @{$self->{'unwanted_slots'}};
+	return @{$self->{'unwanted_slots'}};
 }
 
 =head2 add_unwanted_slot
@@ -469,19 +455,18 @@ sub get_unwanted_slots{
  Returns : TRUE
  Args    : an array of slot names (strings)
 
-
 =cut
 
 sub add_unwanted_slot{
-    my ($self,@slots) = @_;
+	my ($self,@slots) = @_;
 
-    my $myslots = $self->{'unwanted_slots'};
-    foreach my $slot (@slots) {
-	if(! grep { $slot eq $_; } @$myslots) {
-	    push(@$myslots, $slot);
+	my $myslots = $self->{'unwanted_slots'};
+	foreach my $slot (@slots) {
+		if(! grep { $slot eq $_; } @$myslots) {
+			push(@$myslots, $slot);
+		}
 	}
-    }
-    return 1;
+	return 1;
 }
 
 =head2 remove_unwanted_slots
@@ -494,14 +479,13 @@ sub add_unwanted_slot{
  Returns : the previous list of unwanted slot names
  Args    : none
 
-
 =cut
 
 sub remove_unwanted_slots{
-    my $self = shift;
-    my @slots = $self->get_unwanted_slots();
-    $self->{'unwanted_slots'} = [];
-    return @slots;
+	my $self = shift;
+	my @slots = $self->get_unwanted_slots();
+	$self->{'unwanted_slots'} = [];
+	return @slots;
 }
 
 =head2 want_none
@@ -520,16 +504,15 @@ sub remove_unwanted_slots{
  Returns : TRUE
  Args    : none
 
-
 =cut
 
 sub want_none{
-    my $self = shift;
+	my $self = shift;
 
-    $self->want_all(0);
-    $self->remove_wanted_slots();
-    $self->remove_unwanted_slots();
-    return 1;
+	$self->want_all(0);
+	$self->remove_wanted_slots();
+	$self->remove_unwanted_slots();
+	return 1;
 }
 
 =head2 want_all
@@ -550,14 +533,13 @@ sub want_none{
            FALSE otherwise.
  Args    : on set, new value (a scalar or undef, optional)
 
-
 =cut
 
 sub want_all{
-    my $self = shift;
+	my $self = shift;
 
-    return $self->{'want_all'} = shift if @_;
-    return $self->{'want_all'};
+	return $self->{'want_all'} = shift if @_;
+	return $self->{'want_all'};
 }
 
 =head2 get_object_conditions
@@ -579,13 +561,12 @@ sub want_all{
  Returns : a list of closures
  Args    : none
 
-
 =cut
 
 sub get_object_conditions{
-    my $self = shift;
+	my $self = shift;
 
-    return @{$self->{'object_conds'}};
+	return @{$self->{'object_conds'}};
 }
 
 =head2 add_object_condition
@@ -608,18 +589,17 @@ sub get_object_conditions{
  Returns : TRUE
  Args    : the list of conditions
 
-
 =cut
 
 sub add_object_condition{
-    my ($self,@conds) = @_;
+	my ($self,@conds) = @_;
 
-    if(grep { ref($_) ne 'CODE'; } @conds) {
-	$self->throw("conditions against which to validate an object ".
-		     "must be anonymous code blocks");
-    }
-    push(@{$self->{'object_conds'}}, @conds);
-    return 1;
+	if(grep { ref($_) ne 'CODE'; } @conds) {
+		$self->throw("conditions against which to validate an object ".
+						 "must be anonymous code blocks");
+	}
+	push(@{$self->{'object_conds'}}, @conds);
+	return 1;
 }
 
 =head2 remove_object_conditions
@@ -632,14 +612,13 @@ sub add_object_condition{
  Returns : The list of previously set conditions (an array of closures)
  Args    : none
 
-
 =cut
 
 sub remove_object_conditions{
-    my $self = shift;
-    my @conds = $self->get_object_conditions();
-    $self->{'object_conds'} = [];
-    return @conds;
+	my $self = shift;
+	my @conds = $self->get_object_conditions();
+	$self->{'object_conds'} = [];
+	return @conds;
 }
 
 =head1 Methods to control what type of object is built
@@ -657,17 +636,16 @@ sub remove_object_conditions{
  Args    : on set, new value (a Bio::Factory::SequenceFactoryI
            implementing object or undef, optional)
 
-
 =cut
 
 sub sequence_factory{
-    my $self = shift;
+	my $self = shift;
 
-    if(@_) {
-	delete $self->{'_objskel'};
-	return $self->{'sequence_factory'} = shift;
-    }
-    return $self->{'sequence_factory'};
+	if(@_) {
+		delete $self->{'_objskel'};
+		return $self->{'sequence_factory'} = shift;
+	}
+	return $self->{'sequence_factory'};
 }
 
 1;
