@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Exon.pm,v 1.15.4.1 2006/10/02 23:10:28 sendu Exp $
 #
 # BioPerl module for Bio::SeqFeature::Gene::Exon
 #
@@ -24,11 +24,13 @@ Bio::SeqFeature::Gene::Exon - a feature representing an exon
 
 =head1 DESCRIPTION
 
-This module implements a feature representing an exon by implementing the
-Bio::SeqFeature::Gene::ExonI interface. 
+This module implements a feature representing an exon by implementing
+the Bio::SeqFeature::Gene::ExonI interface. By default an Exon is
+coding. Supply -is_coding =E<gt> 0 to the constructor or call
+$exon-E<gt>is_coding(0) otherwise.
 
-Apart from that, this class also implements Bio::SeqFeatureI by inheriting
-off Bio::SeqFeature::Generic.
+Apart from that, this class also implements Bio::SeqFeatureI by
+inheriting off Bio::SeqFeature::Generic.
 
 =head1 FEEDBACK
 
@@ -39,24 +41,21 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org          - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Hilmar Lapp
 
 Email hlapp@gmx.net
 
-Describe contact details here
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object methods.
@@ -69,13 +68,10 @@ Internal methods are usually preceded with a _
 
 
 package Bio::SeqFeature::Gene::Exon;
-use vars qw(@ISA);
 use strict;
 
-use Bio::SeqFeature::Generic;
-use Bio::SeqFeature::Gene::ExonI;
 
-@ISA = qw(Bio::SeqFeature::Generic Bio::SeqFeature::Gene::ExonI);
+use base qw(Bio::SeqFeature::Generic Bio::SeqFeature::Gene::ExonI);
 
 #
 # A list of allowed exon types. See primary_tag().
@@ -85,11 +81,11 @@ my @valid_exon_types = ('initial', 'internal', 'terminal');
 sub new {
     my ($caller, @args) = @_;
     my $self = $caller->SUPER::new(@args);
-    my ($primary) =
-	$self->_rearrange([qw(PRIMARY)],@args);
 
-    $primary = 'exon' unless $primary;
-    $self->primary_tag($primary); # this will also set is_coding()
+    my ($is_coding) =
+	$self->_rearrange([qw(IS_CODING)],@args);
+    $self->primary_tag('exon') unless $self->primary_tag();
+    $self->is_coding(defined($is_coding) ? $is_coding : 1);
     $self->strand(0) if(! defined($self->strand()));
     return $self;
 }
@@ -213,7 +209,7 @@ sub cds {
     my ($self) = @_;
 
     # UTR is not translated
-    return undef if(! $self->is_coding());
+    return if(! $self->is_coding());
 
     my $seq = $self->seq();
     if(defined($seq) && defined($self->frame()) && ($self->frame() != 0)) {
