@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Promoter.pm,v 1.8.4.1 2006/10/02 23:10:28 sendu Exp $
 #
 # BioPerl module for Bio::SeqFeature::Gene::Promoter
 #
@@ -12,7 +12,7 @@
 
 =head1 NAME
 
-Bio::SeqFeature::Gene::Promoter - Describes a promotor      
+Bio::SeqFeature::Gene::Promoter - Describes a promoter      
 
 =head1 SYNOPSIS
 
@@ -30,28 +30,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - David Block
 
 Email dblock@gene.pbi.nrc.ca
 
-Describe contact details here
-
-=head1 CONTRIBUTORS
-
-Additional contributors names and emails here
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object methods.
@@ -64,14 +57,12 @@ Internal methods are usually preceded with a _
 
 
 package Bio::SeqFeature::Gene::Promoter;
-use vars qw(@ISA);
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
 
-use Bio::SeqFeature::Gene::NC_Feature;
 
-@ISA = qw(Bio::SeqFeature::Gene::NC_Feature);
+use base qw(Bio::SeqFeature::Gene::NC_Feature);
 
 sub new {
   my($class,@args) = @_;
