@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Similarity.pm,v 1.16.4.1 2006/10/02 23:10:28 sendu Exp $
 #
 # BioPerl module for Bio::SeqFeature::Similarity
 #
@@ -38,27 +38,25 @@ and other Bioperl modules. Send your comments and suggestions preferably
  to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
-  bioperl-l@bioperl.org          - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Hilmar Lapp
 
 Email hlapp@gmx.net or hilmar.lapp@pharma.novartis.com
 
-Describe contact details here
-
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -67,24 +65,22 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::SeqFeature::Similarity;
-use vars qw(@ISA);
 use strict;
 
-use Bio::SeqFeature::Generic;
 
-@ISA = qw(Bio::SeqFeature::Generic);
+use base qw(Bio::SeqFeature::Generic);
 
 sub new {
-    my ( $caller, @args) = @_;   
-    my ($self) = $caller->SUPER::new(@args); 
+    my ( $caller, @args) = @_;
+    my ($self) = $caller->SUPER::new(@args);
 
     my ($primary,$evalue, $bits, $frac,$seqlen,$seqdesc) =
 	$self->_rearrange([qw(PRIMARY
 			      EXPECT
 			      BITS
 			      FRAC
+			      SEQLENGTH
 			      SEQDESC
-			      SEQLENGTH				      
 			      )],@args);
 
     defined $evalue && $self->significance($evalue);
@@ -112,9 +108,7 @@ sub new {
 =cut
 
 sub significance {
-    my ($self, $value) = @_;
-
-    return $self->_tag_value('signif', $value);
+    return shift->_tag_value('signif', @_);
 }
 
 =head2 bits
@@ -130,9 +124,7 @@ sub significance {
 =cut
 
 sub bits {
-    my ($self, $value) = @_;
-
-    return $self->_tag_value('Bits', $value);
+    return shift->_tag_value('Bits', @_);
 }
 
 =head2 frac_identical
@@ -148,9 +140,7 @@ sub bits {
 =cut
 
 sub frac_identical {
-    my ($self, $value) = @_;
-
-    return $self->_tag_value('FracId', $value);
+    return shift->_tag_value('FracId', @_);
 }
 
 =head2 seqlength
@@ -166,9 +156,7 @@ sub frac_identical {
 =cut
 
 sub seqlength {
-    my ($self, $value) = @_;
-
-    return $self->_tag_value('SeqLength', $value);
+    return shift->_tag_value('SeqLength', @_);
 }
 
 =head2 seqdesc
