@@ -1,4 +1,4 @@
-# $Id$
+# $Id: MultiFile.pm,v 1.12.4.1 2006/10/02 23:10:28 sendu Exp $
 #
 # BioPerl module for Bio::SeqIO::MultiFile
 #
@@ -31,29 +31,25 @@ set of identically formatted sequence input files as a single stream.
 
 =head2 Mailing Lists
 
-User feedback is an integral part of the evolution of this
-and other Bioperl modules. Send your comments and suggestions preferably
- to one of the Bioperl mailing lists.
-Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other
+Bioperl modules. Send your comments and suggestions preferably to one
+of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                 - General discussion
-  http://www.bioperl.org/MailList.shtml - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.
+Bug reports can be submitted via the web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Ewan Birney
 
 Email birney@ebi.ac.uk
 
-Describe contact details here
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
@@ -66,10 +62,8 @@ The rest of the documentation details each of the object methods. Internal metho
 
 package Bio::SeqIO::MultiFile;
 use strict;
-use vars qw(@ISA);
-use Bio::SeqIO;
 
-@ISA = qw(Bio::SeqIO);
+use base qw(Bio::SeqIO);
 
 
 # _initialize is where the heavy stuff will happen when new is called
@@ -108,7 +102,7 @@ sub _initialize {
  Usage   :
  Function:
  Example :
- Returns : 
+ Returns :
  Args    :
 
 
@@ -120,14 +114,14 @@ sub next_seq{
    my $seq = $self->_current_seqio->next_seq();
    if( !defined $seq ) {
        if( $self->_load_file() == 0) {
-	   return undef;
+	   return;
        } else {
 	   return $self->next_seq();
        }
    } else {
        return $seq;
    }
-   
+
 }
 
 =head2 next_primary_seq
@@ -136,7 +130,7 @@ sub next_seq{
  Usage   :
  Function:
  Example :
- Returns : 
+ Returns :
  Args    :
 
 
@@ -148,7 +142,7 @@ sub next_primary_seq{
    my $seq = $self->_current_seqio->next_primary_seq();
    if( !defined $seq ) {
        if( $self->_load_file() == 0) {
-	   return undef;
+	   return;
        } else {
 	   return $self->next_primary_seq();
        }
@@ -164,7 +158,7 @@ sub next_primary_seq{
  Usage   :
  Function:
  Example :
- Returns : 
+ Returns :
  Args    :
 
 
@@ -193,7 +187,7 @@ sub _load_file{
  Usage   :
  Function:
  Example :
- Returns : 
+ Returns :
  Args    :
 
 
@@ -203,15 +197,15 @@ sub _set_file{
    my ($self,@files) = @_;
 
    push(@{$self->{'_file_array'}},@files);
-   
+
 }
 
 =head2 _current_seqio
 
  Title   : _current_seqio
  Usage   : $obj->_current_seqio($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of _current_seqio
  Args    : newvalue (optional)
 
@@ -231,8 +225,8 @@ sub _current_seqio{
 
  Title   : _format
  Usage   : $obj->_format($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of _format
  Args    : newvalue (optional)
 
