@@ -1,4 +1,4 @@
-# $Id$
+# $Id: locuslink.pm,v 1.12.4.1 2006/10/02 23:10:29 sendu Exp $
 #
 # BioPerl module for Bio::SeqIO::locuslink
 #
@@ -26,7 +26,7 @@
 
 =head1 NAME
 
-Bio::SeqIO::locuslink - DESCRIPTION of Object
+Bio::SeqIO::locuslink - LocusLink input/output stream
 
 =head1 SYNOPSIS
 
@@ -43,12 +43,13 @@ will not work.
 
 The way the current implementation populates the object is rather a
 draft work than a finished work of art. Note that at this stage the
-locuslink entries cannot be round-tripped, because the parser loses
+LocusLink entries cannot be round-tripped, because the parser loses
 certain information. For instance, most of the alternative transcript
 descriptions are not retained. The parser also misses any element
 that deals with visual representation (e.g., 'button') except for the
-URLs. Almost all of the pieces of the annotation are kept in the
-L<Bio::Annotation::Collection> object.
+URLs. Almost all of the pieces of the annotation are kept in a
+Bio::Annotation::Collection object, see L<Bio::Annotation::Collection>
+for more information.
 
 =head1 FEEDBACK
 
@@ -58,24 +59,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via 
+the web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Keith Ching
 
 Email kching at gnf.org
 
-Describe contact details here
-
 =head1 CONTRIBUTORS
 
 Hilmar Lapp, hlapp at gmx.net
@@ -90,9 +88,7 @@ Internal methods are usually preceded with a _
 package Bio::SeqIO::locuslink;
 
 use strict;
-use vars qw(@ISA);
 
-use Bio::SeqIO;
 use Bio::Seq::SeqFactory;
 use Bio::Species;
 use Bio::Annotation::DBLink;
@@ -102,7 +98,7 @@ use Bio::Annotation::SimpleValue;
 use Bio::Annotation::OntologyTerm;
 use Bio::Annotation::Collection;
 
-@ISA = qw(Bio::SeqIO);
+use base qw(Bio::SeqIO);
 
 # list of all the field names in locuslink
 my @locuslink_keys = qw(
@@ -249,12 +245,12 @@ my @ll_firstelements = qw(
 # these fields need to be flattened into a single string, using the given
 # join string
 my %flatten_tags = (
-		    ASSEMBLY            => '',
-		    ORGANISM            => '',
-		    OFFICIAL_SYMBOL     => '',
-		    OFFICIAL_GENE_NAME  => '',
-		    LOCUSID             => '',
-		    PMID                => '',
+		    ASSEMBLY            => ',',
+		    ORGANISM            => '',  # this should occur only once
+		    OFFICIAL_SYMBOL     => '',  # this should occur only once
+		    OFFICIAL_GENE_NAME  => '',  # this should occur only once
+		    LOCUSID             => '',  # this should occur only once
+		    PMID                => ',',
 		    PREFERRED_SYMBOL    => ', ',
 		    PREFERRED_GENE_NAME => ', '
 );
@@ -406,7 +402,7 @@ sub make_unique{
     
     my %seen = ();
     foreach my $dbl ($ann->remove_Annotations($key)) {
-	if(! $seen{$dbl->as_text()}) {
+	if(!exists($seen{$dbl->as_text()})) {
 	    $seen{$dbl->as_text()} = 1;
 	    $ann->add_Annotation($dbl);
 	} 
@@ -428,7 +424,7 @@ sub next_seq{
 	# slurp in a whole entry and return if no more entries
 	return unless my $entry = $self->_readline;
 
-	# strip the leading '>>' is it's the first entry
+	# strip the leading '>>' if it's the first entry
 	if (index($entry,'>>') == 0) { #first entry
 	    $entry = substr($entry,2);
 	}
@@ -514,9 +510,6 @@ sub next_seq{
 	$ann=add_annotation_ref($ann,'URL',$record{LINK});
 	$ann=add_annotation_ref($ann,'URL',$record{DB_LINK});
 
-	# presently we can't store types of dblinks - hence make unique
-	make_unique($ann,'dblink');
-
 	# everything else gets a simple tag or comment value annotation
 	foreach my $anntype (keys %anntype_map) {
 	    foreach my $key (@{$anntype_map{$anntype}}){
@@ -551,6 +544,10 @@ sub next_seq{
 	    }
 	}
 
+	# presently we can't store types or context of dblinks - therefore
+	# we need to remove duplicates that only differ in context
+	make_unique($ann,'dblink');
+
 	# create sequence object (i.e., let seq.factory create one)
 	my $seq = $self->sequence_factory->create(
 			     -verbose => $self->verbose(),
