@@ -9,6 +9,7 @@
 # You may distribute this module under the same terms as perl itself
 #
 # POD documentation - main docs before the code
+
 =head1 NAME
 
 Bio::Structure::SecStr::STRIDE::Res - Module for parsing/accessing stride output
@@ -96,17 +97,16 @@ UsUser feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org          - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bio.perl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Ed Green
 
@@ -123,12 +123,10 @@ Internal methods are preceded with a _.
 
 package Bio::Structure::SecStr::STRIDE::Res;
 use strict;
-use vars qw(@ISA);
-use Bio::Root::Root;
 use Bio::Root::IO;
 use Bio::PrimarySeq;
 
-@ISA = qw(Bio::Root::Root);
+use base qw(Bio::Root::Root);
 
 our %ASGTable = ( 'aa'         =>  0,
 		  'resNum'     =>  1,
