@@ -1,4 +1,4 @@
-# $Id$
+# $Id: ProteinAlphabet.pm,v 1.7.2.1 2006/10/02 23:10:31 sendu Exp $
 #
 # BioPerl module for Bio::Symbol::ProteinAlphabet
 #
@@ -34,28 +34,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Jason Stajich
 
 Email jason@bioperl.org
 
-Describe contact details here
-
-=head1 CONTRIBUTORS
-
-Additional contributors names and emails here
-
 =head1 APPENDIX
 
 The rest of the documentation details each of the object methods.
@@ -68,15 +61,13 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Symbol::ProteinAlphabet;
-use vars qw(@ISA);
 use strict;
 
-use Bio::Symbol::Alphabet;
 use Bio::Symbol::Symbol;
 use Bio::Tools::IUPAC;
 use Bio::SeqUtils;
 
-@ISA = qw(Bio::Symbol::Alphabet);
+use base qw(Bio::Symbol::Alphabet);
 
 =head2 new
 
@@ -98,7 +89,6 @@ sub new {
   my @left;
   
   foreach my $let ( keys %codes  ) {  
-      next if( $let eq 'U');
       if( scalar @{$codes{$let}} != 1) { push @left, $let; next; }
       $symbols{$let} = new Bio::Symbol::Symbol(-name => $aa{$let},
 					       -token => $let);      
