@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Tree.pm,v 1.3.4.1 2006/10/02 23:10:31 sendu Exp $
 #
 # BioPerl module for Bio::Taxonomy::Tree
 #
@@ -14,6 +14,9 @@ Bio::Taxonomy::Tree - An Organism Level Implementation of TreeI interface.
 
 =head1 SYNOPSIS
 
+    NB: This module is deprecated. Use Bio::Taxon in combination with
+    Bio::Tree::Tree instead
+
     # like from a TreeIO
     my $treeio = new Bio::TreeIO(-format => 'newick', -file => 'treefile.dnd');
     my $tree = $treeio->next_tree;
@@ -28,64 +31,63 @@ This object holds handles to Taxonomic Nodes which make up a tree.
 
 =head1 EXAMPLES
 
-              use Bio::Species;
-              use Bio::Taxonomy::Tree;
+  use Bio::Species;
+  use Bio::Taxonomy::Tree;
 
-              my $human=new Bio::Species;
-              my $chimp=new Bio::Species;
-              my $bonobo=new Bio::Species;
+  my $human=new Bio::Species;
+  my $chimp=new Bio::Species;
+  my $bonobo=new Bio::Species;
 
-              $human->classification(qw( sapiens Homo Hominidae
-                                         Catarrhini Primates Eutheria
-                                         Mammalia Euteleostomi Vertebrata 
-                                         Craniata Chordata
-                                         Metazoa Eukaryota ));
-              $chimp->classification(qw( troglodytes Pan Hominidae
-                                         Catarrhini Primates Eutheria
-                                         Mammalia Euteleostomi Vertebrata 
-                                         Craniata Chordata
-                                         Metazoa Eukaryota ));
-              $bonobo->classification(qw( paniscus Pan Hominidae
-                                          Catarrhini Primates Eutheria
-                                          Mammalia Euteleostomi Vertebrata 
-                                          Craniata Chordata
-                                          Metazoa Eukaryota ));
+  $human->classification(qw( sapiens Homo Hominidae
+                             Catarrhini Primates Eutheria
+                             Mammalia Euteleostomi Vertebrata 
+                             Craniata Chordata
+                             Metazoa Eukaryota ));
+  $chimp->classification(qw( troglodytes Pan Hominidae
+                             Catarrhini Primates Eutheria
+                             Mammalia Euteleostomi Vertebrata 
+                             Craniata Chordata
+                             Metazoa Eukaryota ));
+  $bonobo->classification(qw( paniscus Pan Hominidae
+                              Catarrhini Primates Eutheria
+                              Mammalia Euteleostomi Vertebrata 
+                              Craniata Chordata
+                              Metazoa Eukaryota ));
 
-              # ranks passed to $taxonomy match ranks of species
-              my @ranks = ('superkingdom','kingdom','phylum','subphylum',
-                           'no rank 1','no rank 2','class','no rank 3','order',
-                           'suborder','family','genus','species');
+  # ranks passed to $taxonomy match ranks of species
+  my @ranks = ('superkingdom','kingdom','phylum','subphylum',
+               'no rank 1','no rank 2','class','no rank 3','order',
+               'suborder','family','genus','species');
 
-              my $taxonomy=new Bio::Taxonomy(-ranks => \@ranks,
-                                             -method => 'trust',
-                                             -order => -1);
+  my $taxonomy=new Bio::Taxonomy(-ranks => \@ranks,
+                                 -method => 'trust',
+                                 -order => -1);
 
-              my @nodes;
 
-              my $tree1=new Bio::Taxonomy::Tree;
-              my $tree2=new Bio::Taxonomy::Tree;
+  my $tree1=new Bio::Taxonomy::Tree;
+  my $tree2=new Bio::Taxonomy::Tree;
 
-              push @nodes,$tree1->make_species_branch($human,$taxonomy);
-              push @nodes,$tree2->make_species_branch($chimp,$taxonomy);
+  $tree1->make_species_branch($human,$taxonomy);
+  $tree2->make_species_branch($chimp,$taxonomy);
 
-              my ($homo_sapiens)=$tree1->get_leaves;
+  my ($homo_sapiens)=$tree1->get_leaves;
 
-              $tree1->splice($tree2);
+  $tree1->splice($tree2);
 
-              push @nodes,$tree1->add_species($bonobo,$taxonomy);
+  $tree1->add_species($bonobo,$taxonomy);
 
-              my @taxa;
-              foreach my $leaf ($tree1->get_leaves) {
-                 push @taxa,$leaf->taxon;
-              }
-              print join(", ",@taxa)."\n";
+  my @taxa;
+  foreach my $leaf ($tree1->get_leaves) {
+     push @taxa,$leaf->taxon;
+  }
+  print join(", ",@taxa)."\n";
 
-              @taxa=();
-              $tree1->remove_branch($homo_sapiens);
-              foreach my $leaf ($tree1->get_leaves) {
-                 push @taxa,$leaf->taxon;
-              }
-              print join(", ",@taxa)."\n";
+  @taxa=();
+  $tree1->remove_branch($homo_sapiens);
+  foreach my $leaf ($tree1->get_leaves) {
+     push @taxa,$leaf->taxon;
+  }
+  print join(", ",@taxa)."\n";
 
 =head1 FEEDBACK
 
@@ -111,20 +113,16 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Taxonomy::Tree;
-use vars qw(@ISA);
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
 
-use Bio::Root::Root;
-use Bio::Tree::TreeFunctionsI;
-use Bio::Tree::TreeI;
 use Bio::Taxonomy::Taxon;
 
 # Import rank information from Bio::Taxonomy.pm
 use vars qw(@RANK %RANK);
 
-@ISA = qw(Bio::Root::Root Bio::Tree::TreeI Bio::Tree::TreeFunctionsI);
+use base qw(Bio::Root::Root Bio::Tree::TreeI Bio::Tree::TreeFunctionsI);
 
 =head2 new
 
@@ -141,6 +139,8 @@ sub new {
   my($class,@args) = @_;
   
   my $self = $class->SUPER::new(@args);
+  $self->warn("Bio::Taxonomy::Tree is deprecated. Use Bio::Taxon in combination with Bio::Tree::Tree instead.");
+  
   $self->{'_rootnode'} = undef;
   $self->{'_maxbranchlen'} = 0;
 
