@@ -45,7 +45,7 @@ Bio::Tools::BPlite::HSP - Blast report High Scoring Pair (HSP)
 	    $hsp->query->end;
 	    $hsp->hit->start;
 	    $hsp->hit->end;
-	    $hsp->hit->seqname;
+	    $hsp->hit->seq_id;
 	    $hsp->hit->overlaps($exon);
 	}
     }
@@ -55,7 +55,7 @@ Bio::Tools::BPlite::HSP - Blast report High Scoring Pair (HSP)
     # but that is valid for an empty blast report.
     # Returns -1 for EOF.
 
-    last if ($report->_parseHeader == -1));
+    last if $report->_parseHeader == -1;
 
  redo
  }
@@ -77,17 +77,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org            - General discussion
-http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+email the web:
 
-  bioperl-bugs@bioperl.org
-  http://bioperl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Peter Schattner
 
@@ -108,7 +107,6 @@ Internal methods are usually preceded with a _
 
 package Bio::Tools::BPlite::HSP;
 
-use vars qw(@ISA);
 use strict;
 
 # to disable overloading comment this out:
@@ -116,10 +114,9 @@ use strict;
 
 # Object preamble - inheriets from Bio::SeqFeature::SimilarityPair
 
-use Bio::SeqFeature::SimilarityPair;
 use Bio::SeqFeature::Similarity;
 
-@ISA = qw(Bio::SeqFeature::SimilarityPair);
+use base qw(Bio::SeqFeature::SimilarityPair);
 
 sub new {
     my ($class, @args) = @_;
@@ -140,8 +137,9 @@ sub new {
 
     my $self = $class->SUPER::new(%newargs);
     
-    my ($score,$bits,$match,$hsplength,$positive,$gaps,$p,$qb,$qe,$sb,$se,$qs,
-	$ss,$hs,$qname,$sname,$qlength,$slength,$qframe,$sframe,$blasttype) = 
+    my ($score,$bits,$match,$hsplength,$positive,$gaps,$p,$exp,$qb,$qe,$sb,
+	$se,$qs,$ss,$hs,$qname,$sname,$qlength,$slength,$qframe,$sframe,
+	$blasttype) = 
 	    $self->_rearrange([qw(SCORE
 				  BITS
 				  MATCH
@@ -149,6 +147,7 @@ sub new {
 				  POSITIVE
 				  GAPS				  
 				  P
+				  EXP
 				  QUERYBEGIN
 				  QUERYEND
 				  SBJCTBEGIN
@@ -206,8 +205,8 @@ sub new {
 			 -source=>"BLAST" ) ) }
     
     # name the sequences
-    $self->query->seqname($qname); # query name
-    $self->hit->seqname($sname);   # hit name
+    $self->query->seq_id($qname); # query name
+    $self->hit->seq_id($sname);   # hit name
 
     # set lengths
     $self->query->seqlength($qlength); # query length
@@ -216,7 +215,10 @@ sub new {
     # set object vars
     $self->score($score);
     $self->bits($bits);
+
     $self->significance($p);
+    $self->{'EXP'} = $exp;
+    
     $self->query->frac_identical($match);
     $self->hit->frac_identical($match);
     $self->{'HSPLENGTH'} = $hsplength;
@@ -260,12 +262,28 @@ sub report_type {
     return $self->{'_report_type'};
 }
 
+=head2 EXP
+
+ Title   : EXP
+ Usage   : my $exp = $hsp->EXP;
+ Function: returns the EXP value for the HSP
+ Returns : string value
+ Args    : none
+ Note    : Patch provided by Sami Ashour for BTK parsing
+
+
+=cut
+
+sub EXP{
+    return $_[0]->{'EXP'};
+}
+
+
 =head2 P
 
  Title    : P
  Usage    : $hsp->P();
  Function : returns the P (significance) value for a HSP 
- Example  : 
  Returns  : (double) significance value
  Args     :
 
