@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Iteration.pm,v 1.18.4.1 2006/10/02 23:10:33 sendu Exp $
 # Bioperl module Bio::Tools::BPlite::Iteration
 #	based closely on the Bio::Tools::BPlite modules
 #	Ian Korf (ikorf@sapiens.wustl.edu, http://sapiens.wustl.edu/~ikorf), 
@@ -21,9 +21,9 @@ of a PSIBLAST report
 
 =head1 SYNOPSIS
 
-   use Bio::Tools:: BPpsilite;
+   use Bio::Tools::BPpsilite;
 
-   open FH, "t/psiblastreport.out";
+   open my $FH, "t/psiblastreport.out";
    $report = Bio::Tools::BPpsilite->new(-fh=>\*FH);
 
    # determine number of iterations executed by psiblast
@@ -89,12 +89,10 @@ This software is provided "as is" without warranty of any kind.
 package Bio::Tools::BPlite::Iteration;
 
 use strict;
-use vars qw(@ISA);
-use Bio::Root::Root; # root object to inherit from
 use Bio::Tools::BPlite; #
 use Bio::Tools::BPlite::Sbjct;
 
-@ISA = qw(Bio::Root::Root);
+use base qw(Bio::Root::Root);
 
 sub new {
     my ($class, @args) = @_;
@@ -178,46 +176,47 @@ sub  oldhits  {shift->{'OLDHITS'}}
 =cut
 
 sub nextSbjct {
-  my ($self) = @_;
-  $self->_fastForward or return undef;
- 
-  #######################
-  # get all sbjct lines #
-  #######################
-  my $def = $self->_readline();
+    my ($self) = @_;
+    $self->_fastForward or return;
 
-  while(defined ($_ = $self->_readline) )  {
-    if    ($_ !~ /\w/)            {next}
-    elsif ($_ =~ /Strand HSP/)    {next} # WU-BLAST non-data
-    elsif ($_ =~ /^\s{0,2}Score/) {$self->_pushback( $_); last}
-    elsif ($_ =~ /^(\d+) .* \d+$/) {   # This is not correct at all
-       $self->_pushback($_);           # 1: HSP does not work for -m 6 flag
-       $def = $1;                      # 2: length/name are incorrect     
-       my $length = undef;	       # 3: Names are repeated many times.
-       my $sbjct = new Bio::Tools::BPlite::Sbjct('-name'=>$def,
-						 '-length'=>$length,
-						 '-parent'=>$self);
-       return $sbjct;
-   } # m-6 
-    elsif ($_ =~ /^Parameters|^\s+Database:|^\s+Posted date:/) {
-	$self->_pushback( $_); 
-	last;
-    } else {$def .= $_}
-}
-  $def =~ s/\s+/ /g;
-  $def =~ s/\s+$//g;
-  $def =~ s/Length = ([\d,]+)$//g;
-  my $length = $1;
-  return 0 unless $def =~ /^>/;
-  $def =~ s/^>//;
-  
-  ####################
-  # the Sbjct object #
-  ####################
-  my $sbjct = new Bio::Tools::BPlite::Sbjct('-name'=>$def,
-					    '-length'=>$length,
-					    '-parent'=>$self);
-  return $sbjct;
+    #######################
+    # get all sbjct lines #
+    #######################
+    my $def = $self->_readline();
+
+    while(defined ($_ = $self->_readline) )  {
+	if    ($_ !~ /\w/)            {next}
+	elsif ($_ =~ /Strand HSP/)    {next} # WU-BLAST non-data
+	elsif ($_ =~ /^\s{0,2}Score/) {$self->_pushback( $_); last}
+	elsif ($_ =~ /^(\d+) .* \d+$/) { # This is not correct at all
+	    $self->_pushback($_); # 1: HSP does not work for -m 6 flag
+	    $def = $1;		  # 2: length/name are incorrect     
+	    my $length = undef;	  # 3: Names are repeated many times.
+	    my $sbjct = new Bio::Tools::BPlite::Sbjct('-name'=>$def,
+						      '-length'=>$length,
+						      '-parent'=>$self);
+	    return $sbjct;
+	}			# m-6 
+	elsif ($_ =~ /^Parameters|^\s+Database:|^\s+Posted date:/) {
+	    $self->_pushback( $_); 
+	    last;
+	} else {$def .= $_}
+    }
+    $def = '' unless defined $def;
+    $def =~ s/\s+/ /g;
+    $def =~ s/\s+$//g;
+    $def =~ s/Length = ([\d,]+)$//g;
+    my $length = $1;
+    return 0 unless $def =~ /^>/;
+    $def =~ s/^>//;
+
+    ####################
+    # the Sbjct object #
+    ####################
+    my $sbjct = new Bio::Tools::BPlite::Sbjct('-name'=>$def,
+					      '-length'=>$length,
+					      '-parent'=>$self);
+    return $sbjct;
 }
 
 
@@ -238,9 +237,9 @@ sub nextSbjct {
 sub Align {
     use Bio::SimpleAlign;
     my ($self) = @_;
-    $self->_fastForward or return undef;
+    $self->_fastForward or return;
     my $lastline = $self->_readline();
-    return undef unless $lastline =~ /^QUERY/; # If psiblast not run correctly
+    return unless $lastline =~ /^QUERY/; # If psiblast not run correctly
     my (%sequence,%first,%last,$num);
 
     if ( $lastline =~ /^QUERY\s+(\d*)\s*([-\w]+)\s*(\d*)\s*$/){
