@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Set.pm,v 1.15.4.1 2006/10/02 23:10:33 sendu Exp $
 #
 # BioPerl module for Bio::Tools::HMMER::Set
 #
@@ -39,26 +39,23 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                - General discussion
-  http://www.bioperl.org/MailList.html - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.
-
-Bug reports can be submitted via email or the web:
-
-  bioperl-bugs@bioperl.org
-  http://www.bugzilla.bioperl.org/
+the bugs and their resolution.Bug reports can be submitted via the
+web: http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Ewan Birney
 
-Email birney@sanger.ac.uk
+Email birney-at-ebi.ac.uk
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -67,13 +64,11 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Tools::HMMER::Set;
-use vars qw(@ISA);
 use strict;
 
-use Bio::Root::Root;
 use Bio::Tools::HMMER::Domain;
 
-@ISA = qw( Bio::Root::Root );
+use base qw(Bio::Root::Root);
 
 sub new {
     my($class,@args) = @_;
@@ -115,7 +110,7 @@ sub add_Domain{
 =head2 each_Domain
 
  Title   : each_Domain
- Usage   : foreach $domain ( $set->each_Domain() ) 
+ Usage   : foreach $domain ( $set->each_Domain() )
  Function: returns an array of domain objects in this set
  Returns : array
  Args    : none
@@ -133,8 +128,8 @@ sub each_Domain{
 
  Title   : name
  Usage   : $obj->name($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of name
  Args    : newvalue (optional)
 
@@ -154,8 +149,8 @@ sub name{
 
  Title   : desc
  Usage   : $obj->desc($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of desc
  Args    : newvalue (optional)
 
@@ -174,8 +169,8 @@ sub desc{
 
  Title   : accession
  Usage   : $obj->accession($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of accession
  Args    : newvalue (optional)
 
@@ -195,8 +190,8 @@ sub accession{
 
  Title   : bits
  Usage   : $obj->bits($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of bits
  Args    : newvalue (optional)
 
@@ -217,8 +212,8 @@ sub bits{
 
  Title   : evalue
  Usage   : $obj->evalue($newval)
- Function: 
- Example : 
+ Function:
+ Example :
  Returns : value of evalue
  Args    : newvalue (optional)
 
