@@ -1,43 +1,44 @@
-#$Id$
+#$Id: OddCodes.pm,v 1.19.4.1 2006/10/02 23:10:32 sendu Exp $
 #-----------------------------------------------------------------------------
 # PACKAGE    : OddCodes.pm
 # PURPOSE    : To write amino acid sequences in alternative alphabets
 # AUTHOR     : Derek Gatherer (D.Gatherer@organon.nhe.akzonobel.nl)
-# SOURCE     : 
+# SOURCE     :
 # CREATED    : 8th July 2000
-# MODIFIED   : 
-# DISCLAIMER : I am employed in the pharmaceutical industry but my 
+# MODIFIED   :
+# DISCLAIMER : I am employed in the pharmaceutical industry but my
 #            : employers do not endorse or sponsor this module
 #            : in any way whatsoever.  The above email address is
 #            : given purely for the purpose of easy communication
 #            : with the author, and does not imply any connection
 #	     : between my employers and anything written below.
-# LICENCE    : You may distribute this module under the same terms 
+# LICENCE    : You may distribute this module under the same terms
 #	     : as the rest of BioPerl.
 #----------------------------------------------------------------------------
 
 =head1 NAME
 
-Bio::Tools::OddCodes - Object holding alternative alphabet coding for 
+Bio::Tools::OddCodes - Object holding alternative alphabet coding for
 one protein sequence
 
 =head1 SYNOPSIS
 
-Take a sequence object from eg, an inputstream, and creates an object
-for the purposes of rewriting that sequence in another alphabet.
-These are abbreviated amino acid sequence alphabets, designed to
-simplify the statistical aspects of analysing protein sequences, by
-reducing the combinatorial explosion of the 20-letter alphabet.  These
-abbreviated alphabets range in size from 2 to 8.
+  # Take a sequence object from eg, an inputstream, and creates an
+  # object for the purposes of rewriting that sequence in another
+  # alphabet.  These are abbreviated amino acid sequence alphabets,
+  # designed to simplify the statistical aspects of analysing protein
+  # sequences, by reducing the combinatorial explosion of the
+  # 20-letter alphabet.  These abbreviated alphabets range in size
+  # from 2 to 8.
 
-Creating the OddCodes object, eg:
+  # Creating the OddCodes object, eg:
 
-	my $inputstream = Bio::SeqIO->new( '-file' => "seqfile", 
+	my $inputstream = Bio::SeqIO->new( '-file' => "seqfile",
                                            '-format' => 'Fasta');
 	my $seqobj = $inputstream->next_seq();
 	my $oddcode_obj = Bio::Tools::Oddcodes->new(-seq => $seqobj);
 
-or:
+  # or:
 
 	my $seqobj = Bio::PrimarySeq->new
               (-seq=>'[cut and paste a sequence here]',
@@ -45,7 +46,8 @@ or:
                -id => 'test');
 	my $oddcode_obj  =  Bio::Tools::OddCodes->new(-seq => $seqobj);
 
-do the alternative coding, returning the answer as a reference to a string
+  # do the alternative coding, returning the answer as a reference to
+  # a string
 
 	my $output = $oddcode_obj->structural();
 	my $output = $oddcode_obj->chemical();
@@ -57,7 +59,7 @@ do the alternative coding, returning the answer as a reference to a string
 	my $output = $oddcode_obj->Stanfel();
 
 
-display sequence in new form, eg:
+  # display sequence in new form, eg:
 
 	my $new_coding = $$output;
 	print "\n$new_coding";
@@ -65,7 +67,7 @@ display sequence in new form, eg:
 =head1 DESCRIPTION
 
 Bio::Tools::Oddcodes is a welterweight object for rewriting a protein
-sequence in an alternative alphabet.  8 of these are provided, ranging
+sequence in an alternative alphabet.  Eight of these are provided, ranging
 from the the 2-letter hydrophobic alphabet, to the 8-letter chemical
 alphabet.  These are useful for the statistical analysis of protein
 sequences since they can partially avoid the combinatorial explosion
@@ -74,30 +76,37 @@ etc.)
 
 The objects will print out a warning if the input sequence is not a
 protein. If you know what you are doing, you can silence the warning
-by setting verbose() to a negetive value.
+by setting verbose() to a negative value.
 
-See Synopsis above for object creation code.
+See SYNOPSIS above for object creation code.
+
+=head1 REFERENCES
+
+Stanfel LE (1996) A new approach to clustering the amino acids.  J. theor.
+Biol. 183, 195-205.
+
+Karlin S, Ost F and Blaisdell BE (1989)  Patterns in DNA and amino acid
+sequences and their statistical significance.  Chapter 6 of: Mathematical
+Methods for DNA Sequences.  Waterman MS (ed.)  CRC Press, Boca Raton , FL.
 
 =head1 FEEDBACK
 
 =head2 Mailing Lists
 
-User feedback is an integral part of the evolution of this
-and other Bioperl modules. Send your comments and suggestions preferably
-to one of the Bioperl mailing lists.
-Your participation is much appreciated.
+User feedback is an integral part of the evolution of this and other
+Bioperl modules. Send your comments and suggestions preferably to one
+of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                - General discussion
-  http://www.bioperl.org/MailList.html - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://www.bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
@@ -105,23 +114,18 @@ Derek Gatherer
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. 
+The rest of the documentation details each of the object methods.
 Internal methods are usually preceded with a _
 
 =cut
 
-#'
-
 package Bio::Tools::OddCodes;
-use vars qw(@ISA);
 use strict;
 
-use Bio::Root::Root;
 
-@ISA = qw(Bio::Root::Root);
+use base qw(Bio::Root::Root);
 
-
-sub new 
+sub new
 {
     my($class,@args) = @_;
 
@@ -132,10 +136,9 @@ sub new
 	# parameter not passed as named parameter?
 	$seqobj = $args[0];
     }
-    unless  ($seqobj->isa("Bio::PrimarySeqI")) 
+    unless  ($seqobj->isa("Bio::PrimarySeqI"))
     {
-	die("die in _init, OddCodes works only on PrimarySeqI
-objects\n");
+        $self->throw("Bio::Tools::OddCodes only works on PrimarySeqI objects");
     }
 
     $self->{'_seqref'} = $seqobj;
@@ -146,7 +149,7 @@ objects\n");
 =head2 structural
 
  Title   : structural
- Usage   : $output = $oddcode_obj->structural(); 
+ Usage   : $output = $oddcode_obj->structural();
  Function: turns amino acid sequence into 3-letter structural alphabet
 	 : A (ambivalent), E (external), I (internal)
  Example : a sequence ACDEFGH will become AAEEIAE
@@ -161,7 +164,7 @@ sub structural()
 	my $seqstring = &_pullseq($self);	# see _pullseq() below
 
 # now the real business
-	
+
 	$seqstring =~ tr/[ACGPSTWY]/1/;
 	$seqstring =~ tr/[RNDQEHK]/2/;
 	$seqstring =~ tr/[ILMFV]/3/;
@@ -177,10 +180,10 @@ sub structural()
 =head2 functional
 
  Title   : functional
- Usage   : $output = $oddcode_obj->functional(); 
+ Usage   : $output = $oddcode_obj->functional();
  Function: turns amino acid sequence into 4-letter functional alphabet
 	 : A (acidic), C (basic), H (hydrophobic), P (polar)
- Example : a sequence ACDEFGH will become HPAAHHC 
+ Example : a sequence ACDEFGH will become HPAAHHC
  Returns : Reference to the new sequence string
  Args    : none
 
@@ -192,7 +195,7 @@ sub functional()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[DE]/1/;
 	$seqstring =~ tr/[HKR]/2/;
 	$seqstring =~ tr/[AFILMPVW]/3/;
@@ -210,7 +213,7 @@ sub functional()
 =head2 hydrophobic
 
  Title   : hydrophobic
- Usage   : $output = $oddcode_obj->hydrophobic(); 
+ Usage   : $output = $oddcode_obj->hydrophobic();
  Function: turns amino acid sequence into 2-letter hydrophobicity alphabet
 	 : O (hydrophobic), I (hydrophilic)
  Example : a sequence ACDEFGH will become OIIIOII
@@ -225,7 +228,7 @@ sub hydrophobic()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[AFILMPVW]/1/;
 	$seqstring =~ tr/[CDEGHKNQRSTY]/2/;
 	$seqstring =~ tr/1/I/;
@@ -239,9 +242,11 @@ sub hydrophobic()
 =head2 Dayhoff
 
  Title   : Dayhoff
- Usage   : $output = $oddcode_obj->Dayhoff(); 
+ Usage   : $output = $oddcode_obj->Dayhoff();
  Function: turns amino acid sequence into 6-letter Dayhoff alphabet
- Example : a sequence ACDEFGH will become CADDGCE 
+ Example : a sequence ACDEFGH will become CADDGCE
+         : A (=C),   C (=AGPST), D (=DENQ),
+         : E (=HKR), F (=ILMV),  G (=FWY)
  Returns : Reference to the new sequence string
  Args    : none
 
@@ -253,7 +258,7 @@ sub Dayhoff()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[C]/1/;
 	$seqstring =~ tr/[AGPST]/2/;
 	$seqstring =~ tr/[DENQ]/3/;
@@ -275,9 +280,11 @@ sub Dayhoff()
 =head2 Sneath
 
  Title   : Sneath
- Usage   : $output = $oddcode_obj->Sneath(); 
+ Usage   : $output = $oddcode_obj->Sneath();
  Function: turns amino acid sequence into 7-letter Sneath alphabet
  Example : a sequence ACDEFGH will become CEFFHCF
+         : A (=ILV), C (=AGP), D (=MNQ), E (=CST),
+         : F (=DE),  G (=KR),  H (=FHWY)
  Returns : Reference to the new sequence string
  Args    : none
 
@@ -289,7 +296,7 @@ sub Sneath()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[ILV]/1/;
 	$seqstring =~ tr/[AGP]/2/;
 	$seqstring =~ tr/[MNQ]/3/;
@@ -313,9 +320,10 @@ sub Sneath()
 =head2 Stanfel
 
  Title   : Stanfel
- Usage   : $output = $oddcode_obj->Stanfel(); 
+ Usage   : $output = $oddcode_obj->Stanfel();
  Function: turns amino acid sequence into 4-letter Stanfel alphabet
  Example : a sequence ACDEFGH will become AACCDAE
+         : A (=ACGILMPSTV), C (=DENQ), D (=FWY), E (=HKR)
  Returns : Reference to the new sequence string
  Args    : none
 
@@ -327,7 +335,7 @@ sub Stanfel()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[ACGILMPSTV]/1/;
 	$seqstring =~ tr/[DENQ]/2/;
 	$seqstring =~ tr/[FWY]/3/;
@@ -342,14 +350,14 @@ sub Stanfel()
 # and that's that one
 }
 
-=head2 chemical()
+=head2 chemical
 
  Title   : chemical
- Usage   : $output = $oddcode_obj->chemical(); 
+ Usage   : $output = $oddcode_obj->chemical();
  Function: turns amino acid sequence into 8-letter chemical alphabet
 	 : A (acidic), L (aliphatic), M (amide), R (aromatic)
-	 : C (basic), H (hydroxyl), I (imino), S (sulphur)
- Example : a sequence ACDEFGH will become LSAARAC 
+	 : C (basic),  H (hydroxyl),  I (imino), S (sulphur)
+ Example : a sequence ACDEFGH will become LSAARAC
  Returns : Reference to the new sequence string
  Args    : none
 
@@ -361,7 +369,7 @@ sub chemical()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[DE]/1/;
 	$seqstring =~ tr/[AGILV]/2/;
 	$seqstring =~ tr/[NQ]/3/;
@@ -387,9 +395,10 @@ sub chemical()
 =head2 charge
 
  Title   : charge
- Usage   : $output = $oddcode_obj->charge(); 
+ Usage   : $output = $oddcode_obj->charge();
  Function: turns amino acid sequence into 3-letter charge alphabet
- Example : a sequence ACDEFGH will become NNAANNC 
+ Example : a sequence ACDEFGH will become NNAANNC
+         : A (negative; NOT anode), C (positive; NOT cathode), N (neutral)
  Returns : Reference to the new sequence string
  Args    : none
 
@@ -401,7 +410,7 @@ sub charge()
 	my $seqstring = &_pullseq($self);
 
 # now the real business
-	
+
 	$seqstring =~ tr/[DE]/1/;
 	$seqstring =~ tr/[HKR]/2/;
 	$seqstring =~ tr/[ACFGILMNPQSTVWY]/3/;
@@ -422,10 +431,10 @@ sub _pullseq
 	my $self = $_[0];
 
 	my $seqobj =  $self->{'_seqref'};
-	
-	unless  ($seqobj->isa("Bio::PrimarySeqI")) 
+
+	unless  ($seqobj->isa("Bio::PrimarySeqI"))
 	{
-		die("die, OddCodes works only on PrimarySeqI objects\n");
+		$self->throw("die, OddCodes works only on PrimarySeqI objects\n");
     	}
         $self->warn("\tAll OddCode alphabets need a protein sequence,\n".
                     "\tbut BioPerl thinks this is not: [". $seqobj->id. "]")
@@ -435,7 +444,7 @@ sub _pullseq
 
 	if(length($seqstring)<1)
 	{
-		die("$seqstring: die, sequence has zero length\n");
+		$self->throw("$seqstring: die, sequence has zero length\n");
 	}
 	return $seqstring;
 }
