@@ -1,10 +1,10 @@
-# $Id$
+# $Id: SeqPattern.pm,v 1.21.4.1 2006/10/02 23:10:32 sendu Exp $
 #
 # bioperl module for Bio::Tools::SeqPattern
 #
-# Cared for by  Steve Chervitz  (sac@bioperl.org)
+# Cared for by  Steve Chervitz  (sac-at-bioperl.org)
 #
-# Copyright  Steve Chervitz 
+# Copyright  Steve Chervitz
 #
 # You may distribute this module under the same terms as perl itself
 
@@ -12,28 +12,25 @@
 
 =head1 NAME
 
-Bio::Tools::SeqPattern - Bioperl object for a sequence pattern or motif
+Bio::Tools::SeqPattern - represent a sequence pattern or motif
 
 =head1 SYNOPSIS
 
-=head2 Object Creation
+ use Bio::Tools::SeqPattern;
 
-    use Bio::Tools::SeqPattern ();
+ my $pat1     = 'T[GA]AA...TAAT';
+ my $pattern1 = Bio::Tools::SeqPattern->new(-SEQ =>$pat1, -TYPE =>'Dna');
 
-    $pat1     = 'T[GA]AA...TAAT';
-    $pattern1 = new Bio::Tools::SeqPattern(-SEQ =>$pattern, -TYPE =>'Dna'); 
-
-    $pat2     = '[VILM]R(GXX){3,2}...[^PG]';
-    $pattern2 = new Bio::Tools::SeqPattern(-SEQ =>$pattern, -TYPE =>'Amino'); 
+ my $pat2     = '[VILM]R(GXX){3,2}...[^PG]';
+ my $pattern2 = Bio::Tools::SeqPattern->new(-SEQ =>$pat2, -TYPE =>'Amino');
 
 =head1 DESCRIPTION
 
-The Bio::Tools::SeqPattern.pm module encapsulates generic data and
+L<Bio::Tools::SeqPattern> module encapsulates generic data and
 methods for manipulating regular expressions describing nucleic or
 amino acid sequence patterns (a.k.a, "motifs").
 
-Bio::Tools::SeqPattern.pm is a concrete class that inherits from
-B<Bio::Seq.pm>.
+L<Bio::Tools::SeqPattern> is a concrete class that inherits from L<Bio::Seq>.
 
 This class grew out of a need to have a standard module for doing routine
 tasks with sequence patterns such as:
@@ -46,18 +43,18 @@ tasks with sequence patterns such as:
 Other features to look for in the future:
 
   -- Full pattern syntax checking
-  -- Conversion between expanded and ondensed forms of the pattern
+  -- Conversion between expanded and condensed forms of the pattern
 
 =head1 MOTIVATIONS
 
-A key motivation for Bio::Tools::SeqPattern.pm is to have a way to
+A key motivation for L<Bio::Tools::SeqPattern> is to have a way to
 generate a reverse complement of a nucleotide sequence pattern.
-This makes possible simultaneous pattern matching on both sense and 
-anti-sense strands of a query sequence. 
+This makes possible simultaneous pattern matching on both sense and
+anti-sense strands of a query sequence.
 
-In principle, one could do such a search more inefficiently by testing 
-against both sense and anti-sense versions of a sequence. 
-It is entirely equivalent to test a regexp containing both sense and 
+In principle, one could do such a search more inefficiently by testing
+against both sense and anti-sense versions of a sequence.
+It is entirely equivalent to test a regexp containing both sense and
 anti-sense versions of the *pattern* against one copy of the sequence.
 The latter approach is much more efficient since:
 
@@ -78,36 +75,36 @@ send me some email (sac@bioperl.org). Thanks.
 
 =head2 Extended Alphabet Support
 
-This module supports the same set of ambiguity codes for nucleotide 
-sequences as supported by B<Bio::Seq.pm>. These ambiguity codes
-define the behavior or the expand() method.
+This module supports the same set of ambiguity codes for nucleotide
+sequences as supported by L<Bio::Seq>. These ambiguity codes
+define the behavior or the L<expand()> method.
 
  ------------------------------------------
  Symbol       Meaning      Nucleic Acid
  ------------------------------------------
-  A            A           Adenine
-  C            C           Cytosine
-  G            G           Guanine
-  T            T           Thymine
-  U            U           Uracil
-  M          A or C  
-  R          A or G        Any purine
-  W          A or T    
-  S          C or G     
-  Y          C or T        Any pyrimidine
-  K          G or T     
-  V        A or C or G  
-  H        A or C or T  
-  D        A or G or T  
-  B        C or G or T   
-  X      G or A or T or C 
-  N      G or A or T or C 
-  .      G or A or T or C 
+  A            A           (A)denine
+  C            C           (C)ytosine
+  G            G           (G)uanine
+  T            T           (T)hymine
+  U            U           (U)racil
+  M          A or C        a(M)ino group
+  R          A or G        pu(R)ine
+  W          A or T        (W)eak bond
+  S          C or G        (S)trong bond
+  Y          C or T        p(Y)rimidine
+  K          G or T        (K)eto group
+  V        A or C or G
+  H        A or C or T
+  D        A or G or T
+  B        C or G or T
+  X      G or A or T or C
+  N      G or A or T or C
+  .      G or A or T or C
 
 
 
  ------------------------------------------
- Symbol           Meaning   
+ Symbol           Meaning
  ------------------------------------------
  A        Alanine
  C        Cysteine
@@ -136,7 +133,7 @@ define the behavior or the expand() method.
  .        Any amino acid
 
 
-=head2   Multiple Format Support
+=head2 Multiple Format Support
 
 Ultimately, this module should be able to build SeqPattern.pm objects
 using a variety of pattern formats such as ProSite, Blocks, Prints, GCG, etc.
@@ -149,44 +146,35 @@ directory of the central Bioperl distribution.
 
 =head1 SEE ALSO
 
-L<Bio::Root::Object>   - Base class.
-L<Bio::Seq>            - Lightweight sequence object.
-
-http://bio.perl.org/Projects/modules.html  - Online module documentation
-http://bio.perl.org/                       - Bioperl Project Homepage 
+L<Bio::Seq> - Lightweight sequence object.
 
 =head1 FEEDBACK
 
-=head2 Mailing Lists 
+=head2 Mailing Lists
 
 User feedback is an integral part of the evolution of this and other
 Bioperl modules.  Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-    bioperl-l@bioperl.org              - General discussion
-    http://bio.perl.org/MailList.html  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution. Bug reports can be submitted via email
-or the web:
+the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-    bioperl-bugs@bio.perl.org
-    http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
-Steve Chervitz, sac@bioperl.org
-
-=head1 VERSION
-
-Bio::Tools::SeqPattern.pm, 0.011
+Steve Chervitz, sac-at-bioperl.org
 
 =head1 COPYRIGHT
 
 Copyright (c) 1997-8 Steve Chervitz. All Rights Reserved.
-This module is free software; you can redistribute it and/or 
+This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =cut
@@ -203,14 +191,12 @@ modify it under the same terms as Perl itself.
 
 package Bio::Tools::SeqPattern;
 
-use Bio::Root::Root;
-@ISA = qw(Bio::Root::Root);
+use base qw(Bio::Root::Root);
 use strict;
-use vars qw ($ID $VERSION);
+use vars qw ($ID);
 $ID  = 'Bio::Tools::SeqPattern';
-$VERSION = 0.011;
 
-## These constants may be more appropriate in a Bio::Dictionary.pm 
+## These constants may be more appropriate in a Bio::Dictionary.pm
 ## type of class.
 my $PURINES      = 'AG';
 my $PYRIMIDINES  = 'CT';
@@ -238,8 +224,8 @@ my (%Processed_braces, %Processed_asterics);
  Comments  : The process of creating a new SeqPattern.pm object
            : ensures that the pattern string is untained.
 
-See Also   : B<Bio::Root::Root::new()>, 
-             B<Bio::Seq::_initialize()>
+See Also   : L<Bio::Root::Root::new()>,
+             L<Bio::Seq::_initialize()>
 
 =cut
 
@@ -247,7 +233,7 @@ See Also   : B<Bio::Root::Root::new()>,
 sub new {
 #----------------
     my($class, %param) = @_;
-    
+
     my $self = $class->SUPER::new(%param);
     my ($seq,$type) = $self->_rearrange([qw(SEQ TYPE)], %param);
 
@@ -272,8 +258,8 @@ sub new {
  Title     : alphabet_ok
  Usage     : $mypat->alphabet_ok;
  Purpose   : Checks for invalid regexp characters.
-           : Overrides Bio::Seq::alphabet_ok() to allow 
-           : additional regexp characters ,.*()[]<>{}^$ 
+           : Overrides Bio::Seq::alphabet_ok() to allow
+           : additional regexp characters ,.*()[]<>{}^$
            : in addition to the standard genetic alphabet.
            : Also untaints the pattern and sets the sequence
            : object's sequence to the untained string.
@@ -297,14 +283,14 @@ sub alphabet_ok {
 
     my $pat = $self->seq();
 
-    if($pat =~ /[^$Regexp_chars]/io) { 
+    if($pat =~ /[^$Regexp_chars]/io) {
 	$self->throw("Pattern contains invalid characters: $pat",
 		     'Legal characters: a-z,A-Z,0-9,,.*()[]<>{}^$ ');
     }
 
     # Untaint pattern (makes code taint-safe).
-    $pat  =~ /[$Regexp_chars]+/io; 
-    $self->setseq(uc($&));
+    $pat  =~ /([$Regexp_chars]+)/io;
+    $self->setseq(uc($1));
 #    print STDERR "\npattern ok: $pat\n";
     1;
 }
@@ -317,10 +303,10 @@ sub alphabet_ok {
  Example   : $pat = $seq_pat->expand();
  Returns   : String containing fully expanded sequence pattern
  Argument  : n/a
- Throws    : Exception if sequence type is not recognized 
+ Throws    : Exception if sequence type is not recognized
            : (i.e., is not one of [DR]NA, Amino)
 
-See Also   : B<Extended Alphabet Support>, L<_expand_pep>(), L<_expand_nuc>()
+See Also   : L<Extended Alphabet Support>, L<_expand_pep>(), L<_expand_nuc>()
 
 =cut
 
@@ -343,7 +329,7 @@ sub expand {
  Usage     : n/a; automatically called by expand()
  Purpose   : Expands peptide patterns
  Returns   : String (the expanded pattern)
- Argument  : String (the unexpanded pattern) 
+ Argument  : String (the unexpanded pattern)
  Throws    : n/a
 
 See Also   : L<expand>(), L<_expand_nuc>()
@@ -383,7 +369,7 @@ sub _expand_pep {
  Title     : _expand_nuc
  Purpose   : Expands nucleotide patterns
  Returns   : String (the expanded pattern)
- Argument  : String (the unexpanded pattern) 
+ Argument  : String (the unexpanded pattern)
  Throws    : n/a
 
 See Also   : L<expand>(), L<_expand_pep>()
@@ -441,7 +427,7 @@ sub _expand_nuc {
     $pat =~ s/\((.)\)/$1/g;  ## Doing thses last since:
     $pat =~ s/\[(.)\]/$1/g;  ## Pattern could contain [y] (for example)
 
-    return $pat;  
+    return $pat;
 }
 
 
@@ -452,12 +438,12 @@ sub _expand_nuc {
  Usage     : revcom([1]);
  Purpose   : Forms a pattern capable of recognizing the reverse complement
            : version of a nucleotide sequence pattern.
- Example   : $pattern_object->revcom(); 
+ Example   : $pattern_object->revcom();
            : $pattern_object->revcom(1); ## returns expanded rev complement pattern.
  Returns   : Object reference for a new Bio::Tools::SeqPattern containing
            : the revcom of the current pattern as its sequence.
  Argument  : (1) boolean (optional) (default= false)
-           :     true : expand the pattern before rev-complementing. 
+           :     true : expand the pattern before rev-complementing.
            :     false: don't expand pattern before or after rev-complementing.
  Throws    : Exception if called for amino acid sequence pattern.
  Comments  : This method permits the simultaneous searching of both
@@ -465,10 +451,10 @@ sub _expand_nuc {
            : by means of a grep-type of functionality in which any
            : number of patterns may be or-ed into the recognition
            : pattern.
-           : Overrides Bio::Seq::revcom() and calls it first thing. 
+           : Overrides Bio::Seq::revcom() and calls it first thing.
            : The order of _fixpat() calls is critical.
 
-See Also   : B<Bio::Seq::revcom()>, L<_fixpat_1>(), L<_fixpat_2>(), L<_fixpat_3>(), L<_fixpat_4>(), L<_fixpat_5>()
+See Also   : L<Bio::Seq::revcom()>, L<_fixpat_1>(), L<_fixpat_2>(), L<_fixpat_3>(), L<_fixpat_4>(), L<_fixpat_5>()
 
 =cut
 
@@ -476,7 +462,7 @@ See Also   : B<Bio::Seq::revcom()>, L<_fixpat_1>(), L<_fixpat_2>(), L<_fixpat_3>
 sub revcom {
 #-----------
     my($self,$expand) = @_;
-    
+
     if ($self->type !~ /Dna|Rna/i) {
 	$self->throw("Can't get revcom for ${\$self->type} sequence types.\n");
     }
@@ -492,9 +478,9 @@ sub revcom {
 	$rev = $self->_expand_nuc($rev);
 #	print "\nExpanded: $rev\n";
     }
-			      
-    %Processed_braces = ();			      
-    %Processed_asterics = ();			      
+
+    %Processed_braces = ();
+    %Processed_asterics = ();
 
     my $fixrev = _fixpat_1($rev);
 #   print "FIX 1: $fixrev";<STDIN>;
@@ -507,7 +493,7 @@ sub revcom {
 
      $fixrev = _fixpat_4($fixrev);
 #    print "FIX 4: $fixrev";<STDIN>;
-    
+
      $fixrev = _fixpat_5($fixrev);
 #    print "FIX 5: $fixrev";<STDIN>;
 
@@ -542,7 +528,7 @@ See Also   : L<revcom>()
 sub _fixpat_1 {
 #--------------
     my $pat = shift;
-    
+
     ## Part I:
     my (@done,@parts);
     while(1) {
@@ -588,7 +574,7 @@ sub _fixpat_1 {
 	last if not $pat;
     }
     return join('', reverse @done);
-    
+
 }
 
 
@@ -611,7 +597,7 @@ See Also   : L<revcom>()
 sub _fixpat_2 {
 #--------------
     my $pat = shift;
-    
+
     local($^W) = 0;
     my (@done,@parts,$braces);
     while(1) {
@@ -649,7 +635,7 @@ See Also   : L<revcom>()
 sub _fixpat_3 {
 #-------------
     my $pat = shift;
-    
+
     my (@done,@parts,$braces,$newpat,$oldpat);
     while(1) {
 #	$pat =~ s/(.+)(\{\S+\})(\(\w+\))(.*)/$1#$3$2$4/ or do{ push @done, $pat; last; };
@@ -668,8 +654,8 @@ sub _fixpat_3 {
 ##ps	    }
 	} elsif( $pat =~ /^(\{\S+\})(\(\w+\))(.*)/) {
 	    $pat = "#$2$1$3";
-	} else { 
-	    push @done, $pat; last; 
+	} else {
+	    push @done, $pat; last;
 	}
 	@parts = split '#', $pat;
 	push @done, $parts[1];
@@ -699,7 +685,7 @@ See Also   : L<revcom>()
 sub _fixpat_4 {
 #---------------
     my $pat = shift;
-    
+
     my (@done,@parts,$braces,$newpat,$oldpat);
     while(1) {
 #	$pat =~ s/(.*)(\{\S+\})(\[\w+\])(.*)/$1#$3$2$4/ or do{ push @done, $pat; last; };
@@ -718,12 +704,12 @@ sub _fixpat_4 {
 		$pat = $newpat;  # Change it.
 #		print "new pat: $pat";<STDIN>;
 	    }
-	} elsif( $pat =~ /^(\{\S+\})(\[\w+\])(.*)/) {  
+	} elsif( $pat =~ /^(\{\S+\})(\[\w+\])(.*)/) {
 	    $pat = "#$2$1$3";
-	} else { 
-	    push @done, $pat; last; 
+	} else {
+	    push @done, $pat; last;
 	}
-	    
+
 	@parts = split '#', $pat;
 	push @done, $parts[1];
 	$pat = $parts[0];
@@ -753,7 +739,7 @@ See Also   : L<revcom>()
 sub _fixpat_5 {
 #--------------
     my $pat = shift;
-    
+
     my (@done,@parts,$newpat,$oldpat);
     while(1) {
 #	$pat =~ s/(.*)(\{\S+\})(\[\w+\])(.*)/$1#$3$2$4/ or do{ push @done, $pat; last; };
@@ -769,12 +755,12 @@ sub _fixpat_5 {
 		$pat = $newpat;  # Change it.
 #		print "new pat: $pat";<STDIN>;
 	    }
-	} elsif( $pat =~ /^\*(\[\w+\]|\(\w+\))(.*)/) {  
+	} elsif( $pat =~ /^\*(\[\w+\]|\(\w+\))(.*)/) {
 	    $pat = "#$1*$3";
-	} else { 
-	    push @done, $pat; last; 
+	} else {
+	    push @done, $pat; last;
 	}
-	    
+
 	@parts = split '#', $pat;
 	push @done, $parts[1];
 	$pat = $parts[0];
@@ -839,7 +825,7 @@ sub _fixpat_6 {
 
  Title   : str
  Usage   : $obj->str($newval)
- Function: 
+ Function:
  Returns : value of str
  Args    : newvalue (optional)
 
@@ -860,7 +846,7 @@ sub str{
 
  Title   : type
  Usage   : $obj->type($newval)
- Function: 
+ Function:
  Returns : value of type
  Args    : newvalue (optional)
 
@@ -882,7 +868,7 @@ sub type{
 __END__
 
 #########################################################################
-#  End of class 
+#  End of class
 #########################################################################
 
 =head1 FOR DEVELOPERS ONLY
@@ -895,7 +881,7 @@ in mind:
 
 =over 2
 
-=item 1 Do NOT rely on these in any code outside of this module. 
+=item 1 Do NOT rely on these in any code outside of this module.
 
 All data members are prefixed with an underscore to signify that they
 are private.  Always use accessor methods. If the accessor doesn't
@@ -920,7 +906,7 @@ to a hash containing all or some of the following fields:
  INHERITED DATA MEMBERS:
 
  _seq     : (From Bio::Seq.pm) The original, unexpanded input sequence after untainting.
- _type    : (From Bio::Seq.pm) 'Dna' or 'Amino' 
+ _type    : (From Bio::Seq.pm) 'Dna' or 'Amino'
 
 
 =cut
