@@ -1,9 +1,9 @@
-
+# $Id: Results.pm,v 1.25.4.1 2006/10/02 23:10:37 sendu Exp $
 #
 # BioPerl module for Bio::Tools::Sim4::Results
 #
-# Cared for by Ewan Birney <birney@sanger.ac.uk>
-#          and Hilmar Lapp <hlapp@gmx.net>
+# Cared for by Ewan Birney <birney-at-sanger.ac.uk>
+#          and Hilmar Lapp <hlapp-at-gmx.net>
 #
 # Copyright Ewan Birney and Hilmar Lapp
 #
@@ -19,26 +19,26 @@ Bio::Tools::Sim4::Results - Results of one Sim4 run
 
    # to preset the order of EST and genomic file as given on the sim4 
    # command line:
-   $sim4 = Bio::Tools::Sim4::Results->new(-file => 'result.sim4',
-                                          -estisfirst => 1);
+   my $sim4 = Bio::Tools::Sim4::Results->new(-file => 'result.sim4',
+                                             -estfirst => 1);
    # to let the order be determined automatically (by length comparison):
-   $sim4 = Bio::Tools::Sim4->new( -file => 'sim4.results' );
+   $sim4 = Bio::Tools::Sim4::Results->new( -file => 'sim4.results' );
    # filehandle:
-   $sim4 = Bio::Tools::Sim4->new( -fh   => \*INPUT );
+   $sim4 = Bio::Tools::Sim4::Results->new( -fh   => \*INPUT );
 
    # parse the results
-   while($exonset = $sim4->next_exonset()) {
+   while(my $exonset = $sim4->next_exonset()) {
        # $exonset is-a Bio::SeqFeature::Generic with Bio::Tools::Sim4::Exons
        # as sub features
-       print "Delimited on sequence ", $exonset->seqname(), 
-             "from ", $exonset->start(), " to ", $exonset->end() "\n";
-       foreach $exon ( $exonset->sub_SeqFeature() ) {
+       print "Delimited on sequence ", $exonset->seq_id(), 
+             "from ", $exonset->start(), " to ", $exonset->end(), "\n";
+       foreach my $exon ( $exonset->sub_SeqFeature() ) {
 	  # $exon is-a Bio::SeqFeature::FeaturePair
 	  print "Exon from ", $exon->start, " to ", $exon->end, 
                 " on strand ", $exon->strand(), "\n";
           # you can get out what it matched using the est_hit attribute
-          $homol = $exon->est_hit();
-          print "Matched to sequence", $homol->seqname, 
+          my $homol = $exon->est_hit();
+          print "Matched to sequence ", $homol->seq_id, 
                 " at ", $homol->start," to ", $homol->end, "\n";
       }
    }
@@ -86,24 +86,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org          - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via email
-or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bio.perl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Ewan Birney, Hilmar Lapp
 
-Email birney@sanger.ac.uk
-      hlapp@gmx.net (or hilmar.lapp@pharma.novartis.com)
-
-Describe contact details here
+Ewan Birney E<lt>birney-at-sanger.ac.ukE<gt>
+Hilmar Lapp E<lt>hlapp-at-gmx.netE<gt> or E<lt>hilmar.lapp-at-pharma.novartis.comE<gt>.
 
 =head1 APPENDIX
 
@@ -116,17 +113,14 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Tools::Sim4::Results;
-use vars qw(@ISA);
 use strict;
 
-# Object preamble - inherits from Bio::Root::Object
 
 use File::Basename;
 use Bio::Root::Root;
-use Bio::Tools::AnalysisResult;
 use Bio::Tools::Sim4::Exon;
 
-@ISA = qw(Bio::Tools::AnalysisResult);
+use base qw(Bio::Tools::AnalysisResult);
 
 
 sub _initialize_state {
@@ -174,7 +168,7 @@ sub analysis_method {
            this method repeatedly until an empty array is returned to get the
            results for all alignments.
 
-           The $exon->seqname() attribute will be set to the identifier of the
+           The $exon->seq_id() attribute will be set to the identifier of the
            respective sequence for both sequences if A=4 was used in the sim4
            run, and otherwise for the second sequence only. If the output does
            not contain the identifier, the filename stripped of path and 
@@ -213,7 +207,6 @@ sub parse_next_alignment {
    
    while(defined($_ = $self->_readline())) {
        #chomp();
-
        #
        # bascially, each sim4 'hit' starts with seq1...
        #
@@ -234,7 +227,7 @@ sub parse_next_alignment {
        /^seq2/ && do {
 	   # the second hit has also the database name in the >name syntax 
 	   # (in brackets).
-	   /^seq2\s+=\s+(\S+)\s+\(>?(\S+)\s*\)\,\s+(\d+)/ ||
+	   /^seq2\s+=\s+(\S+)\s+\(>?(\S+)\s*\)\,\s+(\d+)/||
 	       $self->throw("Sim4 parsing error on seq2 [$_] line. Sorry!");
 	   $seq2props{'filename'} = $1;
 	   $seq2props{'seqname'} = $2;
@@ -309,11 +302,11 @@ sub parse_next_alignment {
 					    '-end'   => $genomseq->{'end'},
 					    '-strand' => $hit_direction);
 	   if(exists($genomseq->{'seqname'})) {
-	       $exon->seqname($genomseq->{'seqname'});
+	       $exon->seq_id($genomseq->{'seqname'});
 	   } else {
 	       # take filename stripped of path as fall back
 	       my ($basename) = &File::Basename::fileparse($genomseq->{'filename'}, '\..*');
-	       $exon->seqname($basename);
+	       $exon->seq_id($basename);
 	   }
 	   $exon->feature1()->add_tag_value('filename',
 					    $genomseq->{'filename'});
@@ -332,12 +325,12 @@ sub parse_next_alignment {
 					    '-strand' => 0,
 					    '-primary' => "aligning_EST");
 	   if(exists($estseq->{'seqname'})) {
-	       $fea2->seqname($estseq->{'seqname'});
+	       $fea2->seq_id($estseq->{'seqname'});
 	   } else {
 	       # take filename stripped of path as fall back
 	       my ($basename) =
 		   &File::Basename::fileparse($estseq->{'filename'}, '\..*');
-	       $fea2->seqname($basename);
+	       $fea2->seq_id($basename);
 	   }
 	   $fea2->add_tag_value('filename', $estseq->{'filename'});
 	   $fea2->seqlength($estseq->{'length'});
@@ -386,7 +379,10 @@ sub next_exonset {
 
     # get the next array of exons
     my @exons = $self->parse_next_alignment();
-    return if($#exons < 0);
+    unless( @exons ) {
+	return if eof($self->_fh);
+	return $self->next_exonset;
+    } 
     # create the container of exons as a feature object itself, with the
     # data of the first exon for initialization
     $exonset = Bio::SeqFeature::Generic->new('-start' => $exons[0]->start(),
@@ -394,7 +390,7 @@ sub next_exonset {
 					     '-strand' => $exons[0]->strand(),
 					     '-primary' => "ExonSet");
     $exonset->source_tag($exons[0]->source_tag());
-    $exonset->seqname($exons[0]->seqname());
+    $exonset->seq_id($exons[0]->seq_id());
     # now add all exons as sub features, with enabling EXPANsion of the region
     # covered in total
     foreach my $exon (@exons) {
