@@ -1,4 +1,4 @@
-# $Id$
+# $Id: UpdateableSeqI.pm,v 1.7.4.1 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::UpdateableSeqI
 #
@@ -33,17 +33,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - David Block
 
@@ -65,16 +64,14 @@ Internal methods are usually preceded with a _
 
 
 package Bio::UpdateableSeqI;
-use vars qw(@ISA);
 use strict;
 use Carp;
 
 # Object preamble - inherits from Bio::Root::Root
 
-use Bio::SeqI;
 
 
-@ISA = qw(Bio::SeqI);
+use base qw(Bio::SeqI);
 
 
 =head2 delete_feature
