@@ -1,8 +1,8 @@
-# $Id: AAChange.pm,v 1.13 2002/10/22 07:38:49 lapp Exp $
+# $Id: AAChange.pm,v 1.20.4.1 2006/10/02 23:10:38 sendu Exp $
 #
 # BioPerl module for Bio::Variation::AAChange
 #
-# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
+# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
 #
 # Copyright Heikki Lehvaslaiho
 #
@@ -61,27 +61,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
-report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email:  heikki@ebi.ac.uk
-
-Address:
-
-     EMBL Outstation, European Bioinformatics Institute
-     Wellcome Trust Genome Campus, Hinxton
-     Cambs. CB10 1SD, United Kingdom
+Email:  heikki-at-bioperl-dot-org
 
 =head1 APPENDIX
 
@@ -95,14 +88,13 @@ methods. Internal methods are usually preceded with a _
 
 
 package Bio::Variation::AAChange;
-my $VERSION=1.0;
-use vars qw(@ISA $MATRIX);
+
+use vars qw($MATRIX);
 use strict;
 
 # Object preamble - inheritance
-use Bio::Variation::VariantI;
 
-@ISA = qw( Bio::Variation::VariantI );
+use base qw(Bio::Variation::VariantI);
 
 BEGIN {
 
@@ -241,14 +233,14 @@ sub RNAChange {
   if (defined $value) {
       if( ! $value->isa('Bio::Variation::RNAChange') ) {
 	  $self->throw("Is not a Bio::Variation::RNAChange object but a [$self]");
-	  return (undef);
+	  return;
       }
       else {
 	  $self->{'RNAChange'} = $value;
       }
   }
   unless (exists $self->{'RNAChange'}) {
-      return (undef);
+      return;
   } else {
       return $self->{'RNAChange'};
   }
@@ -356,8 +348,8 @@ sub similarity_score {
     my ($o, $m, $type);
     $o = $self->allele_ori->seq if $self->allele_ori and $self->allele_ori->seq;
     $m = $self->allele_mut->seq if $self->allele_mut and $self->allele_mut->seq;
-    return undef unless $o and $m and length $o == 1 and length $m == 1;
-    return undef unless $o =~ /[ARNDCQEGHILKMFPSTWYVBZX*]/i and
+    return unless $o and $m and length $o == 1 and length $m == 1;
+    return unless $o =~ /[ARNDCQEGHILKMFPSTWYVBZX*]/i and
 	$m =~ /[ARNDCQEGHILKMFPSTWYVBZX*]/i;
     return $MATRIX->{"\U$o"}->{"\U$m"};
 }
@@ -374,7 +366,7 @@ sub similarity_score {
            the 'trivial name' of the mutation. Trivial name is
            specified in Antonorakis & MDI Nomenclature Working Group:
            Human Mutation 11:1-3, 1998.
-           http://www.interscience.wiley.com/jpages/1059-7794/nomenclature.html
+           http://www3.interscience.wiley.com/cgi-bin/abstract/5001291/ABSTRACT
 
  Returns : string
 
