@@ -1,8 +1,8 @@
-# $Id$
+# $Id: IO.pm,v 1.22.4.1 2006/10/02 23:10:38 sendu Exp $
 #
 # BioPerl module for Bio::Variation::IO
 #
-# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
+# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
 #
 # Copyright Heikki Lehvaslaiho
 #
@@ -18,30 +18,32 @@ Bio::Variation::IO - Handler for sequence variation IO Formats
 
     use Bio::Variation::IO;
 
-    $in  = Bio::Variation::IO->new(-file => "inputfilename" , '-format' => 'flat');
-    $out = Bio::Variation::IO->new(-file => ">outputfilename" , '-format' => 'xml');
-    # note: we quote -format to keep older perl's from complaining.
+    $in  = Bio::Variation::IO->new(-file => "inputfilename" , 
+                                   -format => 'flat');
+    $out = Bio::Variation::IO->new(-file => ">outputfilename" ,
+                                   -format => 'xml');
 
     while ( my $seq = $in->next() ) {
-	$out->write($seq);
+	   $out->write($seq);
     }
 
-or
+  # or
 
     use Bio::Variation::IO;
 
     #input file format can be read from the file extension (dat|xml)
     $in  = Bio::Variation::IO->newFh(-file => "inputfilename");
-    $out = Bio::Variation::IO->newFh('-format' => 'xml');
+    $out = Bio::Variation::IO->newFh(-format => 'xml');
 
     # World's shortest flat<->xml format converter:
     print $out $_ while <$in>;
 
 =head1 DESCRIPTION
 
-Bio::Variation::IO is a handler module for the formats in the Variation IO set (eg,
-Bio::Variation::IO::flat). It is the officially sanctioned way of getting at
-the format objects, which most people should use.
+Bio::Variation::IO is a handler module for the formats in the 
+Variation IO set (eg, Bio::Variation::IO::flat). It is the officially 
+sanctioned way of getting at the format objects, which most people 
+should use.
 
 The structure, conventions and most of the code is inherited from
 L<Bio::SeqIO> module. The main difference is that instead of using
@@ -66,15 +68,16 @@ also
    $stream->type() # returns 'INPUT' or 'OUTPUT'
 
 As an added bonus, you can recover a filehandle that is tied to the
-SeqIO object, allowing you to use the standard E<lt>E<gt> and print operations
-to read and write sequence objects:
+SeqIO object, allowing you to use the standard E<lt>E<gt> and print 
+operations to read and write sequence objects:
 
     use Bio::Variation::IO;
 
-    $stream = Bio::Variation::IO->newFh(-format => 'flat'); # read from standard input
+    $stream = Bio::Variation::IO->newFh(-format => 'flat'); 
+    # read from standard input
 
     while ( $seq = <$stream> ) {
-	# do something with $seq
+	   # do something with $seq
     }
 
 and
@@ -86,13 +89,12 @@ This makes the simplest ever reformatter
     #!/usr/local/bin/perl
 
     $format1 = shift;
-    $format2 = shift || die "Usage: reformat format1 format2 < input > output";
+    $format2 = shift;
 
     use Bio::Variation::IO;
 
     $in  = Bio::Variation::IO->newFh(-format => $format1 );
     $out = Bio::Variation::IO->newFh(-format => $format2 );
-    #note: you might want to quote -format to keep older perl's from complaining.
 
     print $out $_ while <$in>;
 
@@ -197,27 +199,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the 
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
-report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email:  heikki@ebi.ac.uk
-Address: 
-
-     EMBL Outstation, European Bioinformatics Institute
-     Wellcome Trust Genome Campus, Hinxton
-     Cambs. CB10 1SD, United Kingdom 
-
+Email:  heikki-at-bioperl-dot-org
 
 =head1 APPENDIX
 
@@ -229,14 +224,11 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Variation::IO;
-my $VERSION=1.0;
 
 use strict;
-use vars '@ISA';
 
-use Bio::SeqIO;
 
-@ISA = 'Bio::SeqIO';
+use base qw(Bio::SeqIO);
 
 =head2 new
 
@@ -261,7 +253,7 @@ sub new {
              || 'flat';
    $format = "\L$format"; # normalize capitalization to lower case
 
-   return undef unless $class->_load_format_module($format);
+   return unless $class->_load_format_module($format);
    return "Bio::Variation::IO::$format"->new(%param);
 }
 
