@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: modules.pl,v 1.13 2004/11/14 15:03:14 bosborne Exp $
+# $Id: modules.pl,v 1.22 2006/07/04 22:23:28 mauricio Exp $
 #
 =head1 NAME
 
@@ -111,7 +111,7 @@ sub tested {
     my $self = shift;
     my $value = shift;
     $self->{'tested'} = 1 if defined $value && $value;
-    return $self->{'tested'};
+    return $self->{'tested'} || 0;
 }
 
 sub type {
@@ -252,7 +252,7 @@ sub modules {
             }
             $class->path($File::Find::name);
         }
-        if (/^\w*use/ && /(Bio[\w:]+)\W*;/) {
+        if (/^\w*use/ && /(Bio[\w:]+)\W*;/ && not /base/) {
 	    next unless $class;
             #print "\t$1\n" if $verbose;
             $class->add_used_class($1);
@@ -274,7 +274,6 @@ sub modules {
             }
         }
     }
-
     close F;
 }
 
@@ -342,34 +341,71 @@ sub list_all {
 =item B<-u | --untested>
 
 Prints a list of instance modules which are I<not> explicitly used by
-test files in t directory. Superclasess or any classes used by others
+test files in the directory. Superclasess or any classes used by others
 are not reported, either, since their methods are assumed to be tested
 by subclass tests.
 
-This method can not be improved much without running the tests!
 
 =cut
 
+sub _used_and_super {
+    my $name = shift;
+#    print "-:$name\n" if /Locati/; 
+    foreach ($MODULES{$name}->each_superclass) {
+        next unless defined $MODULES{$_};
+#        print "-^$_\n" if /Locati/; 
+#        unless (defined $MODULES{$_} or $MODULES{$_}->tested) {
+        if (not  $MODULES{$_}->tested) {
+            $MODULES{$_}->tested(1);
+            _used_and_super($_);
+        }
+    }
+    foreach ($MODULES{$name}->each_used_class) {
+        next unless defined $MODULES{$_};
+#        print "--$_\n" if /Locati/; 
+#        unless (defined $MODULES{$_} or $MODULES{$_}->tested) {
+        if (not  $MODULES{$_}->tested) {
+            $MODULES{$_}->tested(1);
+            _used_and_super($_);
+        }
+#        $MODULES{$_}->tested(1) && _used_and_super($_)
+#            unless defined $MODULES{$_} or $MODULES{$_}->tested;
+    }
+    return 1;
+}
+
 sub untested {
-    foreach (`find ../t -name "*.t" -print | xargs grep -hs "use "`) {
-        s/^ *?use +//;
+    foreach (`find ../t -name "*.t" -print | xargs grep -hs "[ur][se][eq]"`) {
+        s/.*use +//;
+        s/.*require +//;
         next unless /^Bio/;
+
         s/[\W;]+$//;
+        s/([\w:]+).*/$1/;
+        my $name = $_;
+
         next unless $MODULES{$_};
         $MODULES{$_}->tested(1) 
             unless defined $MODULES{$_} and $MODULES{$_}->tested;
-        foreach ($MODULES{$_}->each_superclass) {
-            $MODULES{$_}->tested(1)
-                unless defined $MODULES{$_} or $MODULES{$_}->tested;
-        }
-        foreach ($MODULES{$_}->each_used_class) {
-            $MODULES{$_}->tested(1)
-                unless defined $MODULES{$_} and $MODULES{$_}->tested;
-        }
+
+        next if $MODULES{$name}->name eq "Bio::SeqIO::abi"; # exception: requires bioperl ext package
+        next if $MODULES{$name}->name eq "Bio::SeqIO::ctf"; # exception: requires bioperl ext package
+        next if $MODULES{$name}->name eq "Bio::SeqIO::exp"; # exception: requires bioperl ext package
+        next if $MODULES{$name}->name eq "Bio::SeqIO::pln"; # exception: requires bioperl ext package
+        next if $MODULES{$name}->name eq "Bio::SeqIO::ztr"; # exception: requires bioperl ext package
+#        print $MODULES{$name}->name, "\n";
+#        print Dumper $MODULES{$name};
+
+        _used_and_super($name);
 
     }
 
     foreach ( sort keys %MODULES) {
+
+        # skip some name spaces 
+        next  if /^Bio::Search/; # Bio::Search and Bio::SearchIO are extensively tested 
+                                 # but classes are used by attribute naming 
+
         print "$_\n" if
             $MODULES{$_}->type eq 'instance' and ($MODULES{$_}->tested == 0) ;
     }
@@ -431,6 +467,7 @@ sub synopsis {
 
         next unless $c->type eq "instance";
         next if $c->name eq 'Bio::Root::Version';
+        next if $c->name eq 'Bio::Tools::HMM';
 
         my $synopsis = '';
         open (F, $c->path) or warn "can't open file ".$c->name.": $!" && return;
@@ -507,25 +544,24 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
-Heikki Lehvaslaiho, heikki@ebi.ac.uk
+Heikki Lehvaslaiho, heikki-at-bioperl-dot-org
 
 =head1 Contributors
 
-Albert Vilella, avilella@ebi.ac.uk
+Albert Vilella, avilella-AT-gmail-DOT-com
 
 =cut
 
