@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: pod.pl,v 1.4 2004/11/14 15:03:14 bosborne Exp $
+# $Id: pod.pl,v 1.9 2006/07/04 22:23:28 mauricio Exp $
 #
 =head1 NAME
 
@@ -7,7 +7,7 @@ pod.pl - check the POD documentation syntax in modules and scripts
 
 =head1 SYNOPSIS
 
-B<pod.pl> [B<-d|--dir> path ] [B<-v|--verbose>] B<-b|--blankline> 
+B<pod.pl> [B<-d|--dir> path ] [B<-v|--verbose>] B<-b|--blankline>
     [B<-?|-h|--help>]
 
 =head1 DESCRIPTION
@@ -90,6 +90,7 @@ sub podcheck {
     print "$_\n" if $verbose;
     my $checker = new Pod::Checker %POD_CHECKER_OPTIONS;
     $checker->parse_from_file($_, \*F);
+    print "$_\tno POD\n" if $checker->num_errors() < 0;
 }
 
 =head1 OPTIONS
@@ -154,21 +155,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email heikki@ebi.ac.uk
+Email heikki-at-bioperl-dot-org
 
 =cut
 
